(() => {
  if (!window.$docsify) {
    throw new Error('Docsify must be loaded before installing this plugin.');
  }
  function getTheme() {
    return localStorage.getItem('theme') || 'auto';
  }

  function isDark() {
    if (theme === 'auto') {
      return window.matchMedia('(prefers-color-scheme: dark)').matches;
    }
    return theme === 'dark';
  }

  function setTheme(newTheme) {
    const noTransitions = Object.assign(document.createElement('style'), {
      textContent: '* { transition: none !important; }'
    });

    theme = newTheme;
    localStorage.setItem('theme', theme);

    // Update the UI
    if (menu) {
      [...menu.querySelectorAll('twc-menu-item')].map(item => (item.checked = item.getAttribute('value') === theme));
      menuIcon.name = isDark() ? 'moon' : 'sun';
    }
    // Toggle the dark mode class without transitions
    document.body.appendChild(noTransitions);
    requestAnimationFrame(() => {
      document.documentElement.classList.toggle('twc-theme-dark', isDark());
      requestAnimationFrame(() => document.body.removeChild(noTransitions));
    });
  }

  let theme = getTheme();
  let menu, menuIcon;
  window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', () => setTheme(theme));

  // Toggle themes when pressing backslash
  document.addEventListener('keydown', event => {
    if (
      event.key === '\\' &&
      !event.composedPath().some(el => ['input', 'textarea'].includes(el?.tagName?.toLowerCase()))
    ) {
      event.preventDefault();

      setTheme(isDark() ? 'light' : 'dark');
    }
  });

  // Set the initial theme and sync the UI
  setTheme(theme);
  function createThemeDropdown() {
    const existingDropdown = document.querySelector('.theme-picker');
    if (existingDropdown) {
      existingDropdown.remove();
    };
    const dropdown = document.createElement('twc-dropdown');
    dropdown.classList.add('theme-picker');
    dropdown.innerHTML = `
      <twc-button size="small" pill slot="trigger" caret>
        <twc-icon name="sun" label="Select Theme"></twc-icon>
      </twc-button>
      <twc-menu>
        <twc-menu-label>Toggle <kbd>\\</kbd></twc-menu-label>
        <twc-menu-item value="light">Light</twc-menu-item>
        <twc-menu-item value="dark">Dark</twc-menu-item>
        <twc-divider></twc-divider>
        <twc-menu-item value="auto">Auto</twc-menu-item>
      </twc-menu>
    `;    
    const navbar = document.querySelector('#theme-selector');
    if (navbar) {
      navbar.insertAdjacentElement('beforeend', dropdown);
      console.log("dropdown added");      
      menu = dropdown.querySelector('twc-menu');
      menuIcon = dropdown.querySelector('twc-icon');

      menu.addEventListener('twc-select', event => setTheme(event.detail.item.value));    
    }
  }
  function setSelctedClass() {
    // const navLinks = document.querySelectorAll(".nav__links");
    const activeLi = document.querySelectorAll('.nav__links__container ul li');
    const currentHash = (window.location.hash).split('/')[1];
    if(currentHash) {            
      activeLi.forEach(li => {
        const activeLink = li.querySelector('.nav__links');        
      if(activeLink) {
        const currentMenu = activeLink.href.includes(currentHash+'/');
        if(currentMenu)
        li.classList.add('selected');
      }
      })            
    }
    else {
      activeLi[0].classList.add('selected');
    } 
  }
  
  function observeNavbar() {
    const observer = new MutationObserver(() => {
      const navbar = document.querySelector('#theme-selector');
      const navLinks = document.querySelectorAll(".nav__links");    
      if (navbar && navLinks ) {
        setTimeout(() => {
          setSelctedClass();
          createThemeDropdown();
        }, 500);        
        observer.disconnect();
      }
    });

    observer.observe(document.body, { childList: true, subtree: true });
  }
  window.$docsify.plugins.push(hook => {
    hook.afterEach(() => {
      observeNavbar();
    });
  });
})();
