# Getting Started with BPM Components
#### This API reference provides comprehensive documentation for our new BPM Business Components. These components are designed to streamline the development of BPM-related web applications by providing pre-built, framework-agnostic UI elements. Whether you're building a work management portal, a case management system, or any other browser-based BPM application, these components can accelerate your development process.

## Key Features

<li><b>Framework Agnostic:</b> Seamlessly integrate into any JavaScript framework (React, Angular, Vue.js, etc.) or even plain HTML/JavaScript projects.</li>
<li><b>Fully Functional:</b> Each component encapsulates specific BPM functionality, reducing development time and effort.</li>
<li><b>Self-Contained:</b> Components operate independently with minimal external dependencies.</li>
<li><b>Rich Functionality:</b> Cover various BPM aspects, including work management, case management, authentication, and audit trails.</li>

## Component Documentation Structure

Each component's documentation follows a consistent structure to provide clear and concise information:

<li><b>Overview:</b> A brief description of the component's purpose and functionality.</li>
<li><b>Markup:</b> The HTML markup required to render the component in a web page.</li>
<li><b>Attributes:</b> A list of all supported attributes that can be passed to the component to customize its behavior and appearance.</li>
<li><b>Properties:</b> Details about configurable properties that influence the component's internal state and logic. These can be modified dynamically after the component is rendered.</li>
<li><b>Events:</b> A list of custom events emitted by the component, allowing developers to react to specific actions or changes within the component.</li>
<li><b>Methods:</b> Documentation of the component's public methods that can be invoked by the consumer to interact with the component programmatically.</li>
<li><b>Configurations:</b> Information about custom configurations that can be applied globally to modify the overall look and feel of the component.</li>
<li><b>CSS Parts:</b> Information on how to customize the component's styling using CSS parts, allowing for targeted modifications to specific elements.</li>
<li><b>Slots:</b> Explanation of available slots for content projection, enabling developers to insert custom content into predefined areas within the component.</li>
<li><b>CSS Custom Properties:</b> A list of CSS custom properties that can be used to style the component.</li>
<li><b>Dependencies:</b> Details about any external libraries or dependencies required by the component.</li>
<li><b>Examples:</b> Practical examples demonstrating how to use the component in various scenarios.</li>
<li><b>Live Demo:</b> An interactive demo showcasing the component's functionality with mock data, allowing for real-time experimentation.</li>

## Component Categories

The components are categorized based on their functional areas within BPM:

<li><b>Work Management:</b> Components for work items, work views and more.</li>
<li><b>Case Management:</b> Components for case types, cases, case details, case documents, case audit and related actions.</li>
<li><b>Authentication:</b> Components for login and logout.</li>
<li><b>Audit:</b> Components for displaying audit details for work items, cases, processes, users, applications and systems.</li>

## Using the API Reference

This reference guide serves as your primary resource for understanding and effectively utilizing BPM Business Components. Use the navigation to find the desired component and explore its documentation. Each component page provides all the necessary information for integration and customization.
