# tibco-form

[component-header:tibco-form]

Forms are used to collect information from and present data to users.

## Examples

### Loading of forms created in Business Studio Forms Designer and deployed to the runtime
This example shows how to load form that is part of TIBCO® BPM Enterprise projects which are deployed to the BPM runtime.
```html preview
<div id="formContainer">
    <tibco-form formurl="./assets/bpm-forms/artefacts/FormsTutorialSolutions/ProcessPackage/ClaimsProcesswithForms/CaptureClaim/CaptureClaim.gwt.json"  initdataurl="./assets/bpm-forms/artefacts/FormsTutorialSolutions/ProcessPackage/ClaimsProcesswithForms/CaptureClaim/SampleInput.data.json" bomjspath="./assets/bpm-forms/artefacts/" locale="en-US" onSubmit="event.detail.form.getSerializedParameters((data) => console.log(data))"></tibco-form>
</div>
```

### JSON Form
Apart from the capability to render Forms designed in Business Studio, the tibco-form web component is capable of producing Forms from any arbitrary JSON.
It decides to provide an appropriate form field based on the data type of the attribute in the JSON. This default rendering can be further customized using a configuration object(web component attribute - json2formconfig).

e.g. <i>&lt;tibco-form json2form="true" json2formdata='{"name":"Jonathon Smith"}' json2formconfig='{}' <br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    onsubmit="event.detail.form.getSerializedParameters((data) => console.log(data))"&gt;&lt;/tibco-form&gt;</i>

For every object in the JSON, a singleton pane(layout) is created on the form. For every object array, a Grid, Record or Expandable Records pane is created.

The configuration object(web component attribute - json2formconfig) at the top level supports following properties:
 Likewise for attributes with a boolean value, a checkbox is created. For attributs with a number, a numeric control is created. For attribute with values of the format yyyy-MM-dd, a Date control is created. For attribute with values of the format HH:mm:ssZ, a Time control is created. For attribute with values of the format yyyy-MM-dd'T'HH:mm:ssZ, a DateTime control is created.

The top-level configuration for the generator can be found [here](#jsonformtoplevelconfiguration)

#### Text-only JSON Form
This example shows how to generate a text-only forms from JSON.

```html preview
<div id="jsonFormContainer">
    <tibco-form json2form="true" json2formdata='{"CustName": "Jonathon Smith", "CustPhone": "(650) 555-3229", "CustEmail": "jsmith@acme.com", "BirthDate": "1965-03-25", "ClaimAmount": 520.00, "AccTime": "2024-10-01T12:55:32+00:00", "AccDescription": "The other car stopped short, and... boom! I think I sprained my toe.", "PersInjury": "YES", "ThirdPInvolved": true, "WitAvailable": true, "ThirdPName": "Susan Jones", "InsurName": "Gecko", "InsurNumber": "A522-44509-93340", "ThirdPAmount": 322.00, "WitName": "Chris Johnson", "WitPhone": "(560) 555-4200"}'
	  			json2formconfig='{"textOnly": true, "showToolbar": false}' locale="en-US"></tibco-form>
</div>
```

#### Editable JSON Form
This example shows how you can render different editable forms from the same JSON by altering its configuration.

```html preview
<div class="row">
    <div id="jsonFormContainer2" class="column"></div>
    <div id="jsonFormContainer3" class="column"></div>
</div>
<script>
// Pass any JSON to get a form out of it
const anArbitraryJson = {
	"DealCapturingForm": {
		"Summary": {
			"DealNumber": "NW18976",
			"DealName": "Acme Corporation",
			"DealStartDate": "2024-10-01",
			"DealEndDate": "2024-10-21",
			"DealCode": "ACME_ACTIVE",
			"ProductNames": ["BPM", "BW"]
		},
		"Notes": [
			{"ShortLabel": "Meeting", "Comment": "Zoom meeting on 22nd Oct 2024\nMeeting link to be sent."},
            {"ShortLabel": "Meeting", "Comment": "Customer visit on 30th Oct 2024"}
		],
		"CorrespondanceDetails": [
			{"Name": "David Johnson", "Address1": "1234", "Address2": "Disneyland Park", "City": "Anaheim", "State": "California", "Country": "USA", "PinCode": "92802", "Mobile": "(560) 555-4200", "Email": "david@acme.com"},
            {"Name": "John Smith", "Address1": "1234", "Address2": "Disneyland Park", "City": "Anaheim", "State": "California", "Country": "USA", "PinCode": "92802", "Mobile": "(560) 555-4201", "Email": "john@acme.com"}
		]
	}
};
// Additional configuration if any for the form on the left
const json2FormConfig1 = {
    "root" : {
        "DealCapturingForm": {
            "_": {
                "label": "Deal Capturing Form (Default View)"
            },
            "CorrespondanceDetails": {
                "_": {
                    "propSetCollectionPaneSupportExportOperation": true
                }
            }
        }
    }
};
// Additional configuration if any for the form on the right
const json2FormConfig2 = {
    "_": {"tfLibrary": "mwc"},
    "root" : {
        "DealCapturingForm": {
            "_": {
                "label": "Deal Capturing Form (Angular Material View)"
            },
            "CorrespondanceDetails": {
                "_": {
                    "propSetCollectionPaneSupportExportOperation": true
                }
            }
        }
    }
};

let markup1 = `
    <tibco-form json2form="true" json2formdata='${JSON.stringify(anArbitraryJson)}'
            json2formconfig='${JSON.stringify(json2FormConfig1)}' locale="en-US"></tibco-form>
`;

let markup2 = `
    <tibco-form json2form="true" json2formdata='${JSON.stringify(anArbitraryJson)}'
            json2formconfig='${JSON.stringify(json2FormConfig2)}' locale="en-US"></tibco-form>
`;


document.getElementById("jsonFormContainer2").innerHTML = markup1;
document.getElementById("jsonFormContainer3").innerHTML = markup2;
</script>
<style>
    .row {
        display: flex;
        column-gap: 8px;
    }
    .column {
        flex: 50%;
        overflow: auto;
        border-width: 1px;
        border-style: solid;
        border-color: var(--tib-semantic-color-border-neutral-emphasis);
    }
</style>
```

This example shows how you can render the same JSON using a different layout(tabbed in this case).

```html preview
<div class="row">
    <div id="jsonFormContainer4" class="column"></div>
    <div id="jsonFormContainer5" class="column"></div>
</div>
<script>
// Pass any JSON to get a form out of it
const anArbitraryJson = {
	"DealCapturingForm": {
		"Summary": {
			"DealNumber": "NW18976",
			"DealName": "Acme Corporation",
			"DealStartDate": "2024-10-01",
			"DealEndDate": "2024-10-21",
			"DealCode": "ACME_ACTIVE",
			"ProductNames": ["BPM", "BW"]
		},
		"Notes": [
			{"ShortLabel": "Meeting", "Comment": "Zoom meeting on 22nd Oct 2024\nMeeting link to be sent."},
            {"ShortLabel": "Meeting", "Comment": "Customer visit on 30th Oct 2024"}
		],
		"CorrespondanceDetails": [
			{"Name": "David Johnson", "Address1": "1234", "Address2": "Disneyland Park", "City": "Anaheim", "State": "California", "Country": "USA", "PinCode": "92802", "Mobile": "(560) 555-4200", "Email": "david@acme.com"},
            {"Name": "John Smith", "Address1": "1234", "Address2": "Disneyland Park", "City": "Anaheim", "State": "California", "Country": "USA", "PinCode": "92802", "Mobile": "(560) 555-4201", "Email": "john@acme.com"}
		]
	}
};
// Additional configuration if any for the form on the left
const json2FormConfig1 = {
    "root" : {
        "DealCapturingForm": {
            "_": {
                "label": "Deal Capturing Form (Default View)",
                "componentType": "com.tibco.forms.panes.tabbed"
            },
            "CorrespondanceDetails": {
                "_": {
                    "propSetCollectionPaneSupportExportOperation": true
                }
            }
        }
    }
};
// Additional configuration if any for the form on the right
const json2FormConfig2 = {
    "_": {"tfLibrary": "mwc"},
    "root" : {
        "DealCapturingForm": {
            "_": {
                "label": "Deal Capturing Form (Angular Material View)",
                "componentType": "com.tibco.forms.panes.tabbed"
            },
            "CorrespondanceDetails": {
                "_": {
                    "propSetCollectionPaneSupportExportOperation": true
                }
            }
        }
    }
};

let markup1 = `
    <tibco-form json2form="true" json2formdata='${JSON.stringify(anArbitraryJson)}'
            json2formconfig='${JSON.stringify(json2FormConfig1)}' locale="en-US"></tibco-form>
`;

let markup2 = `
    <tibco-form json2form="true" json2formdata='${JSON.stringify(anArbitraryJson)}'
            json2formconfig='${JSON.stringify(json2FormConfig2)}' locale="en-US"></tibco-form>
`;


document.getElementById("jsonFormContainer4").innerHTML = markup1;
document.getElementById("jsonFormContainer5").innerHTML = markup2;
</script>
```

[component-metadata:tibco-form]
