/*
 * $Id$
 * Date: $Date$
 *
 * Copyright (c) 2009-2024. Cloud Software Group, Inc. All Rights Reserved. Confidential & Proprietary.
 */

if (typeof (tibcoforms) == 'undefined')
    tibcoforms = new Object();

tibcoforms.FormProxy = function(jsForm) {
	if (tibcoforms.bridge.log_isDebugEnabled() == true)
        tibcoforms.bridge.log_debug("Form proxy 11.6.0.015.ACE20241021_1917");
    this.id = jsForm.formInstanceId;
    // this.name = jsForm.name;
    this.jsForm = jsForm;
    // for each class loaded via the loader, this will be incremented by one and once the loading is complete, decrements by one
    this.bomJSClassesLoadCount = 0;
    this.f = new Array();
    this.p = new Array();
    this.pn = new Array();
    this.resource = new Object();
    this.initialize();
};

tibcoforms.FormProxy.prototype.initialize = function() {
    this.dataMap = new Object();
    this.dataList = new Array();
    this.controlMap = new Object();
    this.controlList = new Array();
    this.paneMap = new Object();
    this.paneList = new Array();
    this.rootPaneList = new Array();
    /**
     * This is the context object for JavaScript factory classes.
     */
    this._factory = new Object();
    /**
     * This is the context object for java script package classes.
     */
    this._package = new Object();
    this.initParameters(this.jsForm.data);
    if(this.jsForm.controlRefs != undefined)
        this.initControls(this.jsForm.controlRefs);
    this.initPanes(this.jsForm.pane, this.jsForm.rootPaneRefs);

    // associative array. key = item, value = publish subject
    this._registry = new Object();
};

tibcoforms.FormProxy.prototype.initParameters = function(refs) {
	// null check for the cases of form generated by the new designer
	if (refs) {
	    for ( var i = 0; i < refs.length; i++) {
	        var data = new tibcoforms.ParameterProxy(this, refs[i].name);
	        var unpName = refs[i].name.substring(5);
	        this.dataMap[unpName] = data;
	        this.p[unpName] = null;
	        this.dataList[i] = data;
	    }
    }
};

tibcoforms.FormProxy.prototype.initPanes = function(refs, rootPanes) {
    if(refs != undefined) {
        for ( var i = 0; i < refs.length; i++) {
            var pane = new tibcoforms.PaneProxy(this, refs[i], "");
            var unpName = refs[i].name.substring(5);
            this.paneMap[unpName] = pane;
            this.pn[unpName] = null;
            this.paneList[i] = pane;
        }
    }
    if(rootPanes != undefined) {
        for ( var i = 0; i < rootPanes.length; i++) {
            var pane = this.paneMap[rootPanes[i].name.substring(5)];
            this.rootPaneList[i] = pane;
        }
    }
};

tibcoforms.FormProxy.prototype.initControls = function(refs) {
    for ( var i = 0; i < refs.length; i++) {
        var control = new tibcoforms.ControlProxy(this, refs[i].name, refs[i], "");
        var unpName = refs[i].name.substring(8);
        this.controlMap[unpName] = control;
        this.f[unpName] = null;
        this.controlList[i] = control;
    }
};

tibcoforms.FormProxy.prototype.getElement = function() {
    return tibcoforms.bridge.form_getElement(this.id);
};

tibcoforms.FormProxy.prototype.destroy = function() {
    return tibcoforms.bridge.form_destroy(this.id);
};

tibcoforms.FormProxy.prototype.getControl = function(name) {
    return this.controlMap[name];
};

tibcoforms.FormProxy.prototype.getPane = function(name) {
    return this.paneMap[name];
};

tibcoforms.FormProxy.prototype.getParameterValue = function(name) {
    return this.dataMap[name].value;
};

tibcoforms.FormProxy.prototype.setParameterValue = function(name, value) {
	// context.form.setParameterValue() calls in FormsTutorialSolutions/ProcessPackage/ClaimsProcesswithForms/InterviewWitness threw error hence
    this.dataMap[name].value = value;
};

/**
 * This method gets called when locale specific resource are loaded explicitly. This happens during a setLocale() API call. When all
 * the resources are loaded need to notify the form.
 * @since 2.2.0
 */
tibcoforms.FormProxy.prototype.onExplictResourceBundleLoad = function() {
    if (tibcoforms.bridge.log_isDebugEnabled() == true)
        tibcoforms.bridge.log_debug('FormProxy: onExplictResourceBundleLoad: this.jsForm.resourceBundleLoaded: '
            + this.jsForm.resourceBundleLoaded + ', this.jsForm.customCompTypeRescBundles: ' + this.jsForm.customCompTypeRescBundles);
    if (this.jsForm.resourceBundleLoaded == 0 && this.jsForm.customCompTypeRescBundles == 0)
        tibcoforms.bridge.form_onResourceBundleReload(this.id);
    else
        tibcoforms.bridge.log_trace('FormProxy: onExplictResourceBundleLoad: Waiting to complete loading of ('
            + this.jsForm.resourceBundleLoaded  + ', ' + this.jsForm.customCompTypeRescBundles + ') bundles.');
};

tibcoforms.FormProxy.prototype.validate = function(updateMessagePane) {
    return tibcoforms.bridge.form_validate(this.id, updateMessagePane);
};

tibcoforms.FormProxy.prototype.invokeAction = function(actionName, contextObject, context) {
    try {
        var object = new Object();
        object.thisObj = contextObject == null || contextObject == 'undefined' ? null : contextObject;
        object.context = context == null || context == 'undefined' ? null : context;
        tibcoforms.bridge.form_invokeAction(this.id, actionName, object);
    } catch (e) {
        tibcoforms.bridge.log_error("ERR_FORMPROXY_INVOKEACTION: Error invoking action " + actionName + " : " + e);
        throw e;
    }
};

tibcoforms.FormProxy.prototype.log = function(message) {
    tibcoforms.bridge.form_log(this.id, message);
};

tibcoforms.FormProxy.prototype.getLoadStats = function(callback) {
	var loadStats = tibcoforms.bridge.form_getLoadTimeStats(this.id);
	// forms 4.1.0: iframe integration
	if (callback) {
		setTimeout(function() {
			callback(loadStats);
		}, 10);
	}
    return loadStats;
};

tibcoforms.FormProxy.prototype.stringEndsWith = function(str1, str2) {
    if (str1.lastIndexOf(str2) == (str1.length - str2.length)) {
        return true;
    }
    return false;
};

/**
 * Returns a property name with which to register the specified BOM JavaScript class. The method strips the specified suffix and
 * replaces all dot characters with underscores.
 * @param jsClassName A JavaScript class name.
 * @param suffix The suffix to test for.
 */
tibcoforms.FormProxy.prototype.getJSPropertyName = function(jsClassName, suffix) {
    var propertyName;
    var index = jsClassName.lastIndexOf(suffix);
    if (index == -1) {
        propertyName = null;
    } else {
        index = jsClassName.lastIndexOf(".", index);
        propertyName = jsClassName.substring(0, index).replace(/\./g, "_");
    }
    return propertyName;
};

/**
 * IMPORTANT: Adding this method back so that the runtime is backward compatible with the form PSMs generated in 2.1.0. From 2.1.1,
 * this method is not used, but just here for backward compatibility. Loads the factory classes provided in the array input.
 * @param factories - array of Strings for JavaScript factory and package classes.
 */
tibcoforms.FormProxy.prototype.registerFactoryClasses = function(factories) {
    if ($wnd.tibcoforms.bridge.log_isTraceEnabled() == true)
        tibcoforms.bridge.log_trace("tibcoforms.FormProxy.prototype.registerFactoryClasses");
    for ( var i = 0; i < factories.length; i++) {
        var className = factories[i];
        if (this.stringEndsWith(className, "Factory")) {
            var index = className.lastIndexOf("Factory");
            index = className.lastIndexOf(".", index);
            var modClassName = className.substring(0, index);
            modClassName = modClassName.replace(/\./g, "_");
            var classInstance = null;
            classInstance = this._loader.newInstance(className, this, false);
            this._factory[modClassName] = classInstance;
        } else if (this.stringEndsWith(className, "Package")) {
            var index = className.lastIndexOf("Package");
            index = className.lastIndexOf(".", index);
            var modClassName = className.substring(0, index);
            modClassName = modClassName.replace(/\./g, "_");
            var classInstance = null;
            classInstance = this._loader.getClass(className);
            this._package[modClassName] = classInstance;
        }
    }
    /**
     * Obtain a new instance of a Duration.
     * @param isPositive true if this is a positive Duration.
     * @param years number of years in the duration
     * @param months number of months
     * @param days number of days
     * @param hours number of hours
     * @param minutes number of minutes
     * @param seconds number of seconds
     */
    if (typeof (this._factory.DateTimeUtil) == 'undefined')
        this._factory.DateTimeUtil = new Object();
    if (typeof (this._factory.DateTimeUtil.createDuration) == 'undefined') {
        this._factory.DateTimeUtil.createDuration = function(isPositive, years, months, days, hours, minutes, seconds) {
            var duration = new Duration("");
            duration.setIsNegative(!isPositive);
            duration.setYears(years);
            duration.setMonths(months);
            duration.setDays(days);
            duration.setHours(hours);
            duration.setMinutes(minutes);
            duration.setSeconds(seconds);
            return duration;
        };
    }
};

/**
 * Registers the BOM factory classes.
 * @param factories An array of BOM JavaScript factory class names.
 */
tibcoforms.FormProxy.prototype.registerFactories = function(factories) {
    for ( var i = 0; i < factories.length; i++) {
        var jsClassName = factories[i];
        var propertyName = this.getJSPropertyName(jsClassName, "Factory");
        if (propertyName != null)
            this._factory[propertyName] = this._loader.newInstance(jsClassName, this, false);
    }

    /**
     * Obtain a new instance of a Duration.
     * @param isPositive true if this is a positive Duration.
     * @param years number of years in the duration
     * @param months number of months
     * @param days number of days
     * @param hours number of hours
     * @param minutes number of minutes
     * @param seconds number of seconds
     */
    if (typeof (this._factory.DateTimeUtil) == 'undefined')
        this._factory.DateTimeUtil = new Object();
    if (typeof (this._factory.DateTimeUtil.createDuration) == 'undefined') {
        this._factory.DateTimeUtil.createDuration = function(isPositive, years, months, days, hours, minutes, seconds) {
            var duration = new Duration("");
            duration.setIsNegative(!isPositive);
            duration.setYears(years);
            duration.setMonths(months);
            duration.setDays(days);
            duration.setHours(hours);
            duration.setMinutes(minutes);
            duration.setSeconds(seconds);
            return duration;
        };
    }
};

/**
 * Registers the BOM package classes.
 * @param packages An array of BOM JavaScript package class names.
 */
tibcoforms.FormProxy.prototype.registerPackages = function(packages) {
    for ( var i = 0; i < packages.length; i++) {
        var jsClassName = packages[i];
        var propertyName = this.getJSPropertyName(jsClassName, "Package");
        if (propertyName != null)
            this._package[propertyName] = this._loader.getClass(jsClassName);
    }
};

tibcoforms.FormProxy.prototype.getLogger = function() {
    return tibcoforms.bridge.log_logger_instance;
};

tibcoforms.FormProxy.prototype.dataStoreRecognizedPrimType = function(umlType) {
    return tibcoforms.FormProxy.convertToDataStoreRecognizedPrimType(umlType);
};

tibcoforms.FormProxy.prototype.getInternalType = function(param) {
    return tibcoforms.bridge.param_getInOut(this.id, param.name);
};

/**
 * Returns the value for the complex attribute List of wrapper objects for the multiValued attribute or a single wrapper object for
 * the single valued attribute
 */
tibcoforms.FormProxy.prototype.getComplexAttributeValue = function(wrapperObj, complexAttribute) {
    var wrapperClass = wrapperObj.getClass();
    var attrValue = null;
    if (tibcoforms.bridge.log_isTraceEnabled() == true)
        tibcoforms.bridge.log_trace('FormProxy: getComplexAttributeValue: complexAttribute: ' + complexAttribute
            + ', isAttributeMultivalued: ' + wrapperClass._isAttributeMultivalued(complexAttribute));
    if (wrapperClass._isAttributeMultivalued(complexAttribute)) {
        attrValue = wrapperObj._getComplexArrayAttribute(complexAttribute);
    } else {
        attrValue = wrapperObj._getComplexAttribute(complexAttribute);
    }
    return attrValue;
};

/**
 * Returns true if given attribute is a primitive attribute in the wrapper object.
 */
tibcoforms.FormProxy.prototype.isPrimitiveAttribute = function(wrapperObj, attribute) {
    var wrapperClass = wrapperObj.getClass();
    var primAttributes = wrapperClass._getPrimitiveAttributes();

    for ( var j = 0; j < primAttributes.length; j++) {
        if (primAttributes[j] == attribute) {
            return true;
        }
    }
    return false;
};

/**
 * Returns true if given attribute is a complex attribute in the wrapper object.
 */
tibcoforms.FormProxy.prototype.isComplexAttribute = function(wrapperObj, attribute) {
    if (this.isPrimitiveAttribute(wrapperObj, attribute)) {
        return false;
    }
    var wrapperClass = wrapperObj.getClass();
    if (wrapperClass._hasAttribute(attribute)) {
        return true;
    }
    return false;
};

/**
 * Returns true if there is an object defined for the given classname path.
 */
tibcoforms.FormProxy.prototype.isDefined = function(className) {
    /*
     * if (className == null) return false; className = className.toString(); var levels = className.split("."); var check =
     * levels[0]; for (var k = 0; k < levels.length; k++) { if (eval("typeof " + check + "=='undefined';")) { return false; } if (k <
     * levels.length - 1) check += "." + levels[k + 1]; }
     */
    return true;
};

tibcoforms.FormProxy.prototype.createNewObject = function(item, dataStore, type, logger, id, initSimpleAttrsOfCO) {
    return this.createNewObject(item, dataStore, type, logger, id, false, initSimpleAttrsOfCO);
};

tibcoforms.FormProxy.prototype.createNewObject = function(item, dataStore, type, logger, id, isCreatingProxy, initSimpleAttrsOfCO) {
    if (isCreatingProxy == false && (tibcoforms.bridge.log_isDebugEnabled() == true))
        tibcoforms.bridge.log_debug("FormProxy: createNewObject: " + item + "," + dataStore + "," + type + ", " + id);
    // dojo datastore is very old and removed years back!!
    // when type is null, it should be reported
    // if (type == null)
    //     type = dataStore.getValue(item, "$type");
    if (typeof (type) != 'undefined' && type != null) {
        tibcoforms.bridge.log_trace("FormProxy: createNewObject: Creating object of type: " + type);
        var instance = null;
        if (this.isDefined(type)) {
            var context = {
                item : item,
                dataStore : dataStore,
                logger : logger,
                id : id,
                form : this
            };
            // eval("instance = new com.tibco.data.Loader.classDefs['" + type + "'](context);");
            instance = this._loader.newInstanceInternal(type, context, initSimpleAttrsOfCO);
            return instance;
        } else {
            tibcoforms.bridge.log_error("FormProxy: createNewObject: Could not find javascript class for type: " + type);
            return null;
        }
    } else {
        tibcoforms.bridge.log_error("FormProxy: createNewObject: No type information provided for item: " + item);
        return null;
    }
};

tibcoforms.FormProxy.prototype.loader = function() {
    // return new com.tibco.data.Loader({objServer:null, rootPath:null, logger:tibcoforms.bridge.log_logger()});
    // _loader is set by the FormImpl when loading the BOM JS resource
    return this._loader;
};

/**
 * Static method that sets the attribute value of a complex object.
 * @param jsCO The overlay object of the complex object.
 * @param attName The attribute name whose value to be set.
 * @param value The value.
 */
tibcoforms.FormProxy.setComplexObjectComplexAttributeValue = function(jsCO, attName, value) {
    var jsCONativeObject = jsCO.nativeObject == null ? jsCO : jsCO.nativeObject;
    if (tibcoforms.bridge.complexObj_getArray(jsCONativeObject, attName)) {
        var v2 = new Array();
        for ( var i = 0; i < value.size(); i++) {
            var v3 = value.get(i);
            if (v3.nativeObject != null && v3.nativeObject != 'undefined')
                v3 = v3.nativeObject;
            v2[i] = v3;
        }
        tibcoforms.bridge.complexObj_setComplexAttributeArray(jsCONativeObject, attName, v2);
        var v1 = tibcoforms.bridge.complexObj_getComplexAttributeArray(jsCONativeObject, attName);
        for ( var i = 0; i < v1.length; i++) {
            value.get(i).nativeObject = v1[i];
        }
    } else {
        tibcoforms.bridge.complexObj_setComplexAttribute(jsCONativeObject, attName, value.nativeObject != null
            && value.nativeObject != 'undefined' ? value.nativeObject : value);
        var v1 = tibcoforms.bridge.complexObj_getComplexAttribute(jsCONativeObject, attName);
        if (v1 != null)
            value.nativeObject = v1;
    }
};

tibcoforms.ParameterProxy = function(form, name) {
    this.form = form;
    this.name = name;
    this.unpName = this.name.substring(5);
};

tibcoforms.ParameterProxy.prototype.getArray = function() {
    return tibcoforms.bridge.param_getArray(this.form.id, this.name);
};

tibcoforms.ParameterProxy.prototype.getPrimitive = function() {
    return tibcoforms.bridge.param_getPrimitive(this.form.id, this.name);
};

tibcoforms.PaneProxy = function(form, jsPane, cloneUID) {
    this.form = form;
    this.jsBindable = jsPane;
    this.jsPane = jsPane;
    // this.name = jsPane.name;
    this.unpName = jsPane.name.substring(5);
    this.cloneUID = cloneUID;
    this.initialize();
};

tibcoforms.PaneProxy.prototype.destroy = function() {
	if (this.cloneMap) {
        for (var name in this.cloneMap) {
        	this.cloneMap[name].destroy();
        	delete this.cloneMap[name];
        }
        delete this.cloneMap;
	}
	for (var name in this.jsPane)
    	delete this.jsPane[name];
	for (var name in this)
    	delete this[name];
};

tibcoforms.PaneProxy.prototype._getProxy = function(cloneUID) {
    if (cloneUID && (cloneUID != '')) {
        var clone = this.cloneMap[cloneUID];
        if (!clone) {
            clone = new tibcoforms.PaneProxy(this.form, this.jsPane, cloneUID);
            this.cloneMap[cloneUID] = clone;
        }
        return clone;
    } else
        return this;
};

tibcoforms.PaneProxy.prototype.initialize = function() {
    this.cloneMap = new Object();
    this.paneList = new Array();
    this.controlList = new Array();
    // new designer uses the 'group' attribute, hence this change
    var refs = "group" in this.jsPane ? this.jsPane.group : this.jsPane.children;
    for ( var i = 0; i < refs.length; i++) {
        if (refs[i].type == 'pane') {
            var pane = this.form.paneMap[refs[i].name.substring(5)];
            this.paneList[this.paneList.length] = pane;
        } else if (refs[i].type == 'control') {
            var control = this.form.controlMap[refs[i].name.substring(8)];
            this.controlList[this.controlList.length] = control;
        }
    }
};

tibcoforms.PaneProxy.prototype.getForm = function() {
    return this.form;
};

tibcoforms.PaneProxy.prototype.validate = function(updateMessagePane) {
    return tibcoforms.bridge.pane_validate(this.form.id, this.jsPane.name, this.cloneUID, updateMessagePane);
};

tibcoforms.ControlProxy = function(form, name, jsControl, cloneUID) {
    this.form = form;
    // this.name = name;
    this.unpName = jsControl.name.substring(8);
    this.jsBindable = jsControl;
    this.jsControl = jsControl;
    this.cloneUID = cloneUID;
    this.cloneMap = new Object();
};

tibcoforms.ControlProxy.prototype.destroy = function() {
	if (this.cloneMap) {
        for (var name in this.cloneMap) {
        	this.cloneMap[name].destroy();
        	delete this.cloneMap[name];
        }
        delete this.cloneMap;
	}
	for (var name in this.jsControl)
    	delete this.jsControl[name];
	for (var name in this)
    	delete this[name];
};

tibcoforms.ControlProxy.prototype._getProxy = function(cloneUID) {
    if (cloneUID && (cloneUID != '')) {
        var clone = this.cloneMap[cloneUID];
        if (!clone) {
            clone = new tibcoforms.ControlProxy(this.form, this.jsControl.name, this.jsControl, cloneUID);
            this.cloneMap[cloneUID] = clone;
        }
        return clone;
    } else
        return this;
};

tibcoforms.ControlProxy.prototype.getName = function() {
    return this.jsControl.name.substring(8);
};

tibcoforms.ControlProxy.prototype.getForm = function() {
    return this.form;
};

tibcoforms.ControlProxy.prototype.validate = function(updateMessagePane) {
    return tibcoforms.bridge.control_validate(this.form.id, this.jsControl.name, this.cloneUID, updateMessagePane);
};

tibcoforms.ControlProxy.prototype.setOptions = function(values, labels) {
    return tibcoforms.bridge.control_setOptions(this.form.id, this.jsControl.name, this.cloneUID, values, labels);
};

/**
 * @since 2.2.3
 */
tibcoforms.ControlProxy.prototype.setFocus = function() {
    return tibcoforms.bridge.control_setFocus(this.form.id, this.jsControl.name, this.cloneUID, true);
};
// --------------------------------------------------------------------------------------------------------------------//
// FormProxy static utility functions. //
// --------------------------------------------------------------------------------------------------------------------//
/**
 * Converts a UML/BOM JavaScript attribute type to a data store accepted type.
 * @param type The type.
 * @return The data store accepted type name.
 */
tibcoforms.FormProxy.convertToDataStoreRecognizedPrimType = function(type) {
    return tibcoforms.util.convertToDataStoreRecognizedPrimType(type);
};

/**
 * Creates a new Array. An array is created in JSNI using this call as otherwise the array is not recognized as a JS array in
 * Safari.
 * @returns A new Array.
 * @since 2.2.0
 */
tibcoforms.FormProxy.newArray = function() {
    return new Array();
};

/**
 * Decodes the special characters encoded in the url. Moved from ClientAPIUtil to here to workaround a GWT bug:
 * http://code.google.com/p/google-web-toolkit/issues/detail?id=6409
 * @param url The url.
 * @return The decoded url.
 * @since 2.2.2
 */
tibcoforms.FormProxy.urlDecode = function(url) {
    var newUrl = url.replace('%3A', ':');
    newUrl = newUrl.replace('%2F', '/');
    newUrl = newUrl.replace('%26', '&');
    newUrl = newUrl.replace('%3D', '=');
    newUrl = newUrl.replace('%3F', '?');
    return newUrl;
};

/**
 * Note: do not move this to gwt layer even as native code due to window scoping issues.
 * An error handler to capture window errors on IE.
 * @param message Text-based error description.
 * @param url URL which exhibited the script error.
 * @param line The line number being executed when the error occurred.
 * @returns {Boolean}
 * @since 3.0.0
 */
tibcoforms.FormProxy.windowErrorHandler = function(message, url, line) {
	// handle the error here
	var logEnabled = false;
    if (tibcoforms)
        if (tibcoforms.bridge)
            if (tibcoforms.bridge.log_error)
                logEnabled = true;
    var customMsg = "ERR_20101: " + message + "\r\nurl: "  + url + "\r\nline: " + line;
    if (logEnabled)
        tibcoforms.bridge.log_error(customMsg);
    else
        alert(customMsg);

 	// stop the event from bubbling up to the default window.onerror handler
    return true;
};

/**
 * @since 5.1.0
 */
tibcoforms.FormProxy.camelToKebabCase = function(str) {
	return str.replace(/[A-Z]/g, m => "-" + m.toLowerCase());
}

/**
 * @since 5.6.0
 */
tibcoforms.FormProxy.loadFontFaceCSSForShadowDOMUseCases = function(moduleBase) {
	let fonts = `
		@font-face {
		    font-family: "Glyphicons Halflings";
		    src: url("${moduleBase}fonts/glyphicons-halflings-regular.eot");
		    src: url("${moduleBase}fonts/glyphicons-halflings-regular.eot?#iefix") format("embedded-opentype"), url("${moduleBase}fonts/glyphicons-halflings-regular.woff2") format("woff2"), url("${moduleBase}fonts/glyphicons-halflings-regular.woff") format("woff"), url("${moduleBase}fonts/glyphicons-halflings-regular.ttf") format("truetype"), url("${moduleBase}fonts/glyphicons-halflings-regular.svg#glyphicons_halflingsregular") format("svg");
		}
		@font-face {
		    font-family: "av45";
		    font-style: normal;
		    font-weight: normal;
		    src: url("${moduleBase}fonts/avenirltstd-book-webfont.eot?#iefix") format("embedded-opentype"), url("${moduleBase}fonts/avenirltstd-book-webfont.woff") format("woff"), url("${moduleBase}fonts/avenirltstd-book-webfont.ttf") format("truetype"), url("${moduleBase}fonts/avenirltstd-book-webfont.svg#av45") format("svg");
		}
		@font-face {
		    font-family: "av65";
		    font-style: normal;
		    font-weight: normal;
		    src: url("${moduleBase}fonts/avenirltstd-medium-webfont.eot?#iefix") format("embedded-opentype"), url("${moduleBase}fonts/avenirltstd-medium-webfont.woff") format("woff"), url("${moduleBase}fonts/avenirltstd-medium-webfont.ttf") format("truetype"), url("${moduleBase}fonts/avenirltstd-medium-webfont.svg#av65") format("svg");
		}
		@font-face {
		    font-family: "av85";
		    font-style: normal;
		    font-weight: normal;
		    src: url("${moduleBase}fonts/avenirltstd-heavy-webfont.eot?#iefix") format("embedded-opentype"), url("${moduleBase}fonts/avenirltstd-heavy-webfont.woff") format("woff"), url("${moduleBase}fonts/avenirltstd-heavy-webfont.ttf") format("truetype"), url("${moduleBase}fonts/avenirltstd-heavy-webfont.svg#av85") format("svg");
		}
		@font-face {
		  font-family: 'FontAwesome';
		  src: url('${moduleBase}fonts/fontawesome-webfont.eot?v=4.1.0');
		  src: url('${moduleBase}fonts/fontawesome-webfont.eot?#iefix&v=4.1.0') format('embedded-opentype'), url('${moduleBase}fonts/fontawesome-webfont.woff?v=4.1.0') format('woff'), url('${moduleBase}fonts/fontawesome-webfont.ttf?v=4.1.0') format('truetype'), url('${moduleBase}fonts/fontawesome-webfont.svg?v=4.1.0#fontawesomeregular') format('svg');
		  font-weight: normal;
		  font-style: normal;
		}
    `;
	return fonts;
}

/**
 * Note: do not move this to gwt layer even as native code due to window scoping issues.
 * @since 3.0.0
 */
tibcoforms.FormProxy.registerWindowErrorHandler = function() {
	// install the global error-handler
    window.onerror = tibcoforms.FormProxy.windowErrorHandler;
};

/**
 * Note: do not move this to gwt layer even as native code due to window scoping issues.
 * Validation util method used for inline validations.
 * @since 3.0.0
 */
tibcoforms.FormProxy.handleInlineValidation = function(context, form, logger, data, pane, control, factory, pkg, f, p, resource, validationScript, validationName) {
	try {
        return eval(validationScript);
    } catch(e) {
        tibcoforms.bridge.log_error("ERR_20102: Validation(" + (this.getName ? (this.getName() + ": ") : "") + validationName + ") Script Error: " + e + ", for script: " + validationScript);
        throw e;
    }
};

/**
 * Exports the form as a web component.
 * @since ACE Forms 1.0.0
 */
tibcoforms.FormProxy.exportAsWebComponent =  function() {
	class TibcoFormsElement extends HTMLElement {
		static get observedAttributes() {
			return tibcoforms.bridge.form_wcObservedAttrs();
		}

		constructor() {
			// inherit everything from HTMLElement
		    super();
		}

		connectedCallback() {
			this.showLoadingIndicator();
			// @see FormBrige.webComponentLoad()
			this.__$$__cd = true;
			tibcoforms.bridge.form_wcload.call(this);
		}

		disconnectedCallback() {
			// Element removed from the document
			tibcoforms.bridge.form_wcunload.call(this);
		}
		
		showLoadingIndicator() {
			// if a form is already loaded inside, do not show loading indiactor
			if (!this.liShown && (!this.children || (this.children.length == 0))) {
				this.innerHTML = `<tibco-form-loading></tibco-form-loading>`;
				this.liShown = true;
			}
		}

		attributeChangedCallback(attributeName, oldValue, newValue) {
			if (tibcoforms.bridge.log_isTraceEnabled() == true)
			    tibcoforms.bridge.log_trace("FormProxy: exportAsWebComponent: attributeChangedCallback: attributeName: "
			    + attributeName + ", oldValue: " + oldValue + ", newValue: " + newValue);
			this.showLoadingIndicator();
			tibcoforms.bridge.form_wcAttrChangedCallback.call(this, attributeName, oldValue, newValue);
		}

		adoptedCallback(oldDocument, newDocument) {
        	// Called when the element is adopted into a new document
    	}
	}
	class TibcoFormsLoadingIndicatorElement extends HTMLElement {
		static get observedAttributes() {
			return [];
		}

		constructor() {
			// inherit everything from HTMLElement
		    super();
		    this.attachShadow({mode: 'open'});
		}

		connectedCallback() {
		    this.shadowRoot.innerHTML = `
			    <style>
			    	//Styles for skeleton wrapper(loader)
					.skeleton-wrapper {
					  display: block;
					  position: relative;
					  width: 100%;
					}
					
					.skeleton {
					  display: flex;
					  width: 100%;
					  height: 100%;
					  min-height: 1rem;
					}
					
					.skeleton__indicator {
					  flex: 1 1 auto;
					  background: var(--color-tibco-slate-200, #E9E9E9);
					  border-radius: 9999px;
					}
					
					.skeleton--pulse .skeleton__indicator {
					  animation: pulse 2s ease-in-out 0.5s infinite;
					}
					
					@keyframes pulse {
					  0% {
					    opacity: 1;
					  }
					  50% {
					    opacity: 0.4;
					  }
					  100% {
					    opacity: 1;
					  }
					}
					.skeleton-wrapper .skeleton-card {
					  margin-bottom: 1rem;
					}
					.skeleton-wrapper .skeleton-card:nth-child(2) {
					  width: 95%;
					}
					.skeleton-wrapper .skeleton-card:nth-child(4) {
					  width: 90%;
					}
					.skeleton-wrapper .skeleton-card:last-child {
					  width: 90%;
					}
				</style>
				
				<div class="skeleton-wrapper" style="width: 60vw;">
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		          <div
		            part="base"
		            class="skeleton skeleton--pulse skeleton-card"
		            aria-busy="true"
		            aria-live="polite"
		          >
		            <div part="indicator" class="skeleton__indicator"></div>
		          </div>
		        </div>
		    `;
		}

		disconnectedCallback() {
		}

		attributeChangedCallback(attributeName, oldValue, newValue) {
			if (tibcoforms.bridge.log_isTraceEnabled() == true)
			    tibcoforms.bridge.log_trace("FormProxy: TibcoFormsLoadingIndicatorElement: attributeChangedCallback: attributeName: "
			    + attributeName + ", oldValue: " + oldValue + ", newValue: " + newValue);
		}

		adoptedCallback(oldDocument, newDocument) {
        	// Called when the element is adopted into a new document
    	}
	}
	// define the element so it can be used in our HTML page
	// The name of the element has to have a hyphen in the middle, but could be named pretty much anything
	if (customElements) {
		customElements.define('tibco-form', TibcoFormsElement);
		customElements.define('tibco-form-loading', TibcoFormsLoadingIndicatorElement);
	} else
		tibcoforms.bridge.log_error("ERR_20103: Your browser does not support custom elements.");
}
