/*
 * Copyright (c) 2020-2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialDatepicker) == 'undefined') {
	tibcoforms.library.components.ng.MaterialDatepicker = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialDatepicker;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matDatepicker = this.createMaterialDatepicker();
        this.component.parentNode.appendChild(this.matDatepicker);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialDatepicker: refresh: " + updates);
        if (updates == null) return;
        var control = this.component.control;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matDatepicker.value))) {
        	this.matDatepicker.value = this.component.value;
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matDatepicker.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matDatepicker.setAttribute("enabled", this.component.control.reallyEnabled) && !this.component.control.reallyReadOnly;
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matDatepicker.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matDatepicker.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("mwcPlaceholder")) {
        	this.matDatepicker.placeholder = this.component.control.mwcPlaceholder;
        }
        if (updates.includes("mwcAppearance")) {        
        	this.matDatepicker.appearance = this.component.control.mwcAppearance;
        }
        if (updates.includes("validation")) {
        	this.matDatepicker.hasError = JSON.stringify(!this.component.control.valid);
        	this.matDatepicker.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
		if (typeof(event.detail) == 'string') {
			this.component.raiseEvent("update", event.detail);
    	} else if (event.detail != this.component.control.value) {
    		this.component.raiseEvent("update", bpm.forms.Util.formatDate("yyyy-MM-dd", event.detail));
    	}
    }

    wrapper.prototype.createMaterialDatepicker = function() {
    	var matDatepicker = document.createElement("tf-ng-material-datepicker");
    	matDatepicker.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matDatepicker.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matDatepicker.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matDatepicker.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matDatepicker.setAttribute("required", this.component.control.required);
    	if (this.component.control.value)
    		matDatepicker.value = this.component.control.value;
    	if(this.component && this.component.propSetPlaceholder){        
			matDatepicker.setAttribute('placeholder', this.component.propSetPlaceholder);
		}
    	if(this.component.control && this.component.control.mwcPlaceholder){        
        	matDatepicker.setAttribute('placeholder', this.component.control.mwcPlaceholder);
        }
        if(this.component && this.component.propSetAppearance){        
			matDatepicker.setAttribute('appearance', this.component.propSetAppearance);
		}
        if(this.component.control && this.component.control.mwcAppearance){        
        	matDatepicker.setAttribute('appearance', this.component.control.mwcAppearance);
        }
		// when it is overriding a builtin control
		if ((typeof(this.component.propSetYearMin) == 'string') || (typeof(this.component.propSetYearMin) == 'number')) {
        	matDatepicker.setAttribute('startyear', this.component.propSetYearMin);
        }
		// when it is overriding a builtin control
		if (typeof(this.component.propSetMinRelative) == 'boolean') {
        	matDatepicker.setAttribute('startyearrelative', this.component.propSetMinRelative);
        }
		// when it is overriding a builtin control
		if ((typeof(this.component.propSetYearMax) == 'string') || (typeof(this.component.propSetYearMax) == 'number')) {
        	matDatepicker.setAttribute('endyear', this.component.propSetYearMax);
        }
		// when it is overriding a builtin control
		if (typeof(this.component.propSetMaxRelative) == 'boolean') {
        	matDatepicker.setAttribute('endyearrelative', this.component.propSetMaxRelative);
        }
		if (this.component.control && !this.component.control.valid) {
			matDatepicker.hasError = JSON.stringify(!this.component.control.valid);
			matDatepicker.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matDatepicker.addEventListener("mwcchange", this.onChange.bind(this));
    	return matDatepicker;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matDatepicker.parentElement)
			this.matDatepicker.parentElement.removeChild(this.matDatepicker);
    	this.matDatepicker = this.createMaterialDatepicker();
        this.component.parentNode.appendChild(this.matDatepicker);
        this.refresh();
    }
}
