/*
 * Copyright (c) 2020-2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialInput) == 'undefined') {
	tibcoforms.library.components.ng.MaterialInput = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialInput;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matInput = this.createMaterialInput();
        this.component.parentNode.appendChild(this.matInput);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }
    
    wrapper.prototype.applyValue = function(component, matInput) {
    	if (matInput.getAttribute("input-type") == "date")
    		matInput.value = bpm.forms.Util.formatDate("yyyy-MM-dd", component.value);
		else if (matInput.getAttribute("input-type") == "time") {
			// we will show only HH:mm in the UI and no seconds
			matInput.value = bpm.forms.Util.formatDate("HH:mm", component.value);
		} else if (matInput.getAttribute("input-type") == "datetime-local")
			matInput.value = bpm.forms.Util.formatDate("yyyy-MM-dd'T'HH:mm:ss", component.value);
		else
			matInput.value = component.value;
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialInput: refresh: " + updates);
        if (updates == null) return;
        var control = this.component.control; 
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matInput.value))) {
        	this.applyValue(this.component, this.matInput);
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matInput.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matInput.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matInput.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matInput.setAttribute("required", this.component.control.required);
		}
		if (updates.includes("required")) {
			this.matInput.setAttribute("required", this.component.control.required);
		}
		if (updates.includes("suffix")) {
			this.matInput.suffix = this.component.control.suffix;
		}
		if (updates.includes("prefix")) {
			this.matInput.prefix = this.component.control.prefix;
		}
        if (updates.includes("mwcPlaceholder")) {
        	this.matInput.placeholder = this.component.control.mwcPlaceholder;
        }
        if (updates.includes("mwcAppearance")) {        
        	this.matInput.appearance = this.component.control.mwcAppearance;
        }
        if (updates.includes("validation")) {
        	this.matInput.hasError = JSON.stringify(!this.component.control.valid);
        	this.matInput.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	if (event.detail != this.component.control.value) {
    		if (this.matInput.getAttribute("input-type") == "date")
    			this.component.raiseEvent("update", bpm.forms.Util.formatDate("yyyy-MM-dd", event.detail));
    		else if (this.matInput.getAttribute("input-type") == "time") {
				// we will show only HH:mm in the UI and no seconds
    			// this.component.raiseEvent("update", bpm.forms.Util.formatDate("HH:mm:ssZ", event.detail));
				if (event.detail && event.detail.indexOf(":") > 0) {
					const d = new Date();
					d.setHours(event.detail.substring(0, event.detail.indexOf(":")));
					let tempTimeStr = event.detail.substring(event.detail.indexOf(":") + 1);
					// d.setMinutes(tempTimeStr.substring(0, tempTimeStr.indexOf(":")));
					// d.setSeconds(tempTimeStr.substring(tempTimeStr.indexOf(":") + 1));
					d.setMinutes(tempTimeStr);
					d.setSeconds(00);
					this.component.raiseEvent("update", bpm.forms.Util.formatDate("HH:mm:ss", d));
				}
    		} else if (this.matInput.getAttribute("input-type") == "datetime-local")
    			this.component.raiseEvent("update", bpm.forms.Util.formatDate("yyyy-MM-dd'T'HH:mm:ssZ", event.detail));
    		else
    			this.component.raiseEvent("update", event.detail);
    	}
    }

    wrapper.prototype.createMaterialInput = function() {
    	var matInput = document.createElement("tf-ng-material-input");
    	matInput.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matInput.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matInput.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matInput.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matInput.setAttribute("required", this.component.control.required);
    	// if the control is used to override the built-in controls, the custom properties would not exist
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom") {
    		if (this.component.control.mwcInputType)
    			matInput.inputType = this.component.control.mwcInputType;
			if (this.component.control.mwcDisplayLength > 0)
    			matInput.setAttribute("size", this.component.control.mwcDisplayLength);
			if (this.component.control.mwcMaxLength > 0)
    			matInput.setAttribute("maxlength", this.component.control.mwcMaxLength);
    	} else {
    		if (this.component.baseType == "BomPrimitiveTypes.Date")
        		matInput.setAttribute("input-type", "date");
        	else if (this.component.baseType == "BomPrimitiveTypes.Time") {
            		matInput.setAttribute("input-type", "time");
					// matInput.setAttribute("step", "1");
            } else if (this.component.baseType == "BomPrimitiveTypes.DateTimeTZ")
                	matInput.setAttribute("input-type", "datetime-local");
            else if (this.component.baseType == "BomPrimitiveTypes.Decimal")
            	matInput.setAttribute("input-type", "number");
            else if (this.component.propSetTextSecret)
            	matInput.setAttribute("input-type", "password");
			else if (this.component.propSetInputType == 'email')
            	matInput.setAttribute("input-type", "email");
			if(this.component && this.component.propSetPlaceholder){        
				matInput.setAttribute('placeholder', this.component.propSetPlaceholder);
			}
			if(this.component && this.component.propSetAppearance){        
				matInput.setAttribute('appearance', this.component.propSetAppearance);
			}
			if(this.component && this.component.suffix){        
				matInput.setAttribute('suffix', this.component.suffix);
			}
			if(this.component && this.component.prefix){        
				matInput.setAttribute('prefix', this.component.prefix);
			}
			if (this.component.propSetTextDisLen > 0)
    			matInput.setAttribute("size", this.component.propSetTextDisLen);
			if (this.component.propSetTextBoxBaseMaxLen > 0)
    			matInput.setAttribute("maxlength", this.component.propSetTextBoxBaseMaxLen);
    	}
    	if (this.component.value || (this.component.value == 0)) {
        	this.applyValue(this.component, matInput);
        }
        if(this.component.control && this.component.control.mwcPlaceholder){        
        	matInput.setAttribute('placeholder', this.component.control.mwcPlaceholder);
        }
        if(this.component.control && this.component.control.mwcAppearance){        
        	matInput.setAttribute('appearance', this.component.control.mwcAppearance);
        }
		if(this.component.control && this.component.control.suffix){        
        	matInput.setAttribute('suffix', this.component.control.suffix);
        }
		if(this.component.control && this.component.control.prefix){        
        	matInput.setAttribute('prefix', this.component.control.prefix);
        }
		if (this.component.control && !this.component.control.valid) {
			matInput.hasError = JSON.stringify(!this.component.control.valid);
			matInput.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matInput.addEventListener("mwcchange", this.onChange.bind(this));
    	return matInput;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matInput.parentElement)
			this.matInput.parentElement.removeChild(this.matInput);
    	this.matInput = this.createMaterialInput();
        this.component.parentNode.appendChild(this.matInput);
        this.refresh();
    }
}
