/*
 * Copyright (c) 2020-2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialRadioGroup) == 'undefined') {
	tibcoforms.library.components.ng.MaterialRadioGroup = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialRadioGroup;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matRadioGroup = this.createMaterialRadioGroup();
        this.component.parentNode.appendChild(this.matRadioGroup);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialRadioGroup: refresh: " + updates);
        if (updates == null) return;
        var control = this.component.control;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matRadioGroup.value))) {
        	this.matRadioGroup.value = this.component.value;
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matRadioGroup.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matRadioGroup.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matRadioGroup.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matRadioGroup.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("mwcPlaceholder")) {
        	this.matRadioGroup.placeholder = this.component.control.mwcPlaceholder;
        }
        if (updates.includes("mwcChoiceLabels") || updates.includes("mwcChoiceValues")
        		// for this can be used in place of an optionlist(built-in) control
        		|| updates.includes("choiceLabels") || updates.includes("choiceValues")) {
        	const selectOptions = [];
        	for (var i=0; i<this.getMWCChoiceValues().length; i++) {
        		selectOptions.push({"label":
        			this.getMWCChoiceLabels().length > i ? this.getMWCChoiceLabels()[i]
        				: this.getMWCChoiceValues()[i], 
        			"value": this.getMWCChoiceValues()[i]});
        	}
        	this.matRadioGroup.selectOptions = JSON.stringify(selectOptions);
        }
        if (updates.includes("validation")) {
        	this.matRadioGroup.hasError = JSON.stringify(!this.component.control.valid);
        	this.matRadioGroup.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	if (event.detail.value != this.component.control.value) {
    		this.component.raiseEvent("update", event.detail.value);
    	}
    }

    wrapper.prototype.createMaterialRadioGroup = function() {
    	var matRadioGroup = document.createElement("tf-ng-material-radiogroup");
    	matRadioGroup.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matRadioGroup.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matRadioGroup.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matRadioGroup.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matRadioGroup.setAttribute("required", this.component.control.required);
    	const selectOptions = [];
    	for (let i=0; i<this.getMWCChoiceLabels().length; i++) {
    		selectOptions.push({label: this.getMWCChoiceLabels()[i], value: this.getMWCChoiceValues()[i]});
    	}
    	matRadioGroup.setAttribute("select-options", JSON.stringify(selectOptions));
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom") {
    		if (this.component.control.mwcColumns == -1)
    			matRadioGroup.setAttribute("columns", -1);
    		else if (this.component.control.mwcColumns > 1)
    			matRadioGroup.setAttribute("columns", this.component.control.mwcColumns);
    		else
    			matRadioGroup.setAttribute("columns", 1);
    	} else {
    		if (this.component.propSetRadioGroupFormat == "horizontal")
    			matRadioGroup.setAttribute("columns", -1);
    		else if (this.component.propSetRadioGroupColumns > 1)
    			matRadioGroup.setAttribute("columns", this.component.propSetRadioGroupColumns);
    		else
    			matRadioGroup.setAttribute("columns", 1);
    	}
    	if (this.component.control.value)
    		matRadioGroup.value = this.component.control.value;
		if (this.component.control && !this.component.control.valid) {
			matRadioGroup.hasError = JSON.stringify(!this.component.control.valid);
			matRadioGroup.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	return matRadioGroup;
    }

    wrapper.prototype.getMWCChoiceLabels = function() {
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom")
    		return this.component.control.mwcChoiceLabels;
    	else
    		return this.component.control.optionLabels;
    }

    wrapper.prototype.getMWCChoiceValues = function() {
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom")
    		return this.component.control.mwcChoiceValues;
    	else
    		return this.component.control.optionValues;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matRadioGroup.parentElement)
			this.matRadioGroup.parentElement.removeChild(this.matRadioGroup);
    	this.matRadioGroup = this.createMaterialRadioGroup();
        this.component.parentNode.appendChild(this.matRadioGroup);
        this.refresh();
    }
}
