/*
 * Copyright (c) 2020-2023 Cloud Software Group, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialSelect) == 'undefined') {
	tibcoforms.library.components.ng.MaterialSelect = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialSelect;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matSelect = this.createMaterialSelect();
        this.component.parentNode.appendChild(this.matSelect);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }
    
    wrapper.prototype.updatetMatSelectValue = function(matSelect) {
    	if (this.component.control.multiple)
        	matSelect.value = JSON.stringify(this.component.value);
    	else
    		matSelect.value = this.component.value == null ? "" : this.component.value;
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialSelect: refresh: " + updates);
        if (updates == null) return;
        // for a required control, when the value get set, we need to remove the '-Select-' option
        let reqdControlValJustGotSet = !this.matSelect.value && this.component.value;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value !== this.matSelect.value))) {
        	this.updatetMatSelectValue(this.matSelect);
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matSelect.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matSelect.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matSelect.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matSelect.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("mwcPlaceholder")) {
        	this.matSelect.placeholder = this.component.control.mwcPlaceholder;
        }
        if (updates.includes("mwcAppearance")) {        
        	this.matSelect.appearance = this.component.control.mwcAppearance;
        }
        if (updates.includes("mwcChoiceLabels") || updates.includes("mwcChoiceValues")
        		// for this can be used in place of an optionlist(built-in) control
        		|| updates.includes("choiceLabels") || updates.includes("choiceValues")
        		|| updates.includes("required") || reqdControlValJustGotSet) {
        	this.matSelect.selectOptions = JSON.stringify(this.getEffectiveSelectOptions());
        }
        if (updates.includes("validation")) {
        	this.matSelect.hasError = JSON.stringify(!this.component.control.valid);
        	this.matSelect.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	if (event.detail.value != this.component.control.value) {
    		this.component.raiseEvent("update", event.detail);
    	}
    }
    
   /**
    * Returns options. If an explicit '-Select -' otpion needs to be shown, add it to the list.
    * @since 5.5.0
    */
    wrapper.prototype.getEffectiveSelectOptions = function() {
    	const selectOptions = [];
    	let explictUnsetChoice = (this.component.control.required && this.component.value)  || this.component.control.multiple ? false : true;
    	for (let i=0; i<this.getMWCChoiceLabels().length; i++) {
    		selectOptions.push({label: this.getMWCChoiceLabels()[i], value: this.getMWCChoiceValues()[i]});
    		if ("" == this.getMWCChoiceValues()[i])
    			explictUnsetChoice = false;
    	}
    	if (explictUnsetChoice)
    		selectOptions.unshift({label: "- Select -", value: ""});
    	return selectOptions;
    }

    wrapper.prototype.createMaterialSelect = function() {
    	var matSelect = document.createElement("tf-ng-material-select");
    	matSelect.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matSelect.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matSelect.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matSelect.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matSelect.setAttribute("required", this.component.control.required);
    	if (this.component.control.multiple)
    		matSelect.setAttribute("multiple", "true");
        if(this.component && this.component.propSetAppearance){        
			matSelect.setAttribute('appearance', this.component.propSetAppearance);
		}
        if(this.component.control && this.component.control.mwcAppearance){        
        	matSelect.setAttribute('appearance', this.component.control.mwcAppearance);
        }
    	matSelect.setAttribute("select-options", JSON.stringify(this.getEffectiveSelectOptions()));
    	if (this.component.control.value
    		// single select optional control should show '- Select -' when value is not set
    		|| !this.component.control.multiple) {
        	this.updatetMatSelectValue(matSelect);
        }
		if (this.component.control && !this.component.control.valid) {
			matSelect.hasError = JSON.stringify(!this.component.control.valid);
			matSelect.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matSelect.addEventListener("mwcchange", this.onChange.bind(this));
    	return matSelect;
    }

    wrapper.prototype.getMWCChoiceLabels = function() {
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom")
    		return this.component.control.mwcChoiceLabels;
    	else
    		return this.component.control.optionLabels;
    }

    wrapper.prototype.getMWCChoiceValues = function() {
    	if (this.component.control.controlType == "com.tibco.forms.controls.custom")
    		return this.component.control.mwcChoiceValues;
    	else
    		return this.component.control.optionValues;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matSelect.parentElement)
			this.matSelect.parentElement.removeChild(this.matSelect);
    	this.matSelect = this.createMaterialSelect();
        this.component.parentNode.appendChild(this.matSelect);
        this.refresh();
    }
}
