/*
 * Copyright (c) 2020-2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialSlide) == 'undefined') {
	tibcoforms.library.components.ng.MaterialSlide = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialSlide;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matSlide = this.createMaterialSlide();
        this.component.parentNode.appendChild(this.matSlide);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialSlide: refresh: " + updates);
        if (updates == null || updates.length == 0) return;
        var control = this.component.control;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matSlide.value))) {
        	this.matSlide.value = this.component.control.value;
        }
        if (updates.includes("hint")) {
        	this.matSlide.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matSlide.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matSlide.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matSlide.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("validation")) {
        	this.matSlide.hasError = JSON.stringify(!this.component.control.valid);
        	this.matSlide.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	if (event.detail != this.component.control.value) {
    		this.component.raiseEvent("update", event.detail);
    	}
    }

    wrapper.prototype.createMaterialSlide = function() {
    	var matSlide = document.createElement("tf-ng-material-slide");
    	matSlide.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matSlide.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matSlide.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matSlide.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matSlide.setAttribute("required", this.component.control.required);
    	if (this.component.control.mwcMin)
    		matSlide.setAttribute("min", this.component.control.mwcMin);
    	if (this.component.control.mwcMax)
    		matSlide.setAttribute("max", this.component.control.mwcMax);
    	if (this.component.control.mwcTickInterval)
    		matSlide.setAttribute("tickInterval", this.component.control.mwcTickInterval);
    	if (this.component.control.value)
    		matSlide.value = this.component.control.value;
		if (this.component.control && !this.component.control.valid) {
			matSlide.hasError = JSON.stringify(!this.component.control.valid);
			matSlide.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matSlide.addEventListener("mwcchange", this.onChange.bind(this));
    	return matSlide;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matSlide.parentElement)
			this.matSlide.parentElement.removeChild(this.matSlide);
    	this.matSlide = this.createMaterialSlide();
        this.component.parentNode.appendChild(this.matSlide);
        this.refresh();
    }
}
