/*
 * Copyright (c) 2020-2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialTextarea) == 'undefined') {
	tibcoforms.library.components.ng.MaterialTextarea = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialTextarea;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matTextarea = this.createMaterialTextarea();
        this.component.parentNode.appendChild(this.matTextarea);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialTextarea: refresh: " + updates);
        if (updates == null) return;
        var control = this.component.control;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matTextarea.value))) {
        	this.matTextarea.value = this.component.value;
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matTextarea.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matTextarea.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matTextarea.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matTextarea.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("mwcAppearance")) {        
        	this.matTextarea.appearance = this.component.control.mwcAppearance;
        }
        if (updates.includes("validation")) {
        	this.matTextarea.hasError = JSON.stringify(!this.component.control.valid);
        	this.matTextarea.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	if (event.detail != this.component.control.value) {
    		this.component.raiseEvent("update", event.detail);
    	}
    }

    wrapper.prototype.createMaterialTextarea = function() {
    	var matTextarea = document.createElement("tf-ng-material-textarea");
    	matTextarea.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matTextarea.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matTextarea.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matTextarea.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matTextarea.setAttribute("required", this.component.control.required);
    	if (this.component.control.value)
    		matTextarea.value = this.component.control.value;
    	if(this.component && this.component.propSetPlaceholder){        
			matTextarea.setAttribute('placeholder', this.component.propSetPlaceholder);
		}
		if(this.component.control && this.component.control.mwcPlaceholder){        
        	matTextarea.setAttribute('placeholder', this.component.control.mwcPlaceholder);
        }
        if(this.component && this.component.propSetAppearance){        
			matTextarea.setAttribute('appearance', this.component.propSetAppearance);
		}
		if(this.component.control && this.component.control.mwcAppearance){        
        	matTextarea.setAttribute('appearance', this.component.control.mwcAppearance);
        }
		if (this.component.control.controlType == "com.tibco.forms.controls.custom") {
    		if (this.component.control.mwcColumns > 0)
    			matTextarea.setAttribute("columns", this.component.control.mwcColumns);
			if (this.component.control.mwcRows > 0)
    			matTextarea.setAttribute("rows", this.component.control.mwcRows);
			if (this.component.control.mwcMaxLength > 0)
    			matTextarea.setAttribute("maxlength", this.component.control.mwcMaxLength);
    	} else {
    		if (this.component.propSetTextAreaCols > 0)
    			matTextarea.setAttribute("columns", this.component.propSetTextAreaCols);
    		if (this.component.propSetTextAreaRows > 0)
    			matTextarea.setAttribute("rows", this.component.propSetTextAreaRows);
			if (this.component.propSetTextBoxBaseMaxLen > 0)
    			matTextarea.setAttribute("maxlength", this.component.propSetTextBoxBaseMaxLen);
    	}
		if (this.component.control && !this.component.control.valid) {
			matTextarea.hasError = JSON.stringify(!this.component.control.valid);
			matTextarea.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matTextarea.addEventListener("mwcchange", this.onChange.bind(this));
    	return matTextarea;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matTextarea.parentElement)
			this.matTextarea.parentElement.removeChild(this.matTextarea);
    	this.matTextarea = this.createMaterialTextarea();
        this.component.parentNode.appendChild(this.matTextarea);
        this.refresh();
    }
}
