/*
 * Copyright (c) 2022 TIBCO Software, Inc. All Rights Reserved.
 */
if (typeof(tibcoforms) == 'undefined') tibcoforms = new Object();
if (typeof(tibcoforms.library) == 'undefined') tibcoforms.library = new Object();
if (typeof(tibcoforms.library.components) == 'undefined') tibcoforms.library.components = new Object();
if (typeof(tibcoforms.library.components.ng) == 'undefined') tibcoforms.library.components.ng = new Object();
if (typeof(tibcoforms.library.components.ng.MaterialTimeChips) == 'undefined') {
	tibcoforms.library.components.ng.MaterialTimeChips = function() {};
	var wrapper = tibcoforms.library.components.ng.MaterialTimeChips;

	wrapper.prototype.initialize = function(component, renderMode) {
        this.component = component;
        this.renderMode = renderMode;
        this.logger = this.component.logger;
        this.matErrors = [];
        this.matChips = this.createMaterialTimeChips();
        this.component.parentNode.appendChild(this.matChips);
    }

    wrapper.prototype.getFormattedValue = function(value) {
        return value;
    }

    wrapper.prototype.getValue = function() {
        return "TODO: getValue";
    }

    wrapper.prototype.setFocus = function() {
        
    }

    wrapper.prototype.refresh = function(updates) {
        if (this.logger.isDebugEnabled()) this.logger.debug("MaterialTimeChips: refresh: " + updates);
        if (updates == null) return;
        var control = this.component.control;
        if ((this.renderMode == "grid-edit") || (updates.includes("value") && (this.component.value != this.matChips.value))) {
        	this.matChips.value = JSON.stringify(this.component.value);
        }
        if (updates.length == 0) return;
        if (updates.includes("hint")) {
        	this.matChips.hint = this.component.control.hint;
        }
		if (updates.includes("enabled")) {
			// enable and read only do the same for angular components
			this.matChips.setAttribute("enabled", this.component.control.reallyEnabled && !this.component.control.reallyReadOnly);
		}
		if (updates.includes("readOnly")) {
			// enable and read only do the same for angular components
			this.matChips.setAttribute("readonly", this.component.control.reallyReadOnly || !this.component.control.reallyEnabled);
		}
		if (updates.includes("required")) {
			this.matChips.setAttribute("required", this.component.control.required);
		}
        if (updates.includes("mwcPlaceholder")) {
        	this.matChips.placeholder = this.component.control.mwcPlaceholder;
        }
        if (updates.includes("mwcAppearance")) {        
        	this.matChips.appearance = this.component.control.mwcAppearance;
        }
        if (updates.includes("validation")) {
        	this.matChips.hasError = JSON.stringify(!this.component.control.valid);
        	this.matChips.validationMessages = JSON.stringify(this.component.control.validationErrors);
        }
    }

    wrapper.prototype.destroy = function() {
    }

    wrapper.isReady = function() {
    	bpm.forms.Util.loadCSS("https://fonts.googleapis.com/icon?family=Material+Icons", true);
    	return true;
    }

    wrapper.renderStatic = function(value, label, hint, labelId, propertySet, resources, textOnly, parentPaneType, logger) {
    	throw "ERR_MYANGCOM: TODO: Static mode support";
    }

    wrapper.prototype.onChange = function(event) {
    	var detailsArray = event.detail?JSON.parse(event.detail):[];
		// form would check if the values really changed
		this.component.raiseEvent("update", detailsArray);
    }

    wrapper.prototype.createMaterialTimeChips = function() {
    	var matChips = document.createElement("tf-ng-material-chips-time");
    	matChips.setAttribute("label", this.component.control.label);
    	if (this.component.control.hint)
    		matChips.setAttribute("hint", this.component.control.hint);
		// add this attribute only if disabled, otherwise clashes with read only
		// For readonly and disabled, we use disabled as there is no explicit readonly with angular form control
		if (!this.component.control.reallyEnabled)
			matChips.setAttribute("enabled", this.component.control.reallyEnabled);
		if (this.component.control.reallyReadOnly)
			matChips.setAttribute("readonly", this.component.control.reallyReadOnly);
		if (this.component.control.required)
			matChips.setAttribute("required", this.component.control.required);
    	// if the control is used to override the built-in controls, the custom properties would not exist
    	if ((this.component.control.controlType == "com.tibco.forms.controls.custom") && this.component.control.mwcOrientation)
    		matChips.orientation = this.component.control.mwcOrientation;
    	if (this.component.control.value)
    		matChips.value = JSON.stringify(this.component.control.value);	
    	if(this.component && this.component.propSetPlaceholder){        
			matChips.setAttribute('placeholder', this.component.propSetPlaceholder);
		}
    	if(this.component.control && this.component.control.mwcPlaceholder){        
        	matChips.setAttribute('placeholder', this.component.control.mwcPlaceholder);
        }
        if(this.component && this.component.propSetAppearance){        
			matChips.setAttribute('appearance', this.component.propSetAppearance);
		}
        if(this.component.control && this.component.control.mwcAppearance){        
        	matChips.setAttribute('appearance', this.component.control.mwcAppearance);
        }
		// when it is overriding a builtin list control
		if (typeof(this.component.propSetListAllowAdd) == 'boolean') {
        	matChips.setAttribute('allowadd', this.component.propSetListAllowAdd);
        }
		// when it is overriding a builtin list control
    	if (typeof(this.component.propSetListAllowModify) == 'boolean') {
        	matChips.setAttribute('allowmodify', this.component.propSetListAllowModify);
        }
		// when it is overriding a builtin list control
    	if (typeof(this.component.propSetListAllowDelete) == 'boolean') {       
        	matChips.setAttribute('allowdelete', this.component.propSetListAllowDelete);
        }
    	if(this.component.control && (typeof(this.component.mwcAllowAdd) == 'boolean')){        
        	matChips.setAttribute('allowadd', this.component.control.mwcAllowAdd);
        }
    	if(this.component.control && (typeof(this.component.mwcAllowModify) == 'boolean')){        
        	matChips.setAttribute('allowmodify', ("mwcAllowModify" in this.component.control));
        }
    	if(this.component.control && (typeof(this.component.mwcAllowDelete) == 'boolean')){        
        	matChips.setAttribute('allowdelete', this.component.control.mwcAllowDelete);
        }
		if (this.component.control && !this.component.control.valid) {
			matChips.hasError = JSON.stringify(!this.component.control.valid);
			matChips.validationMessages = JSON.stringify(this.component.control.validationErrors);
		}
    	matChips.setAttribute("displayformat", this.component.form.resource.common.time_format);
    	matChips.setAttribute("editformat", this.component.form.resource.common.time_edit_format);
    	matChips.addEventListener("mwcchange", this.onChange.bind(this));
    	return matChips;
    }

    wrapper.prototype.reEnter = function() {
		if (this.matChips.parentElement)
			this.matChips.parentElement.removeChild(this.matChips);
    	this.matChips = this.createMaterialTimeChips();
        this.component.parentNode.appendChild(this.matChips);
        this.refresh();
    }
}
