import BpmeBaseComponent from "../../internal/bpme-base-component";
export declare const auditListManagedObjectsEvents: string[];
/**
 * @since 1.0.0
 * @status stable
 * @dependency bpme-audit-details-managed-objects
 * @slot - The default content slot.
 *
 * @event { string{} } bpme-audit-list-navigate-back-clicked - Emitted when the back button clicked.
 * @event { [{completeObj: string[]}, {itemObj: object}, {activeIndex: number}] } bpme-audit-list-selected - Emitted when the audit list row clicked.
 * @event { ECAuditEntry[] } bpme-audit-selected-managed-item-data-fetched - Emitted when the audit selected managed item data is fetched.
 *
 *
 * @csspart base - The component's internal wrapper.
 * @csspart navigation-wrapper - The component's navigation wrapper.
 * @csspart label-wrapper - The component's label wrapper.
 * @csspart content-container - The component's content wrapper.
 * @csspart audit-details-container - The component's audit details wrapper.
 *
 * @extraconfig ECAuditEntry
 *
 * @paramECAuditEntry eventId (string) (-) The unique identifier of the AuditEntry.
 * @paramECAuditEntry messageCategory (string) (-) The category of the audit message.
 * @paramECAuditEntry messageId (string) (-) The identifier of the audit message.
 * @paramECAuditEntry message (string) (-) The audit message.
 * @paramECAuditEntry severity (string) (-) The severity of the AuditEntry.
 * @paramECAuditEntry creationTime (string) (-) The time at which the AuditEntry was created (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry managedObjectId (string) (-) The managed object identifier.
 * @paramECAuditEntry principalId (string) (-) The principal identifier.
 * @paramECAuditEntry principalName (string) (-) The principal name.
 * @paramECAuditEntry managedObjectName (string) (-) The managed object name.
 * @paramECAuditEntry managedObjectVersion (string) (-) The managed object version.
 * @paramECAuditEntry managedObjectType (string) (-) The managed object type.
 * @paramECAuditEntry managedObjectStatus (string) (-) The managed object status.
 * @paramECAuditEntry managedObjectUrl (string) (-) The managed object URL.
 * @paramECAuditEntry managedObjectDetails (string) (-) The managed object details.
 * @paramECAuditEntry parentObjectId (string) (-) The parent object identifier.
 * @paramECAuditEntry applicationName (string) (-) The Application name.
 * @paramECAuditEntry workItemScheduleStart (string) (-) The time at which the Work Item schedule was started (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry workItemScheduleEnd (string) (-) The time at which the Work Item schedule was ended (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry entities (string) (-) The Work Item entities.
 * @paramECAuditEntry workItemPriority (string) (-) The Work Item priority.
 * @paramECAuditEntry extendedMessage (string) (-) The extended message.
 * @paramECAuditEntry retryTime (string) (-) The retry time.
 * @paramECAuditEntry resourceId (string) (-) The resource identifier.
 * @paramECAuditEntry resourceName (string) (-) The resource name.
 * @paramECAuditEntry entityId (string) (-) The entity identifier.
 * @paramECAuditEntry entityType (string) (-) The entity type.
 * @paramECAuditEntry channelId (string) (-) The channel identifier.
 * @paramECAuditEntry applicationActivityName (string) (-) The Application activity name.
 * @paramECAuditEntry applicationActivityModelId (string) (-) The Application activity model identifier.
 * @paramECAuditEntry applicationActivityInstanceId (string) (-) The Application activity identifier.
 * @paramECAuditEntry systemActionComponentId (string) (-) The system action component identifier.
 * @paramECAuditEntry systemActionId (string) (-) The system action identifier.
 * @paramECAuditEntry rootProcessInstanceId (string) (-) The root Process Instance identifier.
 * @paramECAuditEntry parentProcessInstanceId (string) (-) The parent Process Instance identifier.
 * @paramECAuditEntry parentActivityInstanceId (string) (-) The parent activity instance identifier.
 * @paramECAuditEntry subprocessInstanceId (string) (-) The sub-process instance identifier.
 * @paramECAuditEntry subprocessName (string) (-) The sub-process name.
 * @paramECAuditEntry processPriority (string) (-) The process priority.
 * @paramECAuditEntry moduleName (string) (-) The module name.
 * @paramECAuditEntry priorStepId (string) (-) The prior step identifier.
 * @paramECAuditEntry subprocessVersion (string) (-) The sub-process version.
 * @paramECAuditEntry modelMajorVersion (string) (-) The model major version.
 * @paramECAuditEntry modelVersion (string) (-) The model version.
 * @paramECAuditEntry roleName (string) (-) The name of the role.
 * @paramECAuditEntry iteration (string) (-) The iteration.
 * @paramECAuditEntry iterationId (string) (-) The iteration identifier.
 * @paramECAuditEntry hostTaskName (string) (-) The host task name.
 * @paramECAuditEntry hostTaskType (string) (-) The host task type.
 * @paramECAuditEntry interruptsMainFlow (string) (-) The interrupts main flow.
 * @paramECAuditEntry caseReferences (string[]) (-) Case References
 * @paramECAuditEntry genericAttributes (ECGenericAttribute[]) (-) Generic attributes.
 * @paramECAuditEntry additionalAttributes (ECAdditionalAttribute[]) (-) Additional attributes.
 *
 * @extraconfig ECGenericAttribute
 *
 * @paramECGenericAttribute name (string) (-) The attribute name.
 * @paramECGenericAttribute value (string) (-) The value of the attribute (as a string).
 * @paramECGenericAttribute type (ECGenericAttributeTypeEnum <'Date' | 'Integer' | 'String' | 'Boolean' | 'Long' | 'Double' | 'BigDecimal' | 'BigInteger'>) (-) The type of the attribute. (This is only valid for retrieved data, not when creating events.).
 *
 * @extraconfig ECAdditionalAttribute
 *
 * @paramECAdditionalAttribute name (string) (-) The attribute name.
 * @paramECAdditionalAttribute value (string) (-) The value of the attribute (as a string).
 *
*/
export declare class BpmeAuditListManagedObjects extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** Managed object type of the selected audit item. */
    managedObjectType: string;
    /** Managed object type id of the selected audit item. */
    managedObjectId: string;
    /** Table attributes of the selected audit item */
    tableAttributesJSON: [];
    /** Back button label of the component. */
    backBtnLabel: string;
    /** Name of the selected row audit item. */
    managedObjectName: string;
    tableData: any;
    label: string;
    auditDetailsSidebar: any;
    apiConfig: any;
    auditSidebarLabel: string;
    showLoader: boolean;
    updated(changedProperties: any): void;
    bpmetoast: any;
    getAuditDetails(itemObject?: object, completeObject?: object, activeIndex?: number): void;
    showToast(variant: string, msg: string): void;
    auditDetailsGet(): void;
    navigateBack(event?: any): void;
    renderSideBar(data: any): void;
    transformSideBarLabel(activeIndex: any): void;
    show(): void;
    hide(): void;
    performAction(event: any): void;
    returnTableCellData(rowData: any, colID: any, tableData: any, index: any): import("lit-html").TemplateResult<1>;
    refreshHandle(): void;
    onScroll(): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-audit-list-managed-objects": BpmeAuditListManagedObjects;
    }
}
