import { LitElement, PropertyValues } from 'lit';
import { PFEInstanceInfo, PFEProcessInfo } from 'bpme-services-lib/dist/lib/objectapi/pfe';
/**
 * @since 1.0.0
 * @status stable
 *
 *
 * @extraconfig PFEProcessInfo
 * @paramPFEProcessInfo moduleName (string) (-) The name of the module/package that contains the process to be started
 * @paramPFEProcessInfo processName (string) (-) The name of the process to be started.
 * @paramPFEProcessInfo moduleVersion (string) (-) Optional version of process to be started, defaults to latest
 * @paramPFEProcessInfo data (string) (-) The JSON data, serialized to a string, used to start the Process Instance
 *
 *
 * @event {formStatusChangeObject} bpme-case-action-form-status-change - Emitted when the form update is complete
 * @event {formLoadObject} bpme-case-action-form-form-load - Emitted when the form load is complete
 * @event {formCancelObject} bpme-case-action-form-cancel - Emitted when the form is cancel is complete
 * @event {formCloseObject} bpme-case-action-form-close - Emitted when the form is closed
 * @event {formSubmitObject} bpme-case-action-form-submit - Emitted when the form is submitted
 * @event {formErrorObject} bpme-case-action-form-error - Emitted when there is an error while loading the form
 *
 * @extraconfig formStatusChangeObject
 *
 * @paramformStatusChangeObject eventName (string) (bpme-case-action-form-status-change) The form status change event name
 * @paramformStatusChangeObject displaying (string) ("OTHER" | "FORM" | "BUSY") The display property
 * @paramformStatusChangeObject eventDetailName (string) (-) The event details.
 * @paramformStatusChangeObject serviceToOpen (PFEInstanceInfo) (-) The instance information
 *
 * @extraconfig PFEInstanceInfo
 *
 * @paramPFEInstanceInfo instanceId (string) (-) The unique id of the Process Instance.
 * @paramPFEInstanceInfo processId (string) (-) The id of the process for this instance.
 * @paramPFEInstanceInfo moduleName (string) (-) The name of the module/package for this instance.
 * @paramPFEInstanceInfo moduleVersion (string) (-) The version of the module/package for this instance.
 * @paramPFEInstanceInfo processName (string) (-) The name of the process for this instance.
 * @paramPFEInstanceInfo processLabel (string) (-) Display name of the process configured in studio.
 * @paramPFEInstanceInfo state (PFEInstanceState) (-) The state of the instance .
 * @paramPFEInstanceInfo activityInfo (PFEActivityInfo) (-) The activity info of the Process Instance.
 *
 * @extraconfig PFEActivityInfo
 *
 * @paramPFEActivityInfo activityId (string) (-) Id of the current activity where the process has been passivated
 * @paramPFEActivityInfo activityName (string) (-) Name of the current activity where the process has been passivated
 * @paramPFEActivityInfo activityProcessPackageId (string) (-) Module/Package id of the activity related pageflow
 * @paramPFEActivityInfo activityProcessModuleName (string) (-) Module/Package name of the activity related pageflow
 * @paramPFEActivityInfo activityProcessModuleVersion (string) (-) Module/Package version of the activity related pageflow
 * @paramPFEActivityInfo activityPageflowName (string) (-) Name of the activity related pageflow
 * @paramPFEActivityInfo activityData (string) (-) Data for messages that are related to a specific task, e.g. completion of a user task.
 *
 * @extraconfig PFEInstanceState
 *
 * @paramPFEInstanceState state (PFEInstanceStateStateEnum) (-) The state details.
 * @paramPFEInstanceState failedMessage (PFEFailedMessage) (-) The failed message details of the instance.
 *
 * @extraconfig PFEInstanceStateStateEnum
 *
 * @paramPFEInstanceStateStateEnum  Starting (string) (STARTING) The const value.
 * @paramPFEInstanceStateStateEnum  Active (string) (ACTIVE) The const value.
 * @paramPFEInstanceStateStateEnum  Completed (string) (COMPLETED) The const value.
 * @paramPFEInstanceStateStateEnum  Cancelled (string) (CANCELLED) The const value.
 * @paramPFEInstanceStateStateEnum  Failed (string) (FAILED) The const value.
 * @paramPFEInstanceStateStateEnum  Unknown (string) (UNKNOWN) The const value.
 *
 * @extraconfig PFEFailedMessage
 *
 * @paramPFEFailedMessage msgName (PFEFailedMessageMsgNameEnum) (-) The message name.
 * @paramPFEFailedMessage exceptionMsg (string) (-) Message from root cause of exception
 * @paramPFEFailedMessage exceptionStack (string) (-) Full exception stack
 * @paramPFEFailedMessage msgData (string) (-) Contains any data being passed in the message.
 * @paramPFEFailedMessage activityData (string) (-) Data for messages that are related to a specific task, e.g. completion of a user task.
 *
 * @extraconfig PFEFailedMessageMsgNameEnum
 *
 * @paramPFEFailedMessageMsgNameEnum Start (string) (START) The const value
 * @paramPFEFailedMessageMsgNameEnum Update (string) (UPDATE) The const value
 * @paramPFEFailedMessageMsgNameEnum InjectEvent (string) (INJECT_EVENT) The const value
 *
 * @extraconfig formLoadObject
 *
 * @paramformLoadObject eventName (string) (bpme-case-action-form-form-load) The form status load event name
 * @paramformLoadObject form (formData) (-) The formData.
 *
 * @extraconfig formCancelObject
 *
 * @paramformCancelObject eventName (string) (bpme-case-action-form-cancel) The form status cancel event name
 * @paramformCancelObject form (formData) (-) The formData.
 * @paramformCancelObject data (PFEInstanceInfo) (-) The process instance information.
 *
 * @extraconfig formCloseObject
 *
 * @paramformCloseObject eventName (string) (bpme-case-action-form-close) The form status close event name
 * @paramformCloseObject form (formData) (-) The formData.
 * @paramformCloseObject data (PFEInstanceInfo) (-) The process instance information.
 *
 * @extraconfig formSubmitObject
 *
 * @paramformSubmitObject eventName (string) (bpme-case-action-form-submit) The form status submit event name
 * @paramformSubmitObject form (formData) (-) The formData.
 * @paramformSubmitObject completed (boolean) (-) The status of form submission.
 * @paramformSubmitObject data (PFEInstanceInfo) (-) The process instance information.
 *
 *
 * @extraconfig formErrorObject
 *
 * @paramformErrorObject detail (formErrorData) (-) The form error data.
 *
 * @slot case-action-form - slot for custom case-action-form
 * @csspart tibco-form-container
 */
export declare class BpmeCaseActionForm extends LitElement {
    static styles: import("lit").CSSResult[];
    /** The caseActionConfig for loading case action form.*/
    details: PFEProcessInfo;
    formDivId: any;
    EVENT_STATUS_CHANGE: string;
    EVENT_FORM_LOAD: string;
    EVENT_FORM_CANCEL: string;
    EVENT_FORM_CLOSE: string;
    EVENT_FORM_SUBMIT: string;
    EVENT_ERROR: string;
    skip: number;
    top: number;
    theEnd: boolean;
    user: null;
    serviceToOpenContext: any;
    sortString: null;
    filter: null;
    ShowOptions: Readonly<{
        OTHER: "OTHER";
        FORM: "FORM";
        BUSY: "BUSY";
    }>;
    show: any;
    showSpinner: boolean;
    selectedWork: any;
    selectedIndex: any;
    ngOnChanges(_changes: any): Promise<void>;
    renderPageflowForm(configPageflow: PFEInstanceInfo): void;
    cancelHandler($event: any): void;
    submitHandler($event: any): void;
    errorHandler(error: any): void;
    loadErrorHandler(error: any): void;
    loadHandler($event: any): void;
    startCaseAction(details: any): void;
    workitems: any;
    willUpdate(changedProperties: PropertyValues<this>): void;
    /**
     * Implement to perform updating tasks.
     * Setting properties inside this method will *not* trigger another update.
     */
    update(changedProps: any): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    start(): Promise<void>;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-action-form": BpmeCaseActionForm;
    }
}
