import { LitElement, PropertyValues } from 'lit';
import { CDCaseInfo, CDTypeInfo } from 'bpme-services-lib/dist/lib/objectapi/cd/api';
import { PFECaseAction } from 'bpme-services-lib/dist/lib/objectapi/pfe/api';
/**
 * @since 1.0.0
 * @status stable
 *
 *
 * @dependency twc-button-group
 * @dependency twc-button
 * @dependency twc-dropdown
 * @dependency twc-icon
 * @dependency twc-menu
 * @dependency twc-menu-item
 *
 * @extraconfig CDCasesPutRequestBodyItem
 * @paramCDCasesPutRequestBodyItem caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCasesPutRequestBodyItem casedata (string) (-) The JSON Case data, serialized to a string
 *
 * @extraconfig CDTypeInfo
 * @paramCDTypeInfo name (string) (-) The name of the Type
 * @paramCDTypeInfo label (string) (-) The label for the Type
 * @paramCDTypeInfo isCase (boolean) (-) Either true for a Case Type, or false for a Structured Type
 * @paramCDTypeInfo namespace (string) (-) The namespace in which the Type is defined
 * @paramCDTypeInfo applicationId (string) (-) The unique identifier of the application in which the Type is defined
 * @paramCDTypeInfo applicationMajorVersion (number) (-) he major version of the application in which the Type is defined
 * @paramCDTypeInfo dependencies (CDTypeInfoDependency[]) (-) Descriptions of data models in other Applications on which this Type depends
 * @paramCDTypeInfo attributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes defined in the Type
 * @paramCDTypeInfo summaryAttributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes that are included in the Case summary for the Type
 * @paramCDTypeInfo states (CDTypeInfoState[]) (-) The definitions of all states defined in the Type
 * @paramCDTypeInfo links (CDTypeInfoLink[]) (-) The definition of all Links defined for the Type
 *
 *
 * @extraconfig CDTypeInfoDependency
 * @paramCDTypeInfoDependency namespace (string) (-) The namespace of the data model in another Application
 * @paramCDTypeInfoDependency applicationId (string) (-) The unique identifier of the other Application
 * @paramCDTypeInfoDependency applicationMajorVersion (number) (-) The major version of the other Application
 *
 * @extraconfig CDTypeInfoAttribute
 * @paramCDTypeInfoAttribute name  (string) (-) The name for the attribute
 * @paramCDTypeInfoAttribute label (string) (-) The label for the attribute
 * @paramCDTypeInfoAttribute type (string) (-) If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'
 * @paramCDTypeInfoAttribute isStructuredType (boolean) (-) If true, this indicates that the value for \'type\' is the name of a Structured Type
 * @paramCDTypeInfoAttribute isIdentifier (boolean) (-) True if the attribute is the Type\'s designated \'identifier\' attribute
 * @paramCDTypeInfoAttribute isAutoIdentifier (boolean) (-) True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case
 * @paramCDTypeInfoAttribute isState (boolean) (-) True if the attribute is the Type\'s designated \'state\' attribute
 * @paramCDTypeInfoAttribute isArray (boolean) (-) True if the attribute is an array
 * @paramCDTypeInfoAttribute isMandatory (boolean) (-) True if the attribute must be populated
 * @paramCDTypeInfoAttribute isSearchable (boolean) (-) True if the attribute is searchable
 * @paramCDTypeInfoAttribute isSummary (boolean) (-) True if the attribute forms part of the Case summary
 * @paramCDTypeInfoAttribute constraints (CDTypeInfoAttributeConstraints) (-) Descriptions of constraints on the permitted values for the attribute
 *
 *
 * @extraconfig CDTypeInfoAttributeConstraints
 * @paramCDTypeInfoAttributeConstraints length (number) (-) The maximum permitted length (only applicable to attributes of the \'Text\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValue (string) (-) The minimum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValueInclusive (boolean) (-) If true, then the value specified in \'minValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints maxValue (string) (-) The maximum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints maxValueInclusive (boolean  ) (-) If true, then the value specified in \'maxValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints decimalPlaces (number) (-) The maximum number of decimal places permitted (only applicable to attributes of the \'FixedPointNumber\' base type)
 *
 *
 *
 * @extraconfig CDTypeInfoState
 * @paramCDTypeInfoState label (string) (-) The label for the state
 * @paramCDTypeInfoState value (string) (-) The value for the state (as it appears within casedata)
 * @paramCDTypeInfoState isTerminal (boolean) (-) True if the state is a \'terminal\' state (one in which a Case is no longer considered active)
 *
 *
 * @extraconfig CDTypeInfoLink
 * @paramCDTypeInfoLink name (string) (-)  The name of the Link
 * @paramCDTypeInfoLink label (string) (-) The label for the Link
 * @paramCDTypeInfoLink type (string) (-) The name of the target Case Type
 * @paramCDTypeInfoLink isArray (boolean) (-) True if the Link is allowed multiple target Cases
 *
 *
 * @extraconfig CDCaseInfo
 *
 * @paramCDCaseInfo caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCaseInfo casedata (string) (-) The JSON Case data, serialized to a string
 * @paramCDCaseInfo summary (string) (-) The JSON Case summary, serialized to a string
 * @paramCDCaseInfo metadata (CDCaseMetadata) (-) The desciption of case meta data.
 *
 * @extraconfig CDCaseMetadata
 *
 * @paramCDCaseMetadata createdBy (string) (-) The GUID for the user that created the Case
 * @paramCDCaseMetadata creationTimestamp (string) (-) The date/time at which the Case was created
 * @paramCDCaseMetadata modifiedBy (string) (-) TThe GUID for the user that last modified the Case
 * @paramCDCaseMetadata modificationTimestamp (string) (-) The date/time at which the Case was last modified
 *
 * @extraconfig PFECaseAction
 *
 * @paramPFECaseAction processId (string) (-) The id of the process
 * @paramPFECaseAction processName (string) (-) The name of the process
 * @paramPFECaseAction processExtName (string) (-) The external name of the process
 * @paramPFECaseAction processLabel (string) (-) Display name of the process configured in studio
 * @paramPFECaseAction processType ( PFECaseActionProcessTypeEnum ) (-) Type of the process pageflow or business service
 * @paramPFECaseAction channelIds ( string[] ) (-) Channels in which the following business services are available
 * @paramPFECaseAction category (string) (-) category of the process
 * @paramPFECaseAction privileges (string[]) (-) privileges of who can access the business services
 * @paramPFECaseAction caseStates (string[]) (-) Case states in which the following business services are available
 * @paramPFECaseAction caseInfo ( PFECaseInfo ) (-) The case info is detail
 * @paramPFECaseAction moduleId (string) (-) The id of the module
 * @paramPFECaseAction moduleName (string) (-) The name of the module
 * @paramPFECaseAction moduleInternalName (string) (-) The internal name of the module
 * @paramPFECaseAction moduleVersion (string) (-) The version number of the module
 *
 * @extraconfig PFECaseActionProcessTypeEnum
 *
 * @paramPFECaseActionProcessTypeEnum Pageflow (string) (PAGEFLOW) The const value
 * @paramPFECaseActionProcessTypeEnum Businessservice (string) (BUSINESSSERVICE) The const value
 * @paramPFECaseActionProcessTypeEnum Caseaction (string) (CASEACTION) The const value
 *
 * @extraconfig PFECaseInfo
 *
 * @paramPFECaseInfo caseClassName (string) (-) Name of the case class
 * @paramPFECaseInfo caseVersion (string) (-) Version of the case
 * @paramPFECaseInfo caseRefParamName (string) (-) Name of the case reference
 *
 * @slot - No slot
 * @csspart base - The component's internal wrapper.
 * @csspart case-action-button-group - The component's action-button wrapper
 * @event { PFECaseAction[] } bpm-case-actions-fetched - Emitted when the list of case actions is fetched for case when it is in a particular state.
 * @event { PFECaseAction } bpm-case-action-selected - Emitted when a case action for case is selected.
 */
export declare class BpmeCaseActions extends LitElement {
    static styles: import("lit").CSSResult[];
    EVENT_DATA: string;
    EVENT_SELECT: string;
    filter: string;
    options: {};
    skip: number;
    top: number;
    theEnd: boolean;
    selectedWorkViewId: number;
    selectedWorkView: any;
    caseActions: any[];
    /** The Selected Case from list of cases of a particular case type to show relevant case actions .*/
    selectedCase: CDCaseInfo;
    disableActions: boolean;
    /** The Selected Case type from the list case types in the system to show relevant case actions .*/
    type: CDTypeInfo;
    actionFormId: string;
    actions: any[];
    config: any;
    stateAttribute: any;
    showForm: boolean;
    processConfig: any;
    processInfo: any;
    formRenderData: any;
    selectedAction: any;
    selectedCaseWatchHandler(newValue: boolean, oldValue: boolean): void;
    /** The method to get list of cases actions of the selected case .*/
    getCaseActions(): void;
    /** The method to reload list of cases actions of the selected case .*/
    refreshCaseActions(): void;
    startCaseActionHandler(event: CustomEvent<any>): void;
    /** The method to start a cases action of the selected case .*/
    start(caseaction: PFECaseAction): void;
    arrayButton: any;
    generateButton(caseaction: any): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
    /**
    * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
    * Setting properties inside this method will *not* trigger another update.
    */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-actions": BpmeCaseActions;
    }
}
