import { LitElement, PropertyValues } from 'lit';
import { CDTypeInfo } from 'bpme-services-lib/dist/lib/objectapi/cd/api';
/**
 * @since 1.0.0
 * @status stable
 *
 * @extraconfig CDTypeInfo
 * @paramCDTypeInfo name (string) (-) The name of the Type
 * @paramCDTypeInfo label (string) (-) The label for the Type
 * @paramCDTypeInfo isCase (boolean) (-) Either true for a Case Type, or false for a Structured Type
 * @paramCDTypeInfo namespace (string) (-) The namespace in which the Type is defined
 * @paramCDTypeInfo applicationId (string) (-) The unique identifier of the application in which the Type is defined
 * @paramCDTypeInfo applicationMajorVersion (number) (-) he major version of the application in which the Type is defined
 * @paramCDTypeInfo dependencies (CDTypeInfoDependency[]) (-) Descriptions of data models in other Applications on which this Type depends
 * @paramCDTypeInfo attributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes defined in the Type
 * @paramCDTypeInfo summaryAttributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes that are included in the Case summary for the Type
 * @paramCDTypeInfo states (CDTypeInfoState[]) (-) The definitions of all states defined in the Type
 * @paramCDTypeInfo links (CDTypeInfoLink[]) (-) The definition of all Links defined for the Type
 *
 *
 * @extraconfig CDTypeInfoDependency
 * @paramCDTypeInfoDependency namespace (string) (-) The namespace of the data model in another Application
 * @paramCDTypeInfoDependency applicationId (string) (-) The unique identifier of the other Application
 * @paramCDTypeInfoDependency applicationMajorVersion (number) (-) The major version of the other Application
 *
 * @extraconfig CDTypeInfoAttribute
 * @paramCDTypeInfoAttribute name  (string) (-) The name for the attribute
 * @paramCDTypeInfoAttribute label (string) (-) The label for the attribute
 * @paramCDTypeInfoAttribute type (string) (-) If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'
 * @paramCDTypeInfoAttribute isStructuredType (boolean) (-) If true, this indicates that the value for \'type\' is the name of a Structured Type
 * @paramCDTypeInfoAttribute isIdentifier (boolean) (-) True if the attribute is the Type\'s designated \'identifier\' attribute
 * @paramCDTypeInfoAttribute isAutoIdentifier (boolean) (-) True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case
 * @paramCDTypeInfoAttribute isState (boolean) (-) True if the attribute is the Type\'s designated \'state\' attribute
 * @paramCDTypeInfoAttribute isArray (boolean) (-) True if the attribute is an array
 * @paramCDTypeInfoAttribute isMandatory (boolean) (-) True if the attribute must be populated
 * @paramCDTypeInfoAttribute isSearchable (boolean) (-) True if the attribute is searchable
 * @paramCDTypeInfoAttribute isSummary (boolean) (-) True if the attribute forms part of the Case summary
 * @paramCDTypeInfoAttribute constraints (CDTypeInfoAttributeConstraints) (-) Descriptions of constraints on the permitted values for the attribute
 *
 *
 * @extraconfig CDTypeInfoAttributeConstraints
 * @paramCDTypeInfoAttributeConstraints length (number) (-) The maximum permitted length (only applicable to attributes of the \'Text\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValue (string) (-) The minimum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValueInclusive (boolean) (-) If true, then the value specified in \'minValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints maxValue (string) (-) The maximum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints maxValueInclusive (boolean  ) (-) If true, then the value specified in \'maxValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints decimalPlaces (number) (-) The maximum number of decimal places permitted (only applicable to attributes of the \'FixedPointNumber\' base type)
 *
 *
 *
 * @extraconfig CDTypeInfoState
 * @paramCDTypeInfoState label (string) (-) The label for the state
 * @paramCDTypeInfoState value (string) (-) The value for the state (as it appears within casedata)
 * @paramCDTypeInfoState isTerminal (boolean) (-) True if the state is a \'terminal\' state (one in which a Case is no longer considered active)
 *
 *
 * @extraconfig CDTypeInfoLink
 * @paramCDTypeInfoLink name (string) (-)  The name of the Link
 * @paramCDTypeInfoLink label (string) (-) The label for the Link
 * @paramCDTypeInfoLink type (string) (-) The name of the target Case Type
 * @paramCDTypeInfoLink isArray (boolean) (-) True if the Link is allowed multiple target Cases
 *
 * @extraconfig caseDataObject
 *
 * @paramcaseDataObject caseData (string | undefined) (-) The casedata of the selected case for a particular case type to show relevant case data
 * @paramcaseDataObject type ( CDTypeInfo ) (-) The selected type.
 *
 * @slot - Component's default slot
 * @event {caseDataObject} bpm-case-data-fetched  - Emitted when the case data is rendered.
 * @csspart tibco-form-container - Component's form wrapper
 */
export default class BpmeCaseData extends LitElement {
    static styles: import("lit").CSSResult[];
    caseInstance?: any;
    /** The selected case type to show relevant case data */
    type: CDTypeInfo;
    /** The casedata of the selected case for a particular case type to show relevant case data */
    caseData?: string;
    overflowHidden: boolean;
    formJSON: any;
    formLocale: string;
    loadIndicator: boolean;
    caseDataWatchHandler(newValue: boolean, oldValue: boolean): void;
    handleCaseInstanceData(): void;
    handleCaseData(): void;
    cancelForm(_eve: any): void;
    loadForm(_eve: any): void;
    formErrorHandler(_error: any): void;
    connectedCallback(): void;
    disconnectedCallback(): void;
    render(): import("lit-html").TemplateResult<1> | undefined;
    /**
    * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
    * Setting properties inside this method will *not* trigger another update.
    */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-data": BpmeCaseData;
    }
}
