import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/icon/icon.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/dialog/dialog.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/divider/divider.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/select/select.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/option/option.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/date/date.js";
import BpmeBaseComponent from '../../internal/bpme-base-component';
import { CDCaseInfo } from "bpme-services-lib/dist/lib/objectapi/cd/api";
/**
 * @since 1.0.0
 * @status stable
 *
 *
 * @extraconfig BPMConfigurationProperty
 * @anyBPMConfigurationProperty detailsConfigProp
 *
 * @paramBPMConfigurationProperty name (string) (-) The name of the config property.
 * @paramBPMConfigurationProperty label (BPMExternalizedText) (-) The label of the config property.
 * @paramBPMConfigurationProperty description (BPMExternalizedText) (-) The description of the config property.
 * @paramBPMConfigurationProperty type ('string' | 'number' | 'boolean') (-) The type of the config property.
 * @paramBPMConfigurationProperty value ('string' | 'number' | 'boolean') (-) The value of the config property.
 * @paramBPMConfigurationProperty defaultValue ('string' | 'number' | 'boolean') (-) The default value of the config property.
 *
 * @extraconfig BPMExternalizedText
 *
 * @paramBPMExternalizedText default (string) (-) The default value of the externalized text.
 * @paramBPMExternalizedText localeKey (string) (-) The locale value of the externalized text.
 *
 * @extraconfig CDCaseInfo
 *
 * @paramCDCaseInfo caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCaseInfo casedata (string) (-) The JSON Case data, serialized to a string
 * @paramCDCaseInfo summary (string) (-) The JSON Case summary, serialized to a string
 * @paramCDCaseInfo metadata (CDCaseMetadata) (-) The desciption of case meta data.
 *
 *
 * @extraconfig CDCaseMetadata
 *
 * @paramCDCaseMetadata createdBy (string) (-) The GUID for the user that created the Case
 * @paramCDCaseMetadata creationTimestamp (string) (-) The date/time at which the Case was created
 * @paramCDCaseMetadata modifiedBy (string) (-) TThe GUID for the user that last modified the Case
 * @paramCDCaseMetadata modificationTimestamp (string) (-) The date/time at which the Case was last modified
 *
 * @extraconfig WRPArtifact
 *
 * @paramWRPArtifact id (string) (-) The internal id of the Artifact (used by the Web Resource Provisioner Service).
 * @paramWRPArtifact name (string) (-) The name (and unique identifier) of the Artifact. For an Application, this name is the full path to the Artifact.
 * @paramWRPArtifact artifactVersion (string) (-) The version of the Artifact.
 * @paramWRPArtifact author (string) (-) The GUID of the User who created the Artifact (by first uploading it).
 * @paramWRPArtifact creationDate (string) (-) The date on which the Artifact was created.
 * @paramWRPArtifact lastModifiedDate (string) (-) The date on which the Artifact was last modified.
 * @paramWRPArtifact lastModifiedBy (string) (-) The GUID of the User who last modified the Artifact.
 * @paramWRPArtifact artifactRef (string) (-) The external reference to the actual Artifact.
 * @paramWRPArtifact artifactCheckSum (string) (-) The checksum used to determine if the Artifact already exists.
 * @paramWRPArtifact ownerApp (string) (-) The id of the Application or Case Folder to which the Artifact belongs.
 * @paramWRPArtifact size (string) (-) The size of the Artifact.
 * @paramWRPArtifact mimeType (string) (-) The MIME type of the Artifact.
 * @paramWRPArtifact description (string) (-) The description of the Artifact.
 *
 * @event { WRPArtifact[] } bpm-case-document-open - Emitted when the case document is open for viewing
 *
 * @csspart base - The component's internal wrapper.
 * @csspart document-details-container - The component's document-details wrapper
 * @csspart document-details - The component's document details
 * @csspart iframe-container - The component's iframe wrapper
**/
export declare class BpmeCaseDocumentsViewer extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** To set the configuration properties to show and hide */
    detailsConfigProp: any;
    /** The Selected document from list of uploaded documents to show preview .*/
    selectedDocument: Document;
    /** The Selected Case from list of cases of a particular case type to show preview of case document .*/
    selectedCase: CDCaseInfo;
    documentVersions: any;
    /**To let the dialog/component to render */
    dialogOpened: boolean;
    dialogClosed: boolean;
    selectedVersion: any;
    location: {
        new (): Location;
        prototype: Location;
    };
    frameURL: any;
    docVersionConfig: any;
    EVENT_FOLDER_ARTIFACTS: string;
    dummyURL: boolean;
    downloadFile(doc: any): string;
    clickDownload(): void;
    getSourceURL(): void;
    versionChanged(event: any): void;
    getDocumentVersions(): void;
    disconnectedCallback(): void;
    getUser(author: string | any, doc: any): void;
    bindData(): any;
    checkConfigStatus(controlName: string): any;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-documents-viewer": BpmeCaseDocumentsViewer;
    }
}
export interface Document {
    id: string;
    name: string;
    artifactVersion: string;
    author: string;
    creationDate: string;
    lastModifiedDate: string;
    lastModifiedBy: string;
    artifactRef: string;
    artifactCheckSum: string;
    ownerApp: string;
    size: string;
    mimeType: string;
    description: string;
    userLabel: string;
}
