import { PropertyValues } from "lit";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/icon/icon.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/dialog/dialog.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/alert-dialog/alert-dialog.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/button/button.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/list-view/list-view.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/list-item/list-item.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/alert/alert.js";
import BpmeBaseComponent from '../../internal/bpme-base-component';
import { CDCaseInfo } from "bpme-services-lib/dist/lib/objectapi/cd/api";
/**
 * @since 1.0.0
 * @status stable
 *
 * @extraconfig BPMConfigurationProperty
 * @anyBPMConfigurationProperty detailsConfigProp
 * @paramBPMConfigurationProperty name (string) (-) The name of the config property.
 * @paramBPMConfigurationProperty label (BPMExternalizedText) (-) The label of the config property.
 * @paramBPMConfigurationProperty description (BPMExternalizedText) (-) The description of the config property.
 * @paramBPMConfigurationProperty type ('string' | 'number' | 'boolean') (-) The type of the config property.
 * @paramBPMConfigurationProperty value ('string' | 'number' | 'boolean') (-) The value of the config property.
 * @paramBPMConfigurationProperty defaultValue ('string' | 'number' | 'boolean') (-) The default value of the config property.
 *
 *
 *
 * @paramBPMExternalizedText default (string) (-) The default value of the externalized text.
 * @paramBPMExternalizedText localeKey (string) (-) The locale value of the externalized text.
 *
 * @extraconfig CDCaseInfo
 *
 * @paramCDCaseInfo caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCaseInfo casedata (string) (-) The JSON Case data, serialized to a string
 * @paramCDCaseInfo summary (string) (-) The JSON Case summary, serialized to a string
 * @paramCDCaseInfo metadata (CDCaseMetadata) (-) The desciption of case meta data.
 *
 *
 * @extraconfig CDCaseMetadata
 *
 * @paramCDCaseMetadata createdBy (string) (-) The GUID for the user that created the Case
 * @paramCDCaseMetadata creationTimestamp (string) (-) The date/time at which the Case was created
 * @paramCDCaseMetadata modifiedBy (string) (-) TThe GUID for the user that last modified the Case
 * @paramCDCaseMetadata modificationTimestamp (string) (-) The date/time at which the Case was last modified
 *
 * @extraconfig WRPArtifact
 *
 * @paramWRPArtifact id (string) (-) The internal id of the Artifact (used by the Web Resource Provisioner Service).
 * @paramWRPArtifact name (string) (-) The name (and unique identifier) of the Artifact. For an Application, this name is the full path to the Artifact.
 * @paramWRPArtifact artifactVersion (string) (-) The version of the Artifact.
 * @paramWRPArtifact author (string) (-) The GUID of the User who created the Artifact (by first uploading it).
 * @paramWRPArtifact creationDate (string) (-) The date on which the Artifact was created.
 * @paramWRPArtifact lastModifiedDate (string) (-) The date on which the Artifact was last modified.
 * @paramWRPArtifact lastModifiedBy (string) (-) The GUID of the User who last modified the Artifact.
 * @paramWRPArtifact artifactRef (string) (-) The external reference to the actual Artifact.
 * @paramWRPArtifact artifactCheckSum (string) (-) The checksum used to determine if the Artifact already exists.
 * @paramWRPArtifact ownerApp (string) (-) The id of the Application or Case Folder to which the Artifact belongs.
 * @paramWRPArtifact size (string) (-) The size of the Artifact.
 * @paramWRPArtifact mimeType (string) (-) The MIME type of the Artifact.
 * @paramWRPArtifact description (string) (-) The description of the Artifact.
 *
 * @extraconfig WRPStatus
 *
 * @paramWRPStatus message (string) (-) Text giving details about the result of the REST call.
 *
 * @slot - The bpme-case-document content.
 *
 * @event { WRPArtifact[] } bpm-case-document-fetched - Emitted when the document is fetched
 *
 * @event { WRPStatus } bpm-case-document-deleted - Emitted when the folder artifact is deleted
 *
 * @csspart base - The component's internal wrapper.
 * @csspart search-upload-container - The component's search-upload wrapper
 * @csspart upload-dialog-wrapper - The component's upload-dialog wrapper
 * @csspart documents-container - The component's documents wrapper
 * @csspart no-documents-wrapper - The component's no-documents wrapper
 * @csspart document-viewer-wrapper - The component's document-viewer wrapper
**/
export declare class BpmeCaseDocuments extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    location: {
        new (): Location;
        prototype: Location;
    };
    /**To set the configuration properties to show and hide for cases documents .*/
    detailsConfigProp: any;
    /** The Selected Case from list of cases of a particular case type to show relevant case documents .*/
    selectedCase: CDCaseInfo;
    documents: any[];
    documentsConfig: any;
    caseFolderConfig: any;
    showSpinner: boolean;
    searchText: string;
    actualSearchedText: string;
    sysConstants: any;
    documentUploadDialog: any;
    documentDeleteDialog: any;
    selectedImageURL: any;
    files: any;
    showSuccess: boolean;
    selectedFile: any;
    spChars: boolean;
    invalidFileExtension: boolean;
    documentViewerWrapper: any;
    selectedDocument: any;
    deleteDocumentSelected: any;
    clearDocumentInChild: boolean;
    dialogOpened: boolean;
    dialogClosed: boolean;
    activateSearchIcon: boolean;
    searchDocumentNoDocShow: boolean;
    searchActive: boolean;
    spinnerBlockShow: boolean;
    EVENT_FOLDER_ARTIFACTS: string;
    EVENT_FOLDER_ARTIFACT_DELETE: string;
    selectedCaseWatchHandler(newValue: boolean, oldValue: boolean): void;
    componentWillLoad(): void;
    openUploadFileDialog(): void;
    getDocuments(): void;
    nextBatch(_$event: any): void;
    refreshDocuments(): void;
    deleteDialog(docName: string): void;
    deleteDocument(docName?: string): void;
    showToastMessage(toastContent: any, messageType: any): void;
    downloadDocumentURL(docName: string, version: string): string;
    getUser(author: string | any, doc: any): void;
    openSelected(_doc: Document): void;
    searchDocuments(e: any): void;
    activateSearch(): void;
    clearSearch(e: any): void;
    getIcon(docName: any): string;
    protected firstUpdated(): void;
    showDocument(event: any): void;
    closeDialog(event: any): void;
    checkConfigStatus(controlName: string): any;
    render(): import("lit-html").TemplateResult<1>;
    /**
     * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
     * Setting properties inside this method will *not* trigger another update.
     */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-documents": BpmeCaseDocuments;
    }
}
