import { PropertyValues } from 'lit';
import { CDCaseInfo, CDTypeInfo } from 'bpme-services-lib/dist/lib/objectapi/cd/api';
import BpmeBaseComponent from '../../internal/bpme-base-component';
/**
 * @since 1.0.0
 * @status stable
 *
 * @extraconfig CDCaseInfo
 *
 * @paramCDCaseInfo caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCaseInfo casedata (string) (-) The JSON Case data, serialized to a string
 * @paramCDCaseInfo summary (string) (-) The JSON Case summary, serialized to a string
 * @paramCDCaseInfo metadata (CDCaseMetadata) (-) The desciption of case meta data.
 *
 *
 * @extraconfig CDCaseMetadata
 *
 * @paramCDCaseMetadata createdBy (string) (-) The GUID for the user that created the Case
 * @paramCDCaseMetadata creationTimestamp (string) (-) The date/time at which the Case was created
 * @paramCDCaseMetadata modifiedBy (string) (-) TThe GUID for the user that last modified the Case
 * @paramCDCaseMetadata modificationTimestamp (string) (-) The date/time at which the Case was last modified
 *
 * @extraconfig CDTypeInfo
 *
 * @paramCDTypeInfo name (string) (-) The name of the Type
 * @paramCDTypeInfo label (string) (-) The label for the Type
 * @paramCDTypeInfo isCase (boolean) (-) Either true for a Case Type, or false for a Structured Type
 * @paramCDTypeInfo namespace (string) (-) The namespace in which the Type is defined
 * @paramCDTypeInfo applicationId (string) (-) The unique identifier of the application in which the Type is defined
 * @paramCDTypeInfo applicationMajorVersion (number) (-) he major version of the application in which the Type is defined
 * @paramCDTypeInfo dependencies (CDTypeInfoDependency[]) (-) Descriptions of data models in other Applications on which this Type depends
 * @paramCDTypeInfo attributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes defined in the Type
 * @paramCDTypeInfo summaryAttributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes that are included in the Case summary for the Type
 * @paramCDTypeInfo states (CDTypeInfoState[]) (-) The definitions of all states defined in the Type
 * @paramCDTypeInfo links (CDTypeInfoLink[]) (-) The definition of all Links defined for the Type
 *
 *
 * @extraconfig CDTypeInfoDependency
 *
 * @paramCDTypeInfoDependency namespace (string) (-) The namespace of the data model in another Application
 * @paramCDTypeInfoDependency applicationId (string) (-) The unique identifier of the other Application
 * @paramCDTypeInfoDependency applicationMajorVersion (number) (-) The major version of the other Application
 *
 * @extraconfig CDTypeInfoAttribute
 *
 * @paramCDTypeInfoAttribute name  (string) (-) The name for the attribute
 * @paramCDTypeInfoAttribute label (string) (-) The label for the attribute
 * @paramCDTypeInfoAttribute type (string) (-) If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'
 * @paramCDTypeInfoAttribute isStructuredType (boolean) (-) If true, this indicates that the value for \'type\' is the name of a Structured Type
 * @paramCDTypeInfoAttribute isIdentifier (boolean) (-) True if the attribute is the Type\'s designated \'identifier\' attribute
 * @paramCDTypeInfoAttribute isAutoIdentifier (boolean) (-) True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case
 * @paramCDTypeInfoAttribute isState (boolean) (-) True if the attribute is the Type\'s designated \'state\' attribute
 * @paramCDTypeInfoAttribute isArray (boolean) (-) True if the attribute is an array
 * @paramCDTypeInfoAttribute isMandatory (boolean) (-) True if the attribute must be populated
 * @paramCDTypeInfoAttribute isSearchable (boolean) (-) True if the attribute is searchable
 * @paramCDTypeInfoAttribute isSummary (boolean) (-) True if the attribute forms part of the Case summary
 * @paramCDTypeInfoAttribute constraints (CDTypeInfoAttributeConstraints) (-) Descriptions of constraints on the permitted values for the attribute
 *
 *
 * @extraconfig CDTypeInfoAttributeConstraints
 *
 * @paramCDTypeInfoAttributeConstraints length (number) (-) The maximum permitted length (only applicable to attributes of the \'Text\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValue (string) (-) The minimum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValueInclusive (boolean) (-) If true, then the value specified in \'minValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints maxValue (string) (-) The maximum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints maxValueInclusive (boolean  ) (-) If true, then the value specified in \'maxValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints decimalPlaces (number) (-) The maximum number of decimal places permitted (only applicable to attributes of the \'FixedPointNumber\' base type)
 *
 *
 *
 * @extraconfig CDTypeInfoState
 *
 * @paramCDTypeInfoState label (string) (-) The label for the state
 * @paramCDTypeInfoState value (string) (-) The value for the state (as it appears within casedata)
 * @paramCDTypeInfoState isTerminal (boolean) (-) True if the state is a \'terminal\' state (one in which a Case is no longer considered active)
 *
 *
 * @extraconfig CDTypeInfoLink
 *
 * @paramCDTypeInfoLink name (string) (-)  The name of the Link
 * @paramCDTypeInfoLink label (string) (-) The label for the Link
 * @paramCDTypeInfoLink type (string) (-) The name of the target Case Type
 * @paramCDTypeInfoLink isArray (boolean) (-) True if the Link is allowed multiple target Cases
 *
 * @extraconfig CDLink
 *
 * @paramCDLink name (string) (-) The name of the Link (as defined in the Case Type of the target Case).
 * @paramCDLink caseReference (string) (-) The Case Reference of the target Case for this Link, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}.
 *
 * @slot - The bpme-linked-cases content.
 * @event { CDLink[] }  bpme-case-linked-cases-select - Emitted when the linked case selected
 *
 * @event { CDLink[] } bpme-case-linked-cases-data - Emitted when the case linked cases are available.
 *
 * @event { CDCaseInfo[] } bpme-case-linked-cases-info - Emitted when the case linked cases info is available.
 *
 * @event { CDTypeInfo[] } bpme-case-linked-cases-types - Emitted when the case linked cases types are available.
 *
 * @csspart base - The component's internal wrapper.
 * @csspart linked-cases-container - The component's linked-cases wrapper
 * @csspart empty-label - The component's empty-label wrapper
**/
export declare class BpmeCaseLinkedCases extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** The Selected Case from list of cases of a particular case type to show relevant linked cases .*/
    selectedCase: CDCaseInfo;
    /** The Selected Case type from the list case types in the system to show relevant linked cases .*/
    type: CDTypeInfo;
    linkedCases: any[];
    linkedCasesConfig: any;
    selectedLinkedCase: any;
    sCaseRef: string[];
    showSpinner: boolean;
    nameSpaceTypes: any[];
    dCases: any[];
    EVENT_DATA: string;
    EVENT_LINKED_CASES_INFO: string;
    EVENT_LINKED_CASES_TYPES: string;
    EVENT_SELECT: string;
    selectedCaseWatchHandler(): void;
    getLinkedCases(): void;
    nextBatch(_$event: any): void;
    selectLinkedCase(event: any): void;
    debounce(func: any, timeout?: number): (...args: any[]) => void;
    processChange: (...args: any[]) => void;
    componentWillLoad(): void;
    getNamespaceTypes(): void;
    refresh(): void;
    render(): import("lit-html").TemplateResult<1>;
    /**
    * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
    * Setting properties inside this method will *not* trigger another update.
    */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-linked-cases": BpmeCaseLinkedCases;
    }
}
