import { PropertyValues } from "lit";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/icon/icon.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/tooltip/tooltip.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/progress/progress.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/progress-state/progress-state.js";
import BpmeBaseComponent from '../../internal/bpme-base-component';
import { CDTypeInfoAttribute, CDTypeInfoState } from "bpme-services-lib/dist/lib/objectapi/cd/api";
/**
 * @since 1.0.0
 * @status stable
 *
 * @slot - The bpme-case-states content.
 *
 * @extraconfig CDTypeInfoState
 * @paramCDTypeInfoState label (string) (-) The label for the state
 * @paramCDTypeInfoState value (string) (-) The value for the state (as it appears within casedata)
 * @paramCDTypeInfoState isTerminal (boolean) (-) True if the state is a \'terminal\' state (one in which a Case is no longer considered active)
 *
 * @extraconfig CDTypeInfoAttribute
 * @paramCDTypeInfoAttribute name  (string) (-) The name for the attribute
 * @paramCDTypeInfoAttribute label (string) (-) The label for the attribute
 * @paramCDTypeInfoAttribute type (string) (-) If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'
 * @paramCDTypeInfoAttribute isStructuredType (boolean) (-) If true, this indicates that the value for \'type\' is the name of a Structured Type
 * @paramCDTypeInfoAttribute isIdentifier (boolean) (-) True if the attribute is the Type\'s designated \'identifier\' attribute
 * @paramCDTypeInfoAttribute isAutoIdentifier (boolean) (-) True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case
 * @paramCDTypeInfoAttribute isState (boolean) (-) True if the attribute is the Type\'s designated \'state\' attribute
 * @paramCDTypeInfoAttribute isArray (boolean) (-) True if the attribute is an array
 * @paramCDTypeInfoAttribute isMandatory (boolean) (-) True if the attribute must be populated
 * @paramCDTypeInfoAttribute isSearchable (boolean) (-) True if the attribute is searchable
 * @paramCDTypeInfoAttribute isSummary (boolean) (-) True if the attribute forms part of the Case summary
 * @paramCDTypeInfoAttribute constraints (CDTypeInfoAttributeConstraints) (-) Descriptions of constraints on the permitted values for the attribute
 *
 * @extraconfig ECAuditEntry
 *
 * @paramECAuditEntry eventId (string) (-) The unique identifier of the AuditEntry
 * @paramECAuditEntry messageId (string) (-) The identifier of the audit message
 * @paramECAuditEntry message (string) (-) The audit message
 * @paramECAuditEntry severity (ECAuditEntrySeverityEnum) (-) The severity of the AuditEntry.
 * @paramECAuditEntry creationTime (string) (-) The time at which the AuditEntry was created (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry managedObjectId (string) (-) The managed object identifier.
 * @paramECAuditEntry principalId (string) (-) The principal identifier.
 * @paramECAuditEntry principalName (string) (-) The principal name.
 * @paramECAuditEntry managedObjectName (string) (-) The managed object name.
 * @paramECAuditEntry managedObjectVersion (string) (-) TThe managed object version.
 * @paramECAuditEntry managedObjectType (string) (-) The managed object type.
 * @paramECAuditEntry managedObjectStatus (string) (-) The managed object status.
 * @paramECAuditEntry managedObjectUrl (string) (-) The managed object URL.
 * @paramECAuditEntry managedObjectDetails (string) (-) The managed object details.
 * @paramECAuditEntry parentObjectId (string) (-) The parent object identifier.
 * @paramECAuditEntry applicationName (string) (-) The Application name.
 * @paramECAuditEntry workItemScheduleStart (string) (-) The time at which the Work Item schedule was started (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry workItemScheduleEnd (string) (-) The time at which the Work Item schedule was ended (as an ISO8601 formatted DateTime string).
 * @paramECAuditEntry entities (string) (-) The Work Item entities.
 * @paramECAuditEntry workItemPriority (string) (-) TThe Work Item priority.
 * @paramECAuditEntry extendedMessage (string) (-) The extended message.
 * @paramECAuditEntry retryTime (string) (-) The retry time.
 * @paramECAuditEntry resourceId (string) (-) The resource identifier.
 * @paramECAuditEntry resourceName (string) (-) The resource name.
 * @paramECAuditEntry entityId (string) (-) The entity identifier.
 * @paramECAuditEntry entityType (string) (-) The entity type.
 * @paramECAuditEntry channelId (string) (-) The channel identifier.
 * @paramECAuditEntry applicationActivityName (string) (-) The Application activity name.
 * @paramECAuditEntry applicationActivityModelId (string) (-) The Application activity model identifier.
 * @paramECAuditEntry applicationActivityInstanceId (string) (-) The Application activity identifier.
 * @paramECAuditEntry systemActionComponentId (string) (-) The system action component identifier.
 * @paramECAuditEntry systemActionId (string) (-) The system action identifier.
 * @paramECAuditEntry rootProcessInstanceId (string) (-) The root Process Instance identifier.
 * @paramECAuditEntry parentProcessInstanceId (string) (-) The parent Process Instance identifier.
 * @paramECAuditEntry parentActivityInstanceId (string) (-) The parent activity instance identifier.
 * @paramECAuditEntry subprocessInstanceId (string) (-) The sub-process instance identifier.
 * @paramECAuditEntry subprocessName (string) (-) The sub-process name.
 * @paramECAuditEntry processPriority (string) (-) The process priority.
 * @paramECAuditEntry moduleName (string) (-) The module name.
 * @paramECAuditEntry priorStepId (string) (-) The prior step identifier.
 * @paramECAuditEntry subprocessVersion (string) (-) The sub-process version.
 * @paramECAuditEntry modelMajorVersion (string) (-) The model major version.
 * @paramECAuditEntry modelVersion (string) (-) The model version.
 * @paramECAuditEntry roleName (string) (-) The name of the role.
 * @paramECAuditEntry iteration (string) (-) The iteration.
 * @paramECAuditEntry iterationId (string) (-) The iteration identifier.
 * @paramECAuditEntry hostTaskName (string) (-) The host task name.
 * @paramECAuditEntry hostTaskType (string) (-) The host task type.
 * @paramECAuditEntry interruptsMainFlow (string) (-) The interrupts main flow.
 * @paramECAuditEntry caseReferences (string[]) (-) The array of case references.
 * @paramECAuditEntry genericAttributes (ECGenericAttribute[]) (-) Generic attributes
 * @paramECAuditEntry additionalAttributes (ECAdditionalAttribute[]) (-) Additional attributes
 *
 * @extraconfig ECAuditEntrySeverityEnum
 *
 * @paramECAuditEntrySeverityEnum Debug (string) (Debug) The const value
 * @paramECAuditEntrySeverityEnum Service (string) (Service) The const value
 * @paramECAuditEntrySeverityEnum Info (string) (Info) The const value
 * @paramECAuditEntrySeverityEnum Audit (string) (Audit) The const value
 * @paramECAuditEntrySeverityEnum Warn (string) (Warn) The const value
 * @paramECAuditEntrySeverityEnum Error (string) (Error) The const value
 * @paramECAuditEntrySeverityEnum Trace (string) (Trace) The const value
 * @paramECAuditEntrySeverityEnum Fatal (string) (Fatal) The const value
 *
 * @extraconfig ECGenericAttribute
 *
 * @paramECGenericAttribute name (string) (-) The attribute name
 * @paramECGenericAttribute value (string) (-) The value of the attribute (as a string)
 * @paramECGenericAttribute type (ECGenericAttributeTypeEnum) (-) The type of the attribute. (This is only valid for retrieved data, not when creating events.)
 *
 * @extraconfig ECGenericAttributeTypeEnum
 *
 * @paramECGenericAttributeTypeEnum Date (Date) (-) The const value
 * @paramECGenericAttributeTypeEnum Integer (Integer) (-) The const value
 * @paramECGenericAttributeTypeEnum String (string) (-) The const value
 * @paramECGenericAttributeTypeEnum Boolean (boolean) (-) The const value
 * @paramECGenericAttributeTypeEnum Long (Long) (-) The const value
 * @paramECGenericAttributeTypeEnum Double (Double) (-) The const value
 * @paramECGenericAttributeTypeEnum BigDecimal (BigDecimal) (-) The const value
 *
 * @extraconfig ECAdditionalAttribute
 *
 * @paramECAdditionalAttribute name (string) (-) The attribute name
 * @paramECAdditionalAttribute value (sring) (-) The value of the attribute (as a string)
 *
 * @event { ECAuditEntry[] } bpm-case-states-fetched - Emitted when the passed states of a selected case are fetched.
 * @event { ECAdditionalAttribute.value[] } bpme-audit-message - Emitted when the audit data is fetched
 *
 * @csspart base - The component's internal wrapper.
 * @csspart case-states - The component's case-states
 */
export declare class BpmeCaseStates extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** The states of the selected case type */
    states: CDTypeInfoState[];
    /** The casedata of the selected case for a particular case type  */
    casedata: string;
    /** The attributes of the selected case type */
    stateAttribute: CDTypeInfoAttribute;
    /** The case reference of the selected case for a particular case type */
    caseReference: string;
    currentState: any;
    showMoreStates: boolean;
    sortedStates: any[];
    passedStates: string[];
    EVENT_DATA: string;
    STATE_DATA: string;
    casedataWatchHandler(newValue: boolean, oldValue: boolean): void;
    statesWatchHandler(newValue: boolean, oldValue: boolean): void;
    private sortStates;
    toggleMoreStates(): void;
    getAuditMessages(): void;
    isPassedState(sName: string): boolean;
    isCurrentState(sName: any): boolean;
    /** The method to reload case states.  */
    refresh(): void;
    render(): import("lit-html").TemplateResult<1>;
    /**
     * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
     * Setting properties inside this method will *not* trigger another update.
     */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-states": BpmeCaseStates;
    }
}
