import { PropertyValues } from "lit";
import BpmeBaseComponent from '../../internal/bpme-base-component';
/**
 * @since 1.0.0
 * @status stable
 *
 * @extraconfig BRMWorkListItem
 *
 * @paramBRMWorkListItem id (string) (-) Unique identity of the Work Item.
 * @paramBRMWorkListItem version (string) (-) Version of the Work Item.
 * @paramBRMWorkListItem header (BRMHeader) (-) Header of the Work Item.
 * @paramBRMWorkListItem state (BRMState) (-) State of the Work Item.
 * @paramBRMWorkListItem attributes (BRMWorkListAttributes) (-) The Work List Attributes. These are the 40 attributes into which data can be mapped for the purpose of sorting and filtering Work Lists.
 * @paramBRMWorkListItem visible (boolean) (-) Indicates whether the Work Item is visible.
 *
 *
 *
 * @extraconfig BRMHeader
 *
 * @paramBRMHeader distributionStrategy (BRMDistributionStrategy) (-) Distribution strategy to be used for the Work Item.
 * @paramBRMHeader priority (number) (-) Priority of the Work Item.
 * @paramBRMHeader groupId (string) (-) Identity of the Group that the Work Item belongs to.
 * @paramBRMHeader startDate (string) (-) Date / time from which work on this Work Item may start.
 * @paramBRMHeader endDate (string) (-) Date / time by which work on this Work Item must be completed.
 * @paramBRMHeader name (string) (-) Name of the Work Item.
 * @paramBRMHeader description (string) (-) Textual description of the Work Item.
 * @paramBRMHeader flags (BRMFlags) (-) Flags set against the Work Item.
 * @paramBRMHeader itemContext (BRMItemContext) (-) Context of the Work Item.
 * @paramBRMHeader userId (string) (-) The user that is opening the Work Item.
 * @paramBRMHeader workType (BRMWorkType) (-) Details of the Work Type this item uses.
 *
 * @extraconfig BRMDistributionStrategy
 *
 * @paramBRMDistributionStrategy stringKey (BRMDistributionStrategyStringKeyEnum<'WMdsOffer' | 'WMdsAllocate'>) (-) The string key used in the relevant language pack.
 * @paramBRMDistributionStrategy description (string) (-) English description/version of the string.
 *
 * @extraconfig BRMFlags
 *
 * @paramBRMFlags scheduleStatus (BRMScheduleStatus) (-) Enumerated value defining whether a Work Item is within its schedule period.
 *
 * @extraconfig BRMScheduleStatus
 *
 * @paramBRMScheduleStatus stringKey (BRMScheduleStatusStringKeyEnum <'WMschedStatusNoSchedule' | 'WMschedStatusBefore' | 'WMschedStatusDuring' | 'WMschedStatusAfter'>) (-) The string key used in the relevant language pack.
 * @paramBRMScheduleStatus description (string) (-) English description/version of the string.
 *
 * @extraconfig BRMItemContext
 *
 * @paramBRMItemContext activityId (string) (-) Identity of the activity from which the Work Item was generated.
 * @paramBRMItemContext activityName (string) (-) Name of the activity from which the Work Item was generated.
 * @paramBRMItemContext appInstance (string) (-) Identifier of the Application Instance.
 * @paramBRMItemContext appName (string) (-) Name of the Application.
 * @paramBRMItemContext appVersion (string) (-) Version of the Application.
 * @paramBRMItemContext appId (string) (-) Identity of the Application.
 * @paramBRMItemContext appInstanceDescription (string) (-) Description of the Application Instance.
 * @paramBRMItemContext processName (string) (-) Name of the process.
 * @paramBRMItemContext caseRef (string) (-) The case reference associated with a Work Item.
 *
 * @extraconfig BRMWorkType
 *
 * @paramBRMWorkType uid (string) (-) The unique ID (GUID) of the Work Type.
 * @paramBRMWorkType version (string) (-) The version of the Work Type expressed as a string (for example, 1.0.0.qualifier).
 *
 *
 * @extraconfig BRMState
 *
 * @paramBRMState stringKey (BRMStateStringKeyEnum <'WMstateAllocate' | 'WMstateAllocated' | 'WMstateCancelled' | 'WMstateClose' | 'WMstateComplete' | 'WMstateCompleted' | 'WMstateCreated' | 'WMstateOffered' | 'WMstateOpen' | 'WMstateOpened' | 'WMstatePend' | 'WMstatePended' | 'WMstatePendHidden' | 'WMstateReallocate' | 'WMstateReallocateRevert' | 'WMstateSave' | 'WMstateSkip' | 'WMstateSuspended' | 'WMstateUnallocate'>) (-) The string key used in the relevant language pack.
 * @paramBRMState description (string) (-) Name of the data field.
 *
 *
 *
 * @extraconfig BRMWorkListAttributes
 *
 * @paramBRMWorkListAttributes attribute1 (number) (-) The Work List Attribute 1.
 * @paramBRMWorkListAttributes attribute2 (string) (-) The Work List Attribute 2.
 * @paramBRMWorkListAttributes attribute3 (string) (-) The Work List Attribute 3.
 * @paramBRMWorkListAttributes attribute4 (string) (-) The Work List Attribute 4.
 * @paramBRMWorkListAttributes attribute5 (number) (-) The Work List Attribute 5.
 * @paramBRMWorkListAttributes attribute6 (string) (-) The Work List Attribute 6.
 * @paramBRMWorkListAttributes attribute7 (string) (-) The Work List Attribute 7.
 * @paramBRMWorkListAttributes attribute8 (string) (-) The Work List Attribute 8.
 * @paramBRMWorkListAttributes attribute9 (string) (-) The Work List Attribute 9.
 * @paramBRMWorkListAttributes attribute10 (string) (-) The Work List Attribute 10.
 * @paramBRMWorkListAttributes attribute11 (string) (-) The Work List Attribute 11.
 * @paramBRMWorkListAttributes attribute12 (string) (-) The Work List Attribute 12.
 * @paramBRMWorkListAttributes attribute13 (string) (-) The Work List Attribute 13.
 * @paramBRMWorkListAttributes attribute14 (string) (-) The Work List Attribute 14.
 * @paramBRMWorkListAttributes attribute15 (number) (-) The Work List Attribute 15.
 * @paramBRMWorkListAttributes attribute16 (number) (-) The Work List Attribute 16.
 * @paramBRMWorkListAttributes attribute17 (number) (-) The Work List Attribute 17.
 * @paramBRMWorkListAttributes attribute18 (number) (-) The Work List Attribute 18.
 * @paramBRMWorkListAttributes attribute19 (string) (-) The Work List Attribute 19.
 * @paramBRMWorkListAttributes attribute20 (string) (-) The Work List Attribute 20.
 * @paramBRMWorkListAttributes attribute21 (string) (-) The Work List Attribute 21.
 * @paramBRMWorkListAttributes attribute22 (string) (-) The Work List Attribute 22.
 * @paramBRMWorkListAttributes attribute23 (string) (-) The Work List Attribute 23.
 * @paramBRMWorkListAttributes attribute24 (string) (-) The Work List Attribute 24.
 * @paramBRMWorkListAttributes attribute25 (string) (-) The Work List Attribute 25.
 * @paramBRMWorkListAttributes attribute26 (string) (-) The Work List Attribute 26.
 * @paramBRMWorkListAttributes attribute27 (string) (-) The Work List Attribute 27.
 * @paramBRMWorkListAttributes attribute28 (string) (-) The Work List Attribute 28.
 * @paramBRMWorkListAttributes attribute29 (string) (-) The Work List Attribute 29.
 * @paramBRMWorkListAttributes attribute30 (string) (-) The Work List Attribute 30.
 * @paramBRMWorkListAttributes attribute31 (string) (-) The Work List Attribute 31.
 * @paramBRMWorkListAttributes attribute32 (string) (-) The Work List Attribute 32.
 * @paramBRMWorkListAttributes attribute33 (string) (-) The Work List Attribute 33.
 * @paramBRMWorkListAttributes attribute34 (string) (-) The Work List Attribute 34.
 * @paramBRMWorkListAttributes attribute35 (string) (-) The Work List Attribute 35.
 * @paramBRMWorkListAttributes attribute36 (string) (-) The Work List Attribute 36.
 * @paramBRMWorkListAttributes attribute37 (string) (-) The Work List Attribute 37.
 * @paramBRMWorkListAttributes attribute38 (string) (-) The Work List Attribute 38.
 * @paramBRMWorkListAttributes attribute39 (string) (-) The Work List Attribute 39.
 * @paramBRMWorkListAttributes attribute40 (string) (-) The Work List Attribute 40.
 *
 * @event { BRMWorkListItem.header.name } bpme-case-work-items-selected - Emitted when the work item is selected
 * @event { BRMWorkListItem[] } bpme-case-work-items-fetched - Emitted when the work items are fetched
 *
 * @csspart base - The component's internal wrapper.
 */
export declare class BpmeCaseWorkItems extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** The  case reference of the selected Case from list of cases of a particular case type to show relevant work items .*/
    caseref: string;
    workitems: any;
    EVENT_DATA: string;
    EVENT_SELECT: string;
    EVENT_SHOW_FORM: string;
    EVENT_FORM_CANCEL: string;
    EVENT_FORM_CLOSE: string;
    EVENT_FORM_SUBMIT: string;
    skip: number;
    top: number;
    theEnd: boolean;
    user: null;
    showSpinner: boolean;
    selectedWorkitems: never[];
    selectedWorkItemIndex: any;
    getWorkitems(): void;
    priorityLevel: any;
    getPriority(priority: any): string;
    getRemainTime(end: any): {};
    select(work: any): void;
    ngOnChanges(_changes: any): Promise<void>;
    onScroll(): void;
    /** The method to reload the work-items list of a selected case */
    refreshWorklist(): void;
    caserefWatchHandler(newValue: boolean, oldValue: boolean): void;
    componentWillLoad(): void;
    upperCase(name: any): any;
    onTypeSelectNew(e: any): void;
    listItemRender(i: any): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
    /**
     * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
     * Setting properties inside this method will *not* trigger another update.
     */
    updated(changedProps: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-case-work-items": BpmeCaseWorkItems;
    }
}
