import { PropertyValues } from 'lit';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/table/table.js';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/dropdown/dropdown.js';
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/skeleton/skeleton.js";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/header/header.js";
import BpmeBaseComponent from '../../internal/bpme-base-component';
import { CDTypeInfo } from 'bpme-services-lib/dist/lib/objectapi/cd/api';
import { BPMConfigurationProperty } from 'bpme-services-lib/dist/lib/bpm-contexts/model/bpm-configuration-context';
/**
 * @since 1.0.0
 * @status stable
 *
 * @dependency twc-table
 * @dependency twc-dropdown
 * @dependency bpme-cases-column-selector-dialog
 * @dependency twc-date
 * @dependency twc-header
 * @dependency twc-input
 * @dependency twc-icon
 * @dependency twc-toolbar
 * @dependency twc-toolbar-group
 * @dependency twc-toolbar-item
 * @dependency twc-divider
 * @dependency twc-card
 * @dependency twc-button
 * @dependency twc-icon-button
 * @dependency twc-select
 * @dependency twc-option
 * @dependency twc-tag
 * @dependency twc-skeleton
 * @dependency bpme-infinite-scroll
 *
 *
 * @extraconfig config
 * @anyconfig config
 * @paramconfig skip (number) (0) The value from where to load the results for case-types.
 * @paramconfig top (number) (30) The value till where to load the results from skip value.
 * @paramconfig search (string) ('') To search the from the list of cases.
 * @paramconfig filter ({caseType, applicationMajorVersion, isInTerminalState, caseState, modificationTimestamp ,caseReference }) ({}) This is optional value to get the list of cases in case case type is not given to load the list of cases.
 *
 * @extraconfig CDTypeInfo
 * @paramCDTypeInfo name (string) (-) The name of the Type
 * @paramCDTypeInfo label (string) (-) The label for the Type
 * @paramCDTypeInfo isCase (boolean) (-) Either true for a Case Type, or false for a Structured Type
 * @paramCDTypeInfo namespace (string) (-) The namespace in which the Type is defined
 * @paramCDTypeInfo applicationId (string) (-) The unique identifier of the application in which the Type is defined
 * @paramCDTypeInfo applicationMajorVersion (number) (-) he major version of the application in which the Type is defined
 * @paramCDTypeInfo dependencies (CDTypeInfoDependency[]) (-) Descriptions of data models in other Applications on which this Type depends
 * @paramCDTypeInfo attributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes defined in the Type
 * @paramCDTypeInfo summaryAttributes (CDTypeInfoAttribute[]) (-) The definitions of all attributes that are included in the Case summary for the Type
 * @paramCDTypeInfo states (CDTypeInfoState[]) (-) The definitions of all states defined in the Type
 * @paramCDTypeInfo links (CDTypeInfoLink[]) (-) The definition of all Links defined for the Type
 *
 *
 * @extraconfig CDTypeInfoDependency
 * @paramCDTypeInfoDependency namespace (string) (-) The namespace of the data model in another Application
 * @paramCDTypeInfoDependency applicationId (string) (-) The unique identifier of the other Application
 * @paramCDTypeInfoDependency applicationMajorVersion (number) (-) The major version of the other Application
 *
 * @extraconfig CDTypeInfoAttribute
 * @paramCDTypeInfoAttribute name  (string) (-) The name for the attribute
 * @paramCDTypeInfoAttribute label (string) (-) The label for the attribute
 * @paramCDTypeInfoAttribute type (string) (-) If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'
 * @paramCDTypeInfoAttribute isStructuredType (boolean) (-) If true, this indicates that the value for \'type\' is the name of a Structured Type
 * @paramCDTypeInfoAttribute isIdentifier (boolean) (-) True if the attribute is the Type\'s designated \'identifier\' attribute
 * @paramCDTypeInfoAttribute isAutoIdentifier (boolean) (-) True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case
 * @paramCDTypeInfoAttribute isState (boolean) (-) True if the attribute is the Type\'s designated \'state\' attribute
 * @paramCDTypeInfoAttribute isArray (boolean) (-) True if the attribute is an array
 * @paramCDTypeInfoAttribute isMandatory (boolean) (-) True if the attribute must be populated
 * @paramCDTypeInfoAttribute isSearchable (boolean) (-) True if the attribute is searchable
 * @paramCDTypeInfoAttribute isSummary (boolean) (-) True if the attribute forms part of the Case summary
 * @paramCDTypeInfoAttribute constraints (CDTypeInfoAttributeConstraints) (-) Descriptions of constraints on the permitted values for the attribute
 *
 *
 * @extraconfig CDTypeInfoAttributeConstraints
 * @paramCDTypeInfoAttributeConstraints length (number) (-) The maximum permitted length (only applicable to attributes of the \'Text\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValue (string) (-) The minimum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints minValueInclusive (boolean) (-) If true, then the value specified in \'minValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints maxValue (string) (-) The maximum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types)
 * @paramCDTypeInfoAttributeConstraints maxValueInclusive (boolean  ) (-) If true, then the value specified in \'maxValue\' is inclusive. (If false or not set, the value is exclusive)
 * @paramCDTypeInfoAttributeConstraints decimalPlaces (number) (-) The maximum number of decimal places permitted (only applicable to attributes of the \'FixedPointNumber\' base type)
 *
 *
 *
 * @extraconfig CDTypeInfoState
 * @paramCDTypeInfoState label (string) (-) The label for the state
 * @paramCDTypeInfoState value (string) (-) The value for the state (as it appears within casedata)
 * @paramCDTypeInfoState isTerminal (boolean) (-) True if the state is a \'terminal\' state (one in which a Case is no longer considered active)
 *
 *
 * @extraconfig CDTypeInfoLink
 * @paramCDTypeInfoLink name (string) (-)  The name of the Link
 * @paramCDTypeInfoLink label (string) (-) The label for the Link
 * @paramCDTypeInfoLink type (string) (-) The name of the target Case Type
 * @paramCDTypeInfoLink isArray (boolean) (-) True if the Link is allowed multiple target Cases
 *
 *
 * @extraconfig BPMConfigurationProperty
 *
 * @paramBPMConfigurationProperty name (string) (-) The name of the config property.
 * @paramBPMConfigurationProperty label (BPMExternalizedText) (-) The label of the config property.
 * @paramBPMConfigurationProperty description (BPMExternalizedText) (-) The description of the config property.
 * @paramBPMConfigurationProperty type ('string' | 'number' | 'boolean') (-) The type of the config property.
 * @paramBPMConfigurationProperty value ('string' | 'number' | 'boolean') (-) The value of the config property.
 * @paramBPMConfigurationProperty defaultValue ('string' | 'number' | 'boolean') (-) The default value of the config property.
 *
 * @extraconfig CDCaseInfo
 *
 * @paramCDCaseInfo caseReference (string) (-) The Case Reference of the Case to be updated, in the form {id}-{namespace}.{caseTypeName}-{applicationMajorVersion}-{version}. For example:        101-com.example.ordermodel-Order-1-7
 * @paramCDCaseInfo casedata (string) (-) The JSON Case data, serialized to a string
 * @paramCDCaseInfo summary (string) (-) The JSON Case summary, serialized to a string
 * @paramCDCaseInfo metadata (CDCaseMetadata) (-) The desciption of case meta data.
 *
 *
 * @extraconfig CDCaseMetadata
 *
 * @paramCDCaseMetadata createdBy (string) (-) The GUID for the user that created the Case
 * @paramCDCaseMetadata creationTimestamp (string) (-) The date/time at which the Case was created
 * @paramCDCaseMetadata modifiedBy (string) (-) TThe GUID for the user that last modified the Case
 * @paramCDCaseMetadata modificationTimestamp (string) (-) The date/time at which the Case was last modified
 *
 * @slot - The bpme-case's content.
 * @event { CDCaseInfo[] } bpm-cases-fetched - Emitted when the list of cases of a case type is fetched.
 * @event { CDCaseInfo } bpm-case-selected - Emitted when any case from the list of cases is selected .
 *
 * @csspart base - The component's internal wrapper.
 * @csspart cases-header - The component's cases-header wrapper
 * @csspart case-action-block - The component's case-action-block wrapper
 * @csspart case-table-container - The component's case-table wrapper
 * @csspart chips-widget - The component's chips-widget wrapper
 * @csspart empty-illustration - The component's empty-illustration wrapper
 */
export default class BpmeCases extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** Case type reference to show the list of cases .*/
    type: CDTypeInfo;
    cardFilter: any;
    /** To set the configuration properties to show and hide for list of cases .*/
    configProperties: BPMConfigurationProperty[];
    /** The default config to show the list of cases of a case type .*/
    config: any;
    columnselectorDialog: any;
    currentDate: any;
    EVENT_DATA: string;
    EVENT_SELECT: string;
    cases: any;
    caseTypeSummary: any;
    caseTypeState: any;
    tableColumns: any;
    displayColumns: any;
    defaultColumns: any;
    indexShowArray: any;
    actualSearchedText: any;
    showSearchWidget: boolean;
    showfilterWidget: boolean;
    selectedDate: any;
    dataValue: any;
    caseStateFilter: any;
    showChipsWidget: boolean;
    columnData: any;
    displayedColumns: any;
    select(casei: any): void;
    handleCasesData(event: any): void;
    showSpinner: boolean;
    /** The method to get list of cases of a case type .*/
    getCases(): void;
    isObjectEmpty(objectName: any): any;
    retrieveAttributes(): void;
    setSelectedColumns(): void;
    nextBatch(_$event: any): void;
    /** The method to reload the list of cases of a case type .*/
    refresh(): void;
    showSearchCases(): void;
    handleDocumentKeyDown(event: KeyboardEvent): void;
    handleDocumentMouseDown(event: MouseEvent): void;
    compareDates(d1: any, d2: any): "is less than" | "is greater than" | "is equal";
    showFilter(): void;
    bindCurrentData(value: any): any;
    closeFilterWidget(): void;
    handleFilter(showChips: boolean): void;
    setFilterConfig(e: any): void;
    searchCases(e: any): void;
    checkConfigStatus(controlName: string): any;
    inputDateFocus(e: any): void;
    clearAllFilter(): void;
    removeFilter(e: any): void;
    emptyText(): import("lit-html").TemplateResult<1>;
    setColumnSelector(event: any): void;
    columnSelectorHandler(event: any): void;
    onScroll(): void;
    showData(casei: any, column: any): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
    updated(changedProperties: PropertyValues): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-cases": BpmeCases;
    }
}
