import { bpmcontext } from "bpme-services-lib";
import { LitElement, PropertyValues } from "lit";
/**
 * @since 1.0.0
 * @status stable
 *
 * @extraconfig BPMLanguage
 *
 * @paramBPMLanguage language (string) (-) Name of the language.
 * @paramBPMLanguage languageData (string) (-) Data related to the language.
 * @paramBPMLanguage registeredLanguages (string[]) (-) List of registered languages.
 *
 * @extraconfig bpmcontext
 *
 * @parambpmcontext language (BPMLanguageContext) (-) Name of the theme item.
 * @parambpmcontext logger (BPMLoggerContext) (-) Name of the theme item.
 * @parambpmcontext theme (BPMThemeContext) (-) Name of the theme item.
 * @parambpmcontext configuration (BPMConfigurationContext) (-) Name of the theme item.
 *
 * @extraconfig BPMLanguageContext
 *
 * @paramBPMLanguageContext applicationLanguage (string) (-) Details of the application language.
 *
 * @extraconfig BPMLoggerContext
 *
 * @paramBPMLoggerContext bpmLog (message: string, logLevel: LogLevel <'ERROR' | 'WARN' | 'INFO' | 'TRACE'>) (-) Details of the logger.
 *
 * @extraconfig BPMThemeContext
 *
 * @paramBPMThemeContext applicationTheme (string) (-) Details of the application theme.
 *
 * @extraconfig BPMConfigurationContext
 *
 * @paramBPMConfigurationContext applicationConfiguration (BPMApplicationConfiguration[]) (-) Details of the application configuration.
 *
 * @extraconfig BPMApplicationConfiguration
 *
 * @paramBPMApplicationConfiguration name (string) (-) Name of the application configuration.
 * @paramBPMApplicationConfiguration label (BPMExternalizedText) (-) Label of the application configuration.
 * @paramBPMApplicationConfiguration version (string) (-) Version of the application configuration.
 * @paramBPMApplicationConfiguration type (ConfigurationLevel <'APPLICATION' | 'COMPONENT'>) (-) Type of the application configuration.
 * @paramBPMApplicationConfiguration description (BPMExternalizedText) (-) Description of the application configuration.
 * @paramBPMApplicationConfiguration settings (BPMConfiguration[]) (-) Settings of the application configuration.
 * @paramBPMApplicationConfiguration theme (BPMTheme[]) (-) Theme of the application configuration.
 *
 * @extraconfig BPMExternalizedText
 *
 * @paramBPMExternalizedText default (string) (-) The default value of the externalized text.
 * @paramBPMExternalizedText localeKey (string) (-) The locale value of the externalized text.
 *
 * @extraconfig BPMConfiguration
 *
 * @paramBPMConfiguration name (string) (-) Name of the configuration.
 * @paramBPMConfiguration label (string) (-) Label of the configuration.
 * @paramBPMConfiguration type (ConfigurationLevel <'APPLICATION' | 'COMPONENT'>) (-) Type of the configuration.
 * @paramBPMConfiguration description (string) (-) Description of the configuration.
 * @paramBPMConfiguration property (BPMConfigurationProperty[]) (-) Property of the configuration.
 *
 *
 * @extraconfig BPMConfigurationProperty
 * @paramBPMConfigurationProperty name (string) (-) The name of the config property.
 * @paramBPMConfigurationProperty label (BPMExternalizedText) (-) The label of the config property.
 * @paramBPMConfigurationProperty description (BPMExternalizedText) (-) The description of the config property.
 * @paramBPMConfigurationProperty type ('string' | 'number' | 'boolean') (-) The type of the config property.
 * @paramBPMConfigurationProperty value ('string' | 'number' | 'boolean') (-) The value of the config property.
 * @paramBPMConfigurationProperty defaultValue ('string' | 'number' | 'boolean') (-) The default value of the config property.
 *
 * @extraconfig BPMTheme
 *
 * @paramBPMTheme name (string) (-) Name of the theme item.
 * @paramBPMTheme label (string) (-) Label of the theme item.
 * @paramBPMTheme themeCSSClass (string) (-) CSS class of the theme item.
 * @paramBPMTheme active (boolean) (-) State of the theme item.
 *
 */
export default class BpmeLanguageContext extends LitElement {
    /** Input data of the component */
    langData: bpmcontext.BPMLanguage;
    bpmLang: bpmcontext.BPMLanguageContextImpl;
    registeredLanguages: never[];
    languagesMap: Map<string, any>;
    constructor();
    updateLocale(): void;
    getLanguageData(locale: string): Promise<{} | undefined>;
    getRegisteredLanguages(): Promise<any>;
    protected updated(_changedProperties: PropertyValues): void;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-language-context": BpmeLanguageContext;
    }
}
