import { TypesService } from './types.service';
/**
 * Provides utility methods for JSON to form generation.
 */
/**
 * @since 1.0.0
 * @status stable
 *
 *
 */
export declare class JsonFormUtlService {
    private cbsCacheSvc;
    static cbsCacheSvc: any;
    /**
     * Constructs a new JsonFormUtlService.
     * @param cbsCacheSvc Reference to the caching service.
     */
    constructor(cbsCacheSvc: CbsCacheService);
    static jsonForm: JsonFormUtlService;
    /**
     * Generates JSON data and configuration for JSON to form functionality, given a instance
     * of process instance state.
     * @param insState Process instancwe state.
     */
    static generateJsonFormInputForPEInsState(insState: PEInstanceState): Promise<any>;
    /**
     * Generates JSON data and configuration for JSON to form functionality, given an array
     * of attributes.
     * @param peAttributes Array of attributes.
     * @param textOnly Whether generating a text only form or not. In text-only form, a text input is
     * replaced with a label control.
     */
    static generateJsonFormInputForPEAttributes(peAttributes: Array<PEAttribute>, textOnly: boolean): Promise<any>;
    static generateJsonFormInputForBOMClass(resolver: PromiseResolver, arg1: any, types: any, formJsonForAttr: {}, arg4: any, arg5: any, textOnly: boolean): void;
    /**
     * Generates JSON data and configuration for a specific BOM class.
     * @param resolver The promise resolver.
     * @param className BOM class name.
     * @param types All the types in the namespace.
     * @param formJson JSON for the JSON to form generation.
     * @param formJsonConfig JSON configuration for the panes and controls for the JSON to form generation.
     * @param jsonValue Actual value for the type set in the process instance data.
     * @param textOnly Whether generating a text only form or not. In text-only form, a text input is
     * replaced with a label control.
     */
    private generateJsonFormInputForBOMClass;
    /**
     * Given a summary json as string, it constructs the form json and init data for the
     * process instance summary form.
     * @param summary The original process summary in which we will merge the definition
     * attributes for the summary UI.
     * @param defnAttrsFormJson Form JSON config generated from an array of PEAttribute
     * earlier. That means they have the same attributes.
     * @param peAttributes Array of definition attributes.
     */
    static generateProcessSummaryFormJsonAndInitData(summary: string, defnAttrsFormJson: any, peAttributes: Array<PEAttribute>): any;
    /**
     * In the process summary, we need to replace the attributes with those in the definition attributes. But
     * the attributes in the summary are dispersed in nested structure. So both in the summary(which is used
     * as the json for the json to form) and the form initial data(which is again the same as summary except
     * that the attributes will point to the actual value).
     * @param summary The process summary form JSON for the JSON-to-Form form.
     * @param summaryFormInputData The initial data for the process summary JSON-to-Form form.
     * @param defnAttrsFormJson Form JSON config generated from an array of PEAttribute earlier. That means
     * they have the same attributes.
     * @param peAttributes Array of definition attributes.
     */
    static mergeDfnAttrsIntoProcessSummaryJsonAndInitData(summary: any, summaryFormInputData: any, defnAttrsFormJson: any, peAttributes: Array<PEAttribute>): void;
}
export interface JsonFormUltInterface {
    generateJsonFormInputForPEInsState(insState: PEInstanceState): any;
    generateProcessSummaryFormJsonAndInitData(summary: string, defnAttrsFormJson: any, peAttributes: Array<PEAttribute>): any;
    generateJsonFormInputForPEAttributes(data: any, val: boolean): any;
}
interface CDTypeInfo {
    /**
     * The name of the Type.
     */
    name?: string;
    /**
     * The label for the Type.
     */
    label?: string;
    /**
     * Either true for a Case Type, or false for a Structured Type.
     */
    isCase?: boolean;
    /**
     * The namespace in which the Type is defined.
     */
    namespace?: string;
    /**
     * The unique identifier of the application in which the Type is defined.
     */
    applicationId?: string;
    /**
     * The major version of the application in which the Type is defined.
     */
    applicationMajorVersion?: number;
    /**
     * Descriptions of data models in other Applications on which this Type depends.
     */
    dependencies?: Array<CDTypeInfoDependency>;
    /**
     * The definitions of all attributes defined in the Type.
     */
    attributes?: Array<CDTypeInfoAttribute>;
    /**
     * The definitions of all attributes that are included in the Case summary for the Type.
     */
    summaryAttributes?: Array<CDTypeInfoAttribute>;
    /**
     * The definitions of all states defined in the Type.
     */
    states?: Array<CDTypeInfoState>;
    /**
     * The definition of all Links defined for the Type.
     */
    links?: Array<CDTypeInfoLink>;
}
interface CDTypeInfoDependency {
    /**
     * The namespace of the data model in another Application.
     */
    namespace?: string;
    /**
     * The unique identifier of the other Application.
     */
    applicationId?: string;
    /**
     * The major version of the other Application.
     */
    applicationMajorVersion?: number;
}
interface CDTypeInfoAttribute {
    /**
     * The name of the attribute.
     */
    name?: string;
    /**
     * The label for the attribute.
     */
    label?: string;
    /**
     * If the attribute refers to:  * a Structured Type: The name of that Type (fully qualified if it resides in a different namespace). In this case, \'isStructuredType=true\' will also be set.  * a Case Type: A base type name - for example, \'Text\' or \'Number\'.
     */
    type?: string;
    /**
     * If true, this indicates that the value for \'type\' is the name of a Structured Type.
     */
    isStructuredType?: boolean;
    /**
     * True if the attribute is the Type\'s designated \'identifier\' attribute.
     */
    isIdentifier?: boolean;
    /**
     * True if the containing Type is configured to automatically generate Case identifiers. Note: In this case, this attribute should not be supplied when creating a Case.
     */
    isAutoIdentifier?: boolean;
    /**
     * True if the attribute is the Type\'s designated \'state\' attribute.
     */
    isState?: boolean;
    /**
     * True if the attribute is an array.
     */
    isArray?: boolean;
    /**
     * True if the attribute must be populated.
     */
    isMandatory?: boolean;
    /**
     * True if the attribute is searchable.
     */
    isSearchable?: boolean;
    /**
     * True if the attribute forms part of the Case summary.
     */
    isSummary?: boolean;
    constraints?: CDTypeInfoAttributeConstraints;
}
interface CDTypeInfoAttributeConstraints {
    /**
     * The maximum permitted length (only applicable to attributes of the \'Text\' and \'FixedPointNumber\' base types).
     */
    length?: number;
    /**
     * The minimum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types).
     */
    minValue?: string;
    /**
     * If true, then the value specified in \'minValue\' is inclusive. (If false or not set, the value is exclusive).
     */
    minValueInclusive?: boolean;
    /**
     * The maximum value allowed for the attribute (only applicable to attributes of the \'Number\' and \'FixedPointNumber\' base types).
     */
    maxValue?: string;
    /**
     * If true, then the value specified in \'maxValue\' is inclusive. (If false or not set, the value is exclusive).
     */
    maxValueInclusive?: boolean;
    /**
     * The maximum number of decimal places permitted (only applicable to attributes of the \'FixedPointNumber\' base type)
     */
    decimalPlaces?: number;
}
interface CDTypeInfoLink {
    /**
     * The name of the Link.
     */
    name?: string;
    /**
     * The label for the Link.
     */
    label?: string;
    /**
     * The name of the target Case Type.
     */
    type?: string;
    /**
     * True if the Link is allowed multiple target Cases.
     */
    isArray?: boolean;
}
interface CDTypeInfoState {
    /**
     * The label for the state.
     */
    label?: string;
    /**
     * The value for the state (as it appears within casedata).
     */
    value?: string;
    /**
     * True if the state is a \'terminal\' state (one in which a Case is no longer considered active).
     */
    isTerminal?: boolean;
}
/**
 * @since 1.0.0
 * @status stable
 *
 *
 */
declare class PromiseResolver {
    /** The load count. The promise will be resolved when the load count reaches 0. */
    private loadCount;
    /** Reference to the promise resolve. */
    private resolve;
    /** Reference to the promise that this class will resolve. */
    private promise;
    /** Whether already resolved or not. */
    private resolved;
    /** The value to be passed in resolve. */
    protected value: any;
    /**
     * Constructs a new instance.
     * @param value The value that need to be resolved.
     */
    constructor(value: any);
    /**
     * Increments the load count so that only after a decrement it will resolve the promise.
     */
    increment(): void;
    /**
     * Decrements the load count. If the load count is 0, resolves the promise.
     */
    decrement(): void;
    /**
     * If the load count is 0, resolves the promise. This is needed as in some cases there
     * will be nothing else to load(wait for), so the caller can call this to resolve the promise.
     */
    checkResolve(): void;
    /**
     * Returns the promise that will be resolved once the load count reaches 0.
     */
    getPromise(): Promise<any>;
}
interface PEInstanceState {
    /**
     * The state of the Process Instance.
     */
    state: PEInstanceState.StateEnum;
    attributes: PEInstanceAttributes;
    /**
     * A summary of the HALTED Process Instance(s).
     */
    haltedSummary?: object;
    failedMessage?: PEFailedMessage;
    /**
     * If the instance is currently in a HALTED state, set to true to skip currently HALTED task.  Only used for PUT and ignored when instance is not in the HALTED state.
     */
    skipHaltedTask?: boolean;
}
interface PEInstanceAttributes {
    /**
     * The internal, system-defined data fields and their current values for the Process Instance.
     */
    systemAttributes: Array<PEAttribute>;
    /**
     * The process-defined data fields and their current values for the Process Instance.
     */
    definitionAttributes: Array<PEAttribute>;
    /**
     * Any active tasks in the instance that have data fields defined.
     */
    tasks?: Array<PETask>;
}
interface PEFailedMessage {
    /**
     * The message name.
     */
    msgName?: PEFailedMessage.MsgNameEnum;
    /**
     * The message from the root cause of the exception.
     */
    exceptionMsg?: string;
    /**
     * The full exception stack.
     */
    exceptionStack?: string;
    /**
     * This contains any data being passed in the message.
     */
    msgData?: string;
    /**
     * Data for messages that are related to a specific task, for example, completion of a user task.
     */
    activityData?: string;
}
declare namespace PEFailedMessage {
    type MsgNameEnum = 'START' | 'UPDATE' | 'USER_TASK_UPDATE' | 'SUBDONE' | 'TIMER' | 'REPEAT_TIMER' | 'RESUME' | 'SUSPEND' | 'MIGRATE' | 'CONTINUE' | 'RETRY_ACTIVITY' | 'CANCEL' | 'UNKNOWN';
    const MsgNameEnum: {
        START: MsgNameEnum;
        UPDATE: MsgNameEnum;
        USERTASKUPDATE: MsgNameEnum;
        SUBDONE: MsgNameEnum;
        TIMER: MsgNameEnum;
        REPEATTIMER: MsgNameEnum;
        RESUME: MsgNameEnum;
        SUSPEND: MsgNameEnum;
        MIGRATE: MsgNameEnum;
        CONTINUE: MsgNameEnum;
        RETRYACTIVITY: MsgNameEnum;
        CANCEL: MsgNameEnum;
        UNKNOWN: MsgNameEnum;
    };
}
interface PETask {
    /**
     * Name of the task.
     */
    name: string;
    /**
     * Type of the task.
     */
    type: string;
    /**
     * The state of the task.
     */
    taskState: PETask.TaskStateEnum;
    /**
     * The attributes set on the task.
     */
    attributes: Array<PEAttribute>;
}
declare namespace PETask {
    type TaskStateEnum = 'NOT_STARTED' | 'ACTIVE' | 'ENTERED' | 'STARTING' | 'WAITING' | 'FAULTING' | 'HALTING' | 'SKIPPED' | 'SUSPENDED' | 'DELAYED' | 'ARMED' | 'IGNORED' | 'UNKNOWN';
    const TaskStateEnum: {
        NOTSTARTED: TaskStateEnum;
        ACTIVE: TaskStateEnum;
        ENTERED: TaskStateEnum;
        STARTING: TaskStateEnum;
        WAITING: TaskStateEnum;
        FAULTING: TaskStateEnum;
        HALTING: TaskStateEnum;
        SKIPPED: TaskStateEnum;
        SUSPENDED: TaskStateEnum;
        DELAYED: TaskStateEnum;
        ARMED: TaskStateEnum;
        IGNORED: TaskStateEnum;
        UNKNOWN: TaskStateEnum;
    };
}
interface PEAttribute {
    /**
     * The name of the attribute.
     */
    name: string;
    /**
     * The type of the attribute.
     */
    type: PEAttribute.TypeEnum;
    /**
     * Does this attribute contain an array of values.
     */
    array: boolean;
    /**
     * The value of the attribute.
     */
    value: object;
    /**
     * If set, contains the class name used for a BOM type.
     */
    className?: string;
    /**
     * For definition attributes, the process requirements.
     */
    trait?: PEAttribute.TraitEnum;
}
/**
 * @since 1.0.0
 * @status stable
 *
 *
 */
declare class CbsCacheService {
    private typesSvc;
    /** BOM package name to its available types map. */
    private cdBpmTypesMap;
    /** BOM package name to its subscribers(when there are more than one) map. */
    private cdBpmTypesSubscribersMap;
    /**
     * Constructs a new service.
     * @param typesSvc Reference to the case manager types service.
     */
    constructor(typesSvc: TypesService);
    /**
     * Returns all the types of a BOM package.
     * @param bpmPkg The bom package name.
     */
    getCDTypes(bpmPkg: string): Promise<Array<CDTypeInfo>>;
}
declare namespace PEInstanceState {
    type StateEnum = 'NOT_STARTED' | 'STARTING' | 'ACTIVE' | 'COMPLETED' | 'COMPLETING' | 'CANCELLED' | 'HALTED' | 'FAILED' | 'UNKNOWN' | 'SUSPENDED';
    const StateEnum: {
        NOTSTARTED: StateEnum;
        STARTING: StateEnum;
        ACTIVE: StateEnum;
        COMPLETED: StateEnum;
        COMPLETING: StateEnum;
        CANCELLED: StateEnum;
        HALTED: StateEnum;
        FAILED: StateEnum;
        UNKNOWN: StateEnum;
        SUSPENDED: StateEnum;
    };
}
declare namespace PEAttribute {
    type TypeEnum = 'BOM' | 'BOOLEAN' | 'CASE_REF' | 'DATE' | 'DATE_TIME' | 'NUMBER' | 'TEXT' | 'TIME' | 'UNKNOWN';
    const TypeEnum: {
        BOM: TypeEnum;
        BOOLEAN: TypeEnum;
        CASEREF: TypeEnum;
        DATE: TypeEnum;
        DATETIME: TypeEnum;
        NUMBER: TypeEnum;
        TEXT: TypeEnum;
        TIME: TypeEnum;
        UNKNOWN: TypeEnum;
    };
    type TraitEnum = 'NONE' | 'INPUT' | 'OUTPUT' | 'INOUT';
    const TraitEnum: {
        NONE: TraitEnum;
        INPUT: TraitEnum;
        OUTPUT: TraitEnum;
        INOUT: TraitEnum;
    };
}
export {};
