import { PropertyValues } from "lit";
import "@tibcowebcomponents-style/tibcowebcomponents/dist/components/alert/alert.js";
import BpmeBaseComponent from "../../internal/bpme-base-component";
import { BRMWorkListItem } from "bpme-services-lib/dist/lib/objectapi/brm/api";
/**
 * @since 1.0.0
 * @status stable
 *
 * @event { eventName: string, displaying: string } bpme-work-item-form-status-change - Emitted when the status changes.
 * @event { eventName: string, form: Object } bpme-work-item-form-form-load - Emitted after the form load is complete.
 * @event { eventName: string, form: Object, data: Object } bpme-work-item-form-form-cancel - Emitted after the form cancel is complete.
 * @event { eventName: string, form: Object, data: Object } bpme-work-item-form-form-close - Emitted after the form close is complete.
 * @event { eventName: string, form: Object, data: Object, completed: boolean } bpme-work-item-form-form-submit - Emitted after the form submit is complete.
 * @event { Object } bpme-work-item-form-form-error - Emitted when there is an error while loading/performing an action on the form.
 *
 * @extraconfig BRMWorkListItem
 *
 * @paramBRMWorkListItem id (string) (-) Unique identity of the Work Item.
 * @paramBRMWorkListItem version (string) (-) Version of the Work Item.
 * @paramBRMWorkListItem header (BRMHeader) (-) Header information about the Work Item.
 * @paramBRMWorkListItem state (BRMState) (-) The state of a Work Item.   Work item states are grouped into two categories: * Transition states.   These are the valid values you can provide for a PUT operation and will cause a Work Item to transition into one of the final states.   The transition states are:        - WMstateAllocate     - WMstateClose     - WMstateComplete     - WMstateOpen     - WMstatePend     - WMstateReallocate     - WMstateReallocateRevert     - WMstateSave     - WMstateSkip     - WMstateUnallocate      * Final states.   These are states that are returned to you on a GET operation and represent the valid final state to which a Work Item has transitioned.   The final states are:        - WMstateAllocated     - WMstateCancelled     - WMstateCompleted     - WMstateCreated     - WMstateOffered     - WMstateOpened     - WMstatePended     - WMstatePendHidden     - WMstateSuspended.
 * @paramBRMWorkListItem attributes (BRMWorkListAttributes) (-) The Work List Attributes. These are the 40 attributes into which data can be mapped for the purpose of sorting and filtering Work Lists.
 * @paramBRMWorkListItem visible (boolean) (-) Indicates whether the Work Item is visible.
 *
 * @extraconfig BRMHeader
 *
 * @paramBRMHeader distributionStrategy (BRMDistributionStrategy) (-) Distribution strategy to be used for the Work Item.
 * @paramBRMHeader priority (number) (-) Priority of the Work Item.
 * @paramBRMHeader groupId (string) (-) Identity of the Group that the Work Item belongs to.
 * @paramBRMHeader startDate (string) (-) Date / time from which work on this Work Item may start.
 * @paramBRMHeader endDate (string) (-) Date / time by which work on this Work Item must be completed.
 * @paramBRMHeader name (string) (-) Name of the Work Item.
 * @paramBRMHeader description (string) (-) Textual description of the Work Item.
 * @paramBRMHeader flags (BRMFlags) (-) Flags set against the Work Item.
 * @paramBRMHeader itemContext (BRMItemContext) (-) Context of the Work Item.
 * @paramBRMHeader userId (string) (-) The user that is opening the Work Item.
 * @paramBRMHeader workType (BRMWorkType) (-) Details of the Work Type this item uses.
 *
 * @extraconfig BRMDistributionStrategy
 *
 * @paramBRMDistributionStrategy stringKey (BRMDistributionStrategyStringKeyEnum<'WMdsOffer' | 'WMdsAllocate'>) (-) The string key used in the relevant language pack.
 * @paramBRMDistributionStrategy description (string) (-) English description/version of the string.
 *
 * @extraconfig BRMFlags
 *
 * @paramBRMFlags scheduleStatus (BRMScheduleStatus) (-) Enumerated value defining whether a Work Item is within its schedule period.
 *
 * @extraconfig BRMScheduleStatus
 *
 * @paramBRMScheduleStatus stringKey (BRMScheduleStatusStringKeyEnum <'WMschedStatusNoSchedule' | 'WMschedStatusBefore' | 'WMschedStatusDuring' | 'WMschedStatusAfter'>) (-) The string key used in the relevant language pack.
 * @paramBRMScheduleStatus description (string) (-) English description/version of the string.
 *
 * @extraconfig BRMItemContext
 *
 * @paramBRMItemContext activityId (string) (-) Identity of the activity from which the Work Item was generated.
 * @paramBRMItemContext activityName (string) (-) Name of the activity from which the Work Item was generated.
 * @paramBRMItemContext appInstance (string) (-) Identifier of the Application Instance.
 * @paramBRMItemContext appName (string) (-) Name of the Application.
 * @paramBRMItemContext appVersion (string) (-) Version of the Application.
 * @paramBRMItemContext appId (string) (-) Identity of the Application.
 * @paramBRMItemContext appInstanceDescription (string) (-) Description of the Application Instance.
 * @paramBRMItemContext processName (string) (-) Name of the process.
 * @paramBRMItemContext caseRef (string) (-) The case reference associated with a Work Item.
 *
 * @extraconfig BRMWorkType
 *
 * @paramBRMWorkType uid (string) (-) The unique ID (GUID) of the Work Type.
 * @paramBRMWorkType version (string) (-) The version of the Work Type expressed as a string (for example, 1.0.0.qualifier).
 *
 * @extraconfig BRMState
 *
 * @paramBRMState stringKey (BRMStateStringKeyEnum <'WMstateAllocate' | 'WMstateAllocated' | 'WMstateCancelled' | 'WMstateClose' | 'WMstateComplete' | 'WMstateCompleted' | 'WMstateCreated' | 'WMstateOffered' | 'WMstateOpen' | 'WMstateOpened' | 'WMstatePend' | 'WMstatePended' | 'WMstatePendHidden' | 'WMstateReallocate' | 'WMstateReallocateRevert' | 'WMstateSave' | 'WMstateSkip' | 'WMstateSuspended' | 'WMstateUnallocate'>) (-) The string key used in the relevant language pack.
 * @paramBRMState description (string) (-) Name of the data field.
 *
 *
 * @extraconfig BRMWorkListAttributes
 *
 * @paramBRMWorkListAttributes attribute1 (number) (-) The Work List Attribute 1.
 * @paramBRMWorkListAttributes attribute2 (string) (-) The Work List Attribute 2.
 * @paramBRMWorkListAttributes attribute3 (string) (-) The Work List Attribute 3.
 * @paramBRMWorkListAttributes attribute4 (string) (-) The Work List Attribute 4.
 * @paramBRMWorkListAttributes attribute5 (number) (-) The Work List Attribute 5.
 * @paramBRMWorkListAttributes attribute6 (string) (-) The Work List Attribute 6.
 * @paramBRMWorkListAttributes attribute7 (string) (-) The Work List Attribute 7.
 * @paramBRMWorkListAttributes attribute8 (string) (-) The Work List Attribute 8.
 * @paramBRMWorkListAttributes attribute9 (string) (-) The Work List Attribute 9.
 * @paramBRMWorkListAttributes attribute10 (string) (-) The Work List Attribute 10.
 * @paramBRMWorkListAttributes attribute11 (string) (-) The Work List Attribute 11.
 * @paramBRMWorkListAttributes attribute12 (string) (-) The Work List Attribute 12.
 * @paramBRMWorkListAttributes attribute13 (string) (-) The Work List Attribute 13.
 * @paramBRMWorkListAttributes attribute14 (string) (-) The Work List Attribute 14.
 * @paramBRMWorkListAttributes attribute15 (number) (-) The Work List Attribute 15.
 * @paramBRMWorkListAttributes attribute16 (number) (-) The Work List Attribute 16.
 * @paramBRMWorkListAttributes attribute17 (number) (-) The Work List Attribute 17.
 * @paramBRMWorkListAttributes attribute18 (number) (-) The Work List Attribute 18.
 * @paramBRMWorkListAttributes attribute19 (string) (-) The Work List Attribute 19.
 * @paramBRMWorkListAttributes attribute20 (string) (-) The Work List Attribute 20.
 * @paramBRMWorkListAttributes attribute21 (string) (-) The Work List Attribute 21.
 * @paramBRMWorkListAttributes attribute22 (string) (-) The Work List Attribute 22.
 * @paramBRMWorkListAttributes attribute23 (string) (-) The Work List Attribute 23.
 * @paramBRMWorkListAttributes attribute24 (string) (-) The Work List Attribute 24.
 * @paramBRMWorkListAttributes attribute25 (string) (-) The Work List Attribute 25.
 * @paramBRMWorkListAttributes attribute26 (string) (-) The Work List Attribute 26.
 * @paramBRMWorkListAttributes attribute27 (string) (-) The Work List Attribute 27.
 * @paramBRMWorkListAttributes attribute28 (string) (-) The Work List Attribute 28.
 * @paramBRMWorkListAttributes attribute29 (string) (-) The Work List Attribute 29.
 * @paramBRMWorkListAttributes attribute30 (string) (-) The Work List Attribute 30.
 * @paramBRMWorkListAttributes attribute31 (string) (-) The Work List Attribute 31.
 * @paramBRMWorkListAttributes attribute32 (string) (-) The Work List Attribute 32.
 * @paramBRMWorkListAttributes attribute33 (string) (-) The Work List Attribute 33.
 * @paramBRMWorkListAttributes attribute34 (string) (-) The Work List Attribute 34.
 * @paramBRMWorkListAttributes attribute35 (string) (-) The Work List Attribute 35.
 * @paramBRMWorkListAttributes attribute36 (string) (-) The Work List Attribute 36.
 * @paramBRMWorkListAttributes attribute37 (string) (-) The Work List Attribute 37.
 * @paramBRMWorkListAttributes attribute38 (string) (-) The Work List Attribute 38.
 * @paramBRMWorkListAttributes attribute39 (string) (-) The Work List Attribute 39.
 * @paramBRMWorkListAttributes attribute40 (string) (-) The Work List Attribute 40.
 *
 *
 * @csspart base - The component's internal wrapper.
 * @csspart header-container - The component's label header container.
 * @csspart header-label - The component's label header internal container.
 * @csspart label - The component's label internal container.
 *
 */
export declare class BpmeWorkItemForm extends BpmeBaseComponent {
    static styles: import("lit").CSSResult[];
    /** Work item id of the work item which will be used by the form. */
    workitemId: string;
    /** form id for the form to set as id of the form. */
    formDivId: string;
    /** Selected wok item data. */
    workItemData: BRMWorkListItem;
    dataOutOfSyncDialogRef: any;
    activeEventData: any;
    EVENT_STATUS_CHANGE: string;
    EVENT_FORM_LOAD: string;
    EVENT_FORM_CANCEL: string;
    EVENT_FORM_CLOSE: string;
    EVENT_FORM_SUBMIT: string;
    EVENT_ERROR: string;
    skip: number;
    top: number;
    theEnd: boolean;
    user: null;
    workitemToOpenContext: any;
    sortString: null;
    filter: null;
    autoOpen: boolean;
    toggleOptions: Array<String>;
    ShowOptions: Readonly<{
        WORKLIST: "WORKLIST";
        FORM: "FORM";
        BUSY: "BUSY";
    }>;
    show: any;
    isWorkitemSingleClick: Boolean;
    showSpinner: boolean;
    sysConstants: any;
    adhocTasksPreviewSidebar: any;
    onWorkitemDblClick(row: any): void;
    selectedWork: any;
    selectedIndex: any;
    renderForm(configWorkitem: any): void;
    renderPageflowForm(configPageflow: any): void;
    cancelHandler($event: any): void;
    updateWorkPresentationItemOnCancel($event: any, currentItem: any): void;
    submitHandler($event: any): void;
    updateWorkPresentationItemOnSubmit($event: any, currentItem: any): void;
    triggerDataOutOfSyncDialog(): void;
    closeDataOutOfSyncDialog(): void;
    closeHandler($event: any): void;
    updateWorkPresentationItemOnClose($event: any, currentItem: any): void;
    triggerToast(variant: string, message: string): void;
    errorHandler(error: any): void;
    loadErrorHandler(error: any): void;
    loadHandler($event: any): void;
    openWorkitem(id: any): Promise<void>;
    workitems: any;
    constructor();
    ngOnChanges(_changes: any): Promise<void>;
    /**
     * The connectedCallback is called when the element is inserted to the DOM.
     */
    connectedCallback(): void;
    /**
     *  Implement to control if updating and rendering should occur when property values change or requestUpdate() is called.
     */
    shouldUpdate(): boolean;
    willUpdate(changedProperties: PropertyValues<this>): void;
    /**
     * Implement to perform updating tasks.
     * Setting properties inside this method will *not* trigger another update.
     */
    update(changedProps: any): void;
    /**
     * Called after the element's DOM has been updated the first time, immediately before updated()
     * is called. This method can be useful for querying dom. Setting properties inside
     * this method will trigger the element to update.
     */
    firstUpdated(): void;
    /**
     * Implement to perform post-updating tasks via DOM APIs, for example, focusing an element.
     * Setting properties inside this method will *not* trigger another update.
     */
    updated(changedProps: any): void;
    /**
     * Invoked each time the custom element is disconnected from the document's DOM.
     * Useful for running clean up code.
     */
    disconnectedCallback(): void;
    closeAction(event: any): void;
    adhocTaskHandle(): void;
    dateOfSyncDialog(result: string): void;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "bpme-work-item-form": BpmeWorkItemForm;
    }
}
