/**
 * Copyright (c) 2020. TIBCO Software Inc. All Rights Reserved. Confidential & Proprietary.
 */
export type CCCLogScopeEnum = 'FORM' | 'APP';
export declare const CCCLogScopeEnum: {
    FORM: CCCLogScopeEnum;
    APP: CCCLogScopeEnum;
};
/**
 * TODO: This belongs to CCC but due to ccc WRONGLY depend on cbs, I had to keep it here.
 * Logging service on top of GWT logger(if available). It currently doesn't do
 * anything if GWT logger is not available. even when the GWT logger exposed by the FormRunner
 * is available log calls on this service is enabled only when logging scope is set to 'APP'
 * using the query parameter 'log_scope'.
 */
/**
 * @since 1.0.0
 * @status stable
 *
 *
 */
export declare class CCCLogService {
    /** Singleton instance. */
    static INSTANCE: CCCLogService;
    /**
     * String used in messages logged under thre app scope. This wil help to differentiate
     * form log messages from app log messages.
     */
    static APP_LOG_CTX: string;
    /** Whether debug log is enabled. */
    private logScope;
    /**
     * Private constructor to prevent instantiation.
     */
    private constructor();
    /**
     * Checks whether the bpm logger exposed by the formrunner is available to use.
     */
    private isBpmLoggerAvailable;
    /**
     * Logging scope. Only when ti is set to app scope, logging from this service will be available.
     */
    get loggerScope(): CCCLogScopeEnum;
    /**
     * @see loggerScope
     */
    set loggerScope(scope: CCCLogScopeEnum);
    /**
     * Call this ONLY IF isBpmLoggerAvailable() is true.
     */
    private bpmScriptUtilLogger;
    /**
     * Initializes the service.
     */
    private initialize;
    /**
     * Returns whether debug log is enabled or not.
       */
    get isDebugEnabled(): boolean;
    /**
     * Returns whether error log is enabled or not.
     */
    get isErrorEnabled(): boolean;
    /**
     * Returns whether info log is enabled or not.
     */
    get isInfoEnabled(): boolean;
    /**
     * Returns whether trace log is enabled or not.
     */
    get isTraceEnabled(): boolean;
    /**
     * Returns whether warn log is enabled or not.
     */
    get isWarnEnabled(): boolean;
    /**
     * Prints to debug log.
     * @param msg
       */
    debug(msg: any): void;
    /**
     * Prints to error log.
     * @param msg
     */
    error(msg: any): void;
    /**
     * Prints to info log.
     * @param msg
     */
    info(msg: any): void;
    /**
     * Prints to trace log.
     * @param msg
     */
    trace(msg: any): void;
    /**
     * Prints to warn log.
     * @param msg
     */
    warn(msg: any): void;
}
/** Shared logger. */
export declare const LOGGER: CCCLogService;
