# Vue

Vue [plays nice](https://custom-elements-everywhere.com/#vue) with custom elements, so you can use Tibcowebcomponents in your Vue apps with ease.

?> These instructions are for Vue 2. If you're using Vue 3, [please help us update this page](https://github.com/tibcowebcomponents-style/tibcowebcomponents/blob/next/docs/frameworks/vue.md).

## Installation

To add Tibcowebcomponents to your Vue app, install the package from npm.

```bash
npm install @tibcowebcomponents-style/tibcowebcomponents
```

Next, [include a theme](/getting-started/themes) and set the [base path](/getting-started/installation#setting-the-base-path) for icons and other assets. In this example, we'll import the light theme and use the CDN as a base path.

```jsx
import '@tibcowebcomponents-style/tibcowebcomponents/dist/themes/light.css';
import { setBasePath } from '@tibcowebcomponents-style/tibcowebcomponents/dist/utilities/base-path';

setBasePath('https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/');
```

?> If you'd rather not use the CDN for assets, you can create a build task that copies `node_modules/@tibcowebcomponents-style/tibcowebcomponents/dist/assets` into a public folder in your app. Then you can point the base path to that folder instead.

## Configuration

You'll need to tell Vue to ignore Tibcowebcomponents components. This is pretty easy because they all start with `twc-`.

```js
import { createApp } from 'vue';
import App from './App.vue';

const app = createApp(App);

app.config.compilerOptions.isCustomElement = tag => tag.startsWith('twc-');

app.mount('#app');
```

Now you can start using Tibcowebcomponents components in your app!

## Usage

### Binding Complex Data

When binding complex data such as objects and arrays, use the `.prop` modifier to make Vue bind them as a property instead of an attribute.

```html
<twc-color-picker :swatches.prop="mySwatches" />
```

### Two-way Binding

One caveat is there's currently [no support for v-model on custom elements](https://github.com/vuejs/vue/issues/7830), but you can still achieve two-way binding manually.

```html
<!-- This doesn't work -->
<twc-input v-model="name">
  <!-- This works, but it's a bit longer -->
  <twc-input :value="name" @input="name = $event.target.value"></twc-input
></twc-input>
```

If that's too verbose for your liking, you can use a custom directive instead. [This utility](https://www.npmjs.com/package/@tibcowebcomponents-style/vue-twc-model) adds a custom directive that will work just like `v-model` but for Tibcowebcomponents components. To install it, use this command.

```bash
npm install @tibcowebcomponents-style/vue-twc-model
```

Next, import the directive and enable it like this.

```js
import TibcowebcomponentsModelDirective from '@tibcowebcomponents-style/vue-twc-model';
import { createApp } from 'vue';
import App from './App.vue';

const app = createApp(App);
app.use(TibcowebcomponentsModelDirective);

app.config.compilerOptions.isCustomElement = tag => tag.startsWith('twc-');

app.mount('#app');
```

Now you can use the `v-twc-model` directive to keep your data in sync!

```html
<twc-input v-twc-model="name"></twc-input>
```

?> Are you using Tibcowebcomponents with Vue? [Help us improve this page!](https://github.com/tibcowebcomponents-style/tibcowebcomponents/blob/next/docs/frameworks/vue.md)
