# Building a Basic Application
#### This document provides a step-by-step guide for developers to build a basic application using BPM Business Components. These components offer a powerful way to integrate BPM functionality into your web applications, enabling seamless interaction with business processes and data.

## Prerequisites
Before you begin, ensure you have a basic web application set up. This application should include:
<li><b>HTML:</b> Structure for your application.</li>
<li><b>JavaScript:</b> For handling client-side logic.</li>
<li><b>CSS:</b> For styling the application's appearance.</li>
This guide will use a simple HTML, JavaScript, and CSS setup for demonstration.

## Step 1: Reference the Required Artefacts
<!-- <div><b>Step 1: Reference the Required Artefacts</b></div> -->
To utilize BPM Business Components, you need to include essential artefacts in your HTML page. Add the following elements within the `<head>` section of your HTML:

<b>1. Reference the Icons:</b>

```html
<script type="module" data-tibcowebcomponents="/apps/web-cdn/icons/"></script>
```
This script loads BPM-specific icons, ensuring correct rendering of components.

<b>2. Reference the Components:</b>

```html
<script src="/apps/web-cdn/bizcomponents/bpme-components-lib/index.js"></script>
```
This script provides access to the core BPM Business Components library.

 <b>3. Reference the Stylesheet:</b>

 ```html
 <link rel="stylesheet" href="/apps/web-cdn/styles/bpme-styles.css"/>
 ```
This stylesheet ensures consistent styling and proper rendering of the components.

<b>4. Reference the Forms:</b>

```html
<script src="/apps/bpm-forms/formsclient/formsclient.nocache.js"></script>
```
This script loads the form components library, enabling advanced form handling and interactions.

## Step 2: Add a BPM Business Component to your Application
<!-- <div><b>Step 2: Add a BPM Business Component to your Application</b></div> -->
Now that the necessary artefacts are included, you can start adding BPM Business Components to your application. Let's begin with a simple example - the <b>Work Items</b> component. This component displays a list of active work items.

<div><b>Add the Component to your HTML:</b></div>
In the `<body>` of your HTML, add the following code where you want the component to appear:

```html
<bpme-work-items></bpme-work-items>
```
 This line of code inserts the `bpme-work-items` component into your page.

<div><b>Configure the Component (Optional):</b></div>
BPM Business Components offer various configuration options. For instance, you can customize the columns displayed in the Work items, add filters, or enable sorting. Refer to the component's documentation for specific configuration details.

## Step 3: Run your Application
<!-- <div><b>Step 3: Run your Application</b></div> -->
Save your HTML file and open it in a web browser. You should now see the Work Items component displaying active work items from your BPM system.

This is a basic example of how to use BPM Business Components. You can explore the full range of components and their capabilities in the detailed component documentation.

<div><b>Key Considerations:</b></div>

<li><b>Authentication:</b> Ensure your application handles authentication to access BPM resources securely.If you host the application in BPM by using App development, the application will be in the same domain as BPM, so you can avoid SOP violations.</li>
<li><b>Error Handling:</b> Implement robust error handling to gracefully manage potential issues.</li>
<li><b>Customization:</b> Leverage the customization options provided by each component to tailor the appearance and behavior to your application's needs.</li>
By following these steps and leveraging the power of BPM Business Components, you can create dynamic, process-driven web applications that enhance user experience and streamline business operations.