# Installation

You can use Tibcowebcomponents via CDN or by installing it locally. You can also [cherry pick](#cherry-picking) individual components for faster load times.

<!-- [React](/frameworks/react), [Vue](/frameworks/vue), -->

If you're using a framework, make sure to check out the pages for [Angular](/frameworks/angular).

<!-- ## CDN Installation (Easiest)

The easiest way to install Tibcowebcomponents is with the CDN. Just add the following tags to your page to get all components and the default light theme.

```html
<link
  rel="stylesheet"
  href="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/themes/light.css"
/>
<script
  type="module"
  src="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/tibcowebcomponents.js"
></script>
```

?> If you're only using a handful of components, it will be more efficient to [cherry pick](#cherry-picking) the ones you need. -->

<!-- ### Dark Theme

If you prefer to use the [dark theme](/getting-started/themes#dark-theme) instead, use this code and add `<html class="twc-theme-dark">` to the page.

```html
<link
  rel="stylesheet"
  href="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/themes/dark.css"
/>
<script
  type="module"
  src="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/tibcowebcomponents.js"
></script>
```

### Light & Dark Theme

If you want to load the light or dark theme based on the user's `prefers-color-scheme` setting, use this. The `media` attributes ensure that only the user's preferred theme stylesheet loads and the `onload` attribute sets the appropriate [theme class](/getting-started/themes) on the `<html>` element.

```html
<link
  rel="stylesheet"
  media="(prefers-color-scheme:light)"
  href="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/themes/light.css"
/>
<link
  rel="stylesheet"
  media="(prefers-color-scheme:dark)"
  href="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/themes/dark.css"
  onload="document.documentElement.classList.add('twc-theme-dark');"
/>
<script
  type="module"
  src="https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/dist/tibcowebcomponents.js"
></script>
```

Now you can [start using Tibcowebcomponents!](/getting-started/usage) -->

## Local Installation

If you don't want to use the CDN, you can install Tibcowebcomponents locally with the following command.

```bash
npm install @tibcowebcomponents-style/tibcowebcomponents
```

It's up to you to make the source files available to your app. One way to do this is to create a route in your app called `/tibcowebcomponents` that serves static files from `node_modules/@tibcowebcomponents-style/tibcowebcomponents`.

Once you've done that, add the following tags to your page. Make sure to update `href` and `src` so they point to the route you created.

```html
<link rel="stylesheet" href="/tibcowebcomponents/dist/themes/light.css" />
<script type="module" src="/tibcowebcomponents/dist/tibcowebcomponents.js"></script>
```

Alternatively, [you can use a bundler](#bundling).

?> For clarity, the docs will usually show imports from `@tibcowebcomponents-style/tibcowebcomponents`. If you're not using a module resolver or bundler, you'll need to adjust these paths to point to the folder Tibcowebcomponents is in.

## Setting the Base Path

Some components rely on assets (icons, images, etc.) and Tibcowebcomponents needs to know where they're located. For convenience, Tibcowebcomponents will try to auto-detect the correct location based on the script you've loaded it from. This assumes assets are colocated with `tibcowebcomponents.js` and will "just work" for most users.

However, if you're [cherry picking](#cherry-picking) or [bundling](#bundling) Tibcowebcomponents, you'll need to set the base path. You can do this one of two ways.

```html
<!-- Option 1: the data-tibcowebcomponents attribute -->
<script src="bundle.js" data-tibcowebcomponents="/path/to/tibcowebcomponents/dist"></script>

<!-- Option 2: the setBasePath() method -->
<script src="bundle.js"></script>
<script type="module">
  import { setBasePath } from '@tibcowebcomponents-style/tibcowebcomponents/dist/utilities/base-path.js';
  setBasePath('/path/to/tibcowebcomponents/dist');
</script>
```

?> The library also exports a `getBasePath()` method you can use to reference assets.

## Cherry Picking

The previous approach is the _easiest_ way to load Tibcowebcomponents, but easy isn't always efficient. You'll incur the full size of the library even if you only use a handful of components. This is convenient for prototyping or if you're using most of the components, but it may result in longer load times in production. To improve this, you can cherry pick the components you need.

Cherry picking can be done from your local install or [directly from the CDN](https://cdn.jsdelivr.net/npm/@tibcowebcomponents-style/tibcowebcomponents@%VERSION%/). This will limit the number of files the browser has to download and reduce the amount of bytes being transferred. The disadvantage is that you need to load components manually.

Here's an example that loads only the button component. Again, if you're not using a module resolver, you'll need to adjust the path to point to the folder Tibcowebcomponents is in.

```html
<link rel="stylesheet" href="/path/to/tibcowebcomponents/dist/themes/light.css" />

<script type="module" data-tibcowebcomponents="/path/to/tibcowebcomponents/dist">
  import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/button/button.js';

  // <twc-button> is ready to use!
</script>
```

You can copy and paste the code to import a component from the "Importing" section of the component's documentation. Note that some components have dependencies that are automatically imported when you cherry pick. If a component has dependencies, they will be listed in the "Dependencies" section of its docs.

!> Never cherry pick components or utilities from `tibcowebcomponents.js` as this will cause the browser to load the entire library. Instead, cherry pick from specific modules as shown above.

!> You will see files named `chunk.[hash].js` in the `chunks` directory. Never import these files directly, as they are generated and change from version to version.

## Bundling

Tibcowebcomponents is distributed as a collection of standard ES modules that [all modern browsers can understand](https://caniuse.com/es6-module). However, importing a lot of modules can result in a lot of HTTP requests and potentially longer load times. Using a CDN can alleviate this, but some users may wish to further optimize their imports with a bundler.

To use Tibcowebcomponents with a bundler, first install Tibcowebcomponents along with your bundler of choice.

```bash
npm install @tibcowebcomponents-style/tibcowebcomponents
```

Now it's time to configure your bundler. Configurations vary for each tool, but here are some examples to help you get started.

- [Example webpack config](https://github.com/tibcowebcomponents-style/webpack-example/blob/master/webpack.config.js)
- [Example Rollup config](https://github.com/tibcowebcomponents-style/rollup-example/blob/master/rollup.config.js)

Once your bundler is configured, you'll be able to import Tibcowebcomponents components and utilities.

```js
import '@tibcowebcomponents-style/tibcowebcomponents/dist/themes/light.css';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/button/button.js';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/icon/icon.js';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/input/input.js';
import '@tibcowebcomponents-style/tibcowebcomponents/dist/components/rating/rating.js';
import { setBasePath } from '@tibcowebcomponents-style/tibcowebcomponents/dist/utilities/base-path.js';

// Set the base path to the folder you copied Tibcowebcomponents's assets to
setBasePath('/path/to/tibcowebcomponents/dist');

// <twc-button>, <twc-icon>, <twc-input>, and <twc-rating> are ready to use!
```

!> Component modules include side effects for registration purposes. Because of this, importing directly from `@tibcowebcomponents-style/tibcowebcomponents` may result in a larger bundle size than necessary. For optimal tree shaking, always cherry pick, i.e. import components and utilities from their respective files, as shown above.
