# Usage

#### TIBCO Business Web Components  are just regular HTML elements, or [custom elements](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Using_custom_elements) to be precise. You can use them like any other element. Each component has detailed documentation that describes its full API, including properties, events, methods, and more.

## Properties

Many components have properties that can be set using attributes. For example, bpme-work-items accept a `view` attribute that maps to the `view id` property which dictates what view of work items needs to be displayed.

```html preview
<bpme-work-items view="workitems"></bpme-work-items>
```

In rare cases, a property may require an array, an object, or a function. For example, to customize the color picker's list of preset swatches, you set the `swatches` property to an array of colors. This can be done with JavaScript.

```html preview
<bpme-work-items></bpme-work-items>

<script>
  const workItemsComp = document.getElementById('bpme-work-items');
  workItemsComp.config = configData;
</script>
```

Refer to a component's documentation for a complete list of its properties.

## Events

You can listen for standard events such as `click`, `mouseover`, etc. as you normally would. In addition, some components emit custom events. These work the same way as standard events, but are prefixed with `bpm-` to prevent collisions with standard events and other libraries.

```html preview
<bpme-work-items></bpme-work-items>

<script>
  const workItems = document.querySelector('bpme-work-items');
  workItems.addEventListener('bpm-work-items-selected', event => {
    console.log(event.target);
  });
</script>
```

Refer to a component's documentation for a complete list of its custom events.


## Slots

Many components use slots to accept content inside of them. The most common slot is the _default_ slot, which includes any content inside the component that doesn't have a `slot` attribute.

For example, a button's default slot is used to populate its label.

```html preview
 <bpme-login></bpme-login>
```

Some components also have _named_ slots. A named slot can be populated by adding a child element with the appropriate `slot` attribute. Notice how the h1 below has the `slot="title"` attribute? This tells the component to place the icon into its `prefix` slot.

```html preview
 <bpme-login backgroundImageURL="./assets/images/waves.jpg">
        <h1 class="docs-login-header" slot="title">TIBCO BPM Enterprise</h1>
</bpme-login>
```

The location of a named slot doesn't matter. You can put it anywhere inside the component and the browser will move it to the right place automatically!

Refer to a component's documentation for a complete list of available slots.



