# Working with BPM Components
#### This section delves deeper into interacting with BPM Business Components, covering techniques to enhance their functionality and integration within your applications.

## Passing Parameters to Components
Many components accept parameters that influence their behavior or data displayed. These parameters are typically passed as attributes in the component's HTML tag.

<div><b>Example:</b></div>
The `bpme-process-instance-list` component has a filter parameter that allows you to specify a filter expression.

```html
<bpme-process-instance-list filter="status='Running'"></bpme-process-instance-list>
```

This would display only running process instances.

Refer to the individual component's documentation for a complete list of supported parameters and their usage.

## Passing Data to Components

Some components allow you to pass data directly, enabling dynamic updates or customized content. This is often achieved through JavaScript and component properties.

```html
<bpme-work-items id="myWorkItems"></bpme-work-items>

<script>
  const workItemsComp = document.getElementById('myWorkItems');
  const workItemData = { /* Your work item data */ };
  workItemsComp.data = workItemData;
</script>
```

This code snippet retrieves the component using its ID, then assigns data to its data property.

## Listening to Component Events

Components emit events to signal changes or user interactions. You can listen to these events using JavaScript's `addEventListener` method.

```html
<bpme-process-instance-list id="processList"></bpme-process-instance-list>

<script>
  const processList = document.getElementById('processList');
  processList.addEventListener('bpm-process-instance-selected', (event) => {
    console.log("Selected process instance:", event.detail); 
  });
</script>
```

This code listens for the `bpm-process-instance-selected` event and logs details of the selected process instance.

Refer to the component's documentation for a list of emitted events and their payloads.


## Listening to Context Events

Context events are application-level events that can be triggered by components or other parts of your application. They provide a way for different components to communicate or react to global changes.

```javascript
document.addEventListener('bpm-context-updated', (event) => {
  console.log("Context updated:", event.detail); 
});
```

This code listens for the `bpm-context-updated` event, which might be triggered by a user logging in or changing application settings.

## Enabling System Actions
System actions are pre-defined actions within the BPM system, like starting a process or completing a task. You can enable these actions within your components to provide users with direct access to common BPM operations.

<b>Example:</b>

Refer to the specific component documentation and the "Usage" section for details on how to enable and configure system actions. This usually involves setting specific properties or using dedicated components for actions.

By mastering these advanced techniques, you can unlock the full potential of BPM Business Components and create truly integrated and interactive business applications. Remember to consult the detailed component documentation and the "Usage" section for comprehensive information and specific examples.
