const { setupWorker, rest, http, HttpResponse  } = MockServiceWorker;

const themesInfo = {
    "themes": [
        { 
            "name": "tibcoDefault",
            "label": "Default themes",
            "variants": [
                {
                    "name": "light",
                    "label": "Light",
                    "themeClass": "twc-theme-light",
                    "themeType": "light",
                    "isDefault": true
                },
                {
                    "name": "dark",
                    "label": "Dark",
                    "themeClass": "twc-theme-dark",
                    "themeType": "dark",
                    "isDefault": true
                }
            ]
        },
        { 
            "name": "myCustom",
            "label": "Custom themes",
            "variants": [
                {
                    "name": "light",
                    "label": "Light",
                    "themeClass": "twc-theme-light",
                    "themeType": "light",
                    "isDefault": false
                },
                {
                    "name": "dark",
                    "label": "Dark",
                    "themeClass": "twc-theme-dark",
                    "themeType": "dark",
                    "isDefault": false
                }
            ]
        }
    ]
}

const lightTheme = {
    "--tib-color-theme-0": "#ffffff",
    "--tib-color-theme-100": "#f2f2f2",
    "--tib-color-primary-50": "#e5f6ff",
    "--tib-color-primary-100": "#ccecff",
    "--tib-color-primary-200": "#99daff",
    "--tib-color-primary-300": "#66c7ff",
    "--tib-color-primary-400": "#33b5ff",
    "--tib-color-primary-500": "#00a2ff",
    "--tib-color-primary-600": "#0081cb",
    "--tib-color-primary-700": "#006199",
    "--tib-color-primary-800": "#004166",
    "--tib-color-primary-900": "#00314d",
    "--tib-color-secondary-50": "#e5efff",
    "--tib-color-secondary-100": "#ccdeff",
    "--tib-color-secondary-200": "#99bdff",
    "--tib-color-secondary-300": "#669dff",
    "--tib-color-secondary-400": "#337cff",
    "--tib-color-secondary-500": "#005bff",
    "--tib-color-secondary-600": "#0049cc",
    "--tib-color-secondary-700": "#003799",
    "--tib-color-secondary-800": "#002d7e",
    "--tib-color-secondary-900": "#001b4d",
    "--tib-color-accent-50": "#fff2e5",
    "--tib-color-accent-100": "#ffe4cc",
    "--tib-color-accent-200": "#ffc999",
    "--tib-color-accent-300": "#ffae66",
    "--tib-color-accent-400": "#ff9333",
    "--tib-color-accent-500": "#ff7800",
    "--tib-color-accent-600": "#cc6000",
    "--tib-color-accent-700": "#994800",
    "--tib-color-accent-800": "#803c00",
    "--tib-color-accent-900": "#4d2400",
    "--tib-color-error-50": "#ffe5eb",
    "--tib-color-error-100": "#ffccd6",
    "--tib-color-error-200": "#ff99ae",
    "--tib-color-error-300": "#ff6685",
    "--tib-color-error-400": "#ff335d",
    "--tib-color-error-500": "#ff0034",
    "--tib-color-error-600": "#c90029",
    "--tib-color-error-700": "#99001f",
    "--tib-color-error-800": "#80001a",
    "--tib-color-error-900": "#4d0010",
    "--tib-color-success-50": "#e5fff1",
    "--tib-color-success-100": "#ccffe2",
    "--tib-color-success-200": "#99ffc6",
    "--tib-color-success-300": "#66ffa9",
    "--tib-color-success-400": "#33ff8c",
    "--tib-color-success-500": "#00ff70",
    "--tib-color-success-600": "#00cb59",
    "--tib-color-success-700": "#009943",
    "--tib-color-success-800": "#008038",
    "--tib-color-success-900": "#004d22",
    "--tib-color-warning-50": "#fff8e5",
    "--tib-color-warning-100": "#fff1cc",
    "--tib-color-warning-200": "#ffe299",
    "--tib-color-warning-300": "#ffd466",
    "--tib-color-warning-400": "#ffc533",
    "--tib-color-warning-500": "#ffb700",
    "--tib-color-warning-600": "#cb9100",
    "--tib-color-warning-700": "#996e00",
    "--tib-color-warning-800": "#805b00",
    "--tib-color-warning-900": "#4d3700",
    "--tib-color-neutral-0": "#ffffff",
    "--tib-color-neutral-50": "#f2f2f2",
    "--tib-color-neutral-100": "#e6e6e6",
    "--tib-color-neutral-200": "#cccccc",
    "--tib-color-neutral-300": "#b3b3b3",
    "--tib-color-neutral-400": "#999999",
    "--tib-color-neutral-500": "#808080",
    "--tib-color-neutral-600": "#666666",
    "--tib-color-neutral-700": "#4d4d4d",
    "--tib-color-neutral-800": "#333333",
    "--tib-color-neutral-900": "#191919",
    "--tib-semantic-color-surface-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-surface-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-surface-primary-disabled": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-surface-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-surface-secondary-subtle": "var(--tib-color-secondary-50)",
    "--tib-semantic-color-surface-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-surface-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-surface-accent-subtle": "var(--tib-color-accent-50)",
    "--tib-semantic-color-surface-accent-disabled": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-surface-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-surface-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-surface-error-subtle": "var(--tib-color-error-50)",
    "--tib-semantic-color-surface-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-surface-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-surface-warning-subtle": "var(--tib-color-warning-50)",
    "--tib-semantic-color-surface-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-surface-success-hover": "var(--tib-color-success-700)",
    "--tib-semantic-color-surface-success-subtle": "var(--tib-color-success-50)",
    "--tib-semantic-color-surface-neutral-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-surface-neutral-hover": "var(--tib-color-neutral-50)",
    "--tib-semantic-color-surface-neutral-subtle": "var(--tib-color-neutral-50)",
    "--tib-semantic-color-text-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-text-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-text-primary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-text-secondary-subtle": "var(--tib-color-secondary-50)",
    "--tib-semantic-color-text-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-text-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-text-inverse-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-text-accent-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-inverse-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-text-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-text-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-text-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-text-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-text-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-text-success-hover": "var(--tib-color-success-800)",
    "--tib-semantic-color-text-neutral-default": "var(--tib-color-neutral-900)",
    "--tib-semantic-color-text-neutral-subtle": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-neutral-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-icon-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-icon-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-icon-primary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-icon-secondary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-icon-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-icon-accent-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-inverse-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-icon-inverse-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-icon-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-icon-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-icon-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-icon-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-icon-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-icon-success-hover": "var(--tib-color-success-700)",
    "--tib-semantic-color-icon-neutral-default": "var(--tib-color-neutral-900)",
    "--tib-semantic-color-icon-neutral-subtle": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-neutral-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-border-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-border-primary-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-border-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-border-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-border-accent-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-border-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-border-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-border-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-border-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-border-success-hover": "var(--tib-color-success-800)",
    "--tib-semantic-color-border-neutral-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-border-neutral-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-border-neutral-emphasis": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-background-default": "var(--tib-color-theme-0)",
    "--tib-semantic-color-background-subtle": "var(--tib-color-theme-100)",
    "--tib-semantic-selected-text-default": "var(--tib-semantic-color-text-secondary-default)",
    "--tib-semantic-selected-icon-default": "var(--tib-semantic-color-icon-secondary-default)",
    "--tib-semantic-selected-border-default": "var(--tib-semantic-color-border-secondary-default)",
    "--tib-semantic-selected-surface-default": "var(--tib-semantic-color-surface-secondary-subtle)",
    "--tib-semantic-sizing-hw-1": "0.25rem",
    "--tib-semantic-sizing-hw-2": "0.5rem",
    "--tib-semantic-sizing-hw-3": "0.75rem",
    "--tib-semantic-sizing-hw-4": "1rem",
    "--tib-semantic-sizing-hw-5": "1.25rem",
    "--tib-semantic-sizing-hw-6": "1.5rem",
    "--tib-semantic-sizing-hw-7": "1.75rem",
    "--tib-semantic-sizing-hw-8": "2rem",
    "--tib-semantic-sizing-hw-9": "2.25rem",
    "--tib-semantic-sizing-hw-10": "2.5rem",
    "--tib-semantic-sizing-hw-12": "3rem",
    "--tib-semantic-sizing-hw-13": "3.5rem",
    "--tib-semantic-sizing-hw-14": "4rem",
    "--tib-semantic-sizing-hw-15": "4.5rem",
    "--tib-semantic-sizing-hw-16": "5.25rem",
    "--tib-semantic-sizing-hw-17": "6rem",
    "--tib-semantic-sizing-hw-27": "6.75rem",
    "--tib-semantic-sizing-hw-30": "7.5rem",
    "--tib-semantic-sizing-hw-36": "9rem",
    "--tib-semantic-sizing-hw-40": "10rem",
    "--tib-semantic-sizing-hw-60": "15rem",
    "--tib-semantic-sizing-hw-80": "20rem",
    "--tib-semantic-sizing-hw-82": "20.5rem",
    "--tib-semantic-sizing-hw-100": "25rem",
    "--tib-semantic-sizing-icon-xs": "1rem",
    "--tib-semantic-sizing-icon-sm": "1.25rem",
    "--tib-semantic-sizing-icon-md": "1.5rem",
    "--tib-semantic-sizing-icon-lg": "1.75rem",
    "--tib-semantic-sizing-icon-xl": "2rem",
    "--tib-semantic-sizing-icon-2xl": "2.25rem",
    "--tib-semantic-sizing-icon-3xl": "2.5rem",
    "--tib-semantic-padding-px-none": "0rem",
    "--tib-semantic-padding-px-xxxs": "0.125rem",
    "--tib-semantic-padding-px-xxs": "0.25rem",
    "--tib-semantic-padding-px-xs": "0.5rem",
    "--tib-semantic-padding-px-sm": "0.75rem",
    "--tib-semantic-padding-px-md": "1rem",
    "--tib-semantic-padding-px-lg": "1.25rem",
    "--tib-semantic-padding-px-xl": "1.5rem",
    "--tib-semantic-padding-px-2xl": "1.75rem",
    "--tib-semantic-padding-px-3xl": "2rem",
    "--tib-semantic-padding-px-4xl": "3rem",
    "--tib-semantic-padding-py-none": "0rem",
    "--tib-semantic-padding-py-xxxs": "0.125rem",
    "--tib-semantic-padding-py-xxs": "0.25rem",
    "--tib-semantic-padding-py-xs": "0.5rem",
    "--tib-semantic-padding-py-sm": "0.75rem",
    "--tib-semantic-padding-py-md": "1rem",
    "--tib-semantic-padding-py-lg": "1.25rem",
    "--tib-semantic-padding-py-xl": "1.5rem",
    "--tib-semantic-padding-py-2xl": "1.75rem",
    "--tib-semantic-padding-py-3xl": "2rem",
    "--tib-semantic-padding-py-4xl": "3rem",
    "--tib-semantic-spacing-spc-none": "0rem",
    "--tib-semantic-spacing-spc-xxxs": "0.125rem",
    "--tib-semantic-spacing-spc-xxs": "0.25rem",
    "--tib-semantic-spacing-spc-xs": "0.5rem",
    "--tib-semantic-spacing-spc-sm": "0.75rem",
    "--tib-semantic-spacing-spc-md": "1rem",
    "--tib-semantic-spacing-spc-lg": "1.25rem",
    "--tib-semantic-spacing-spc-xl": "1.5rem",
    "--tib-semantic-spacing-spc-2xl": "1.75rem",
    "--tib-semantic-spacing-spc-3xl": "2rem",
    "--tib-semantic-border-radius-br-none": "0rem",
    "--tib-semantic-border-radius-br-xs": "0.125rem",
    "--tib-semantic-border-radius-br-sm": "0.25rem",
    "--tib-semantic-border-radius-br-md": "0.5rem",
    "--tib-semantic-border-radius-br-lg": "0.75rem",
    "--tib-semantic-border-radius-br-xl": "1rem",
    "--tib-semantic-border-radius-br-circle": "50%",
    "--tib-semantic-border-radius-br-pill": "9999rem",
    "--tib-semantic-toggle-visibility-show": "0rem",
    "--tib-semantic-toggle-visibility-hide": "0.0625rem",
    "--tib-core-line-height-100": "0.0625rem",
    "--tib-core-line-height-125": "0.078125rem",
    "--tib-core-line-height-150": "0.09375rem",
    "--tib-core-font-size-rem": "1rem",
    "--tib-core-font-size-scaled-50": "0.5rem",
    "--tib-core-font-size-scaled-62": "0.625rem",
    "--tib-core-font-size-scaled-75": "0.75rem",
    "--tib-core-font-size-scaled-87": "0.875rem",
    "--tib-core-font-size-scaled-100": "1rem",
    "--tib-core-font-size-scaled-125": "1.25rem",
    "--tib-core-font-size-scaled-150": "1.5rem",
    "--tib-core-font-size-scaled-175": "1.75rem",
    "--tib-core-font-size-scaled-200": "2rem",
    "--tib-core-font-size-scaled-225": "2.25rem",
    "--tib-core-font-size-scaled-250": "2.5rem",
    "--tib-core-font-size-scaled-275": "2.75rem",
    "--tib-core-font-size-scaled-300": "3rem",
    "--tib-core-font-size-scaled-400": "4rem",
    "--tib-core-font-size-scaled-base": "0.01rem",
    "--tib-core-size-scale": "16",
    "--tib-core-shadow-blur-0": "0 0 0 0 #000000",
    "--tib-core-shadow-blur-1": "0 1px 3px 0 #cccccc",
    "--tib-core-shadow-blur-2": "0 2px 4px 0 #cccccc",
    "--tib-core-shadow-blur-3": "0 2px 8px 0 #cccccc",
    "--tib-core-shadow-blur-4": "0 2px 12px 0 #cccccc",
    "--tib-core-shadow-blur-5": "0 2px 16px 0 #cccccc",
    "--tib-core-shadow-blur-6": "0 2px 20px 0 #cccccc",
    "--tib-core-opacity-0": "0",
    "--tib-core-opacity-1": "0.1",
    "--tib-core-opacity-2": "0.2",
    "--tib-core-opacity-3": "0.3",
    "--tib-core-opacity-4": "0.4",
    "--tib-core-opacity-5": "0.5",
    "--tib-core-opacity-6": "0.6",
    "--tib-core-opacity-7": "0.7",
    "--tib-core-opacity-8": "0.8",
    "--tib-core-opacity-9": "0.9",
    "--tib-core-opacity-10": "1",
    "--tib-core-border-width-0": "0rem",
    "--tib-core-border-width-10": "0.0625rem",
    "--tib-core-border-width-20": "0.125rem",
    "--tib-core-border-width-40": "0.25rem",
    "--tib-core-border-width-80": "0.5rem",
    "--tib-base-shadow-focus-border": "0 0 0 2px #cccccc",
    "--tib-base-shadow-xs": "0 1px 3px 0 #cccccc",
    "--tib-base-shadow-sm": "0 2px 4px 0 #cccccc",
    "--tib-base-shadow-md": "0 2px 8px 0 #cccccc",
    "--tib-base-shadow-lg": "0 2px 12px 0 #cccccc",
    "--tib-base-shadow-xl": "0 2px 16px 0 #cccccc",
    "--tib-base-shadow-2xl": "0 2px 20px 0 #cccccc",
    "--tib-base-border-width-1": "0.0625rem",
    "--tib-base-border-width-2": "0.125rem",
    "--tib-base-border-width-4": "0.25rem",
    "--tib-base-border-width-none": "0rem",
    "--tib-base-font-family-title": "\"Source Sans Pro\"",
    "--tib-base-font-family-body": "\"Source Sans Pro\"",
    "--tib-base-font-weight-light": "300",
    "--tib-base-font-weight-regular": "400",
    "--tib-base-font-weight-semibold": "600",
    "--tib-base-font-weight-bold": "700",
    "--tib-base-font-size-xs": "0.75rem",
    "--tib-base-font-size-sm": "0.875rem",
    "--tib-base-font-size-md": "1rem",
    "--tib-base-font-size-lg": "1.25rem",
    "--tib-base-font-size-xl": "1.5rem",
    "--tib-base-font-size-2xl": "1.75rem",
    "--tib-base-font-size-3xl": "2rem",
    "--tib-base-font-size-4xl": "3rem",
    "--tib-base-font-size-5xl": "4rem",
    "--tib-base-line-height-title-lg": "1.5rem",
    "--tib-base-line-height-title-xl": "1.875rem",
    "--tib-base-line-height-title-2xl": "2.25rem",
    "--tib-base-line-height-title-3xl": "2.5rem",
    "--tib-base-line-height-title-4xl": "3.75rem",
    "--tib-base-line-height-title-5xl": "5rem",
    "--tib-base-line-height-body-sm": "1.25rem",
    "--tib-base-line-height-body-md": "1.5rem",
    "--tib-base-line-height-label-xs": "1.125rem",
    "--tib-transition-x-slow": "1000ms",
    "--tib-transition-slow": "500ms",
    "--tib-transition-medium": "250ms",
    "--tib-transition-fast": "150ms",
    "--tib-transition-x-fast": "50ms",
    "--tib-focus-ring-alpha": "40%",
    "--tib-focus-ring-width": "3px",
    "--tib-focus-ring": "0 0 0 var(--tib-focus-ring-width) hsl(198.6 88.7% 48.4% / var(--tib-focus-ring-alpha))",
    "--tib-overlay-background-color": "hsl(240 3.8% 46.1% / 33%)",
    "--tib-z-index-drawer": "700",
    "--tib-z-index-dialog": "800",
    "--tib-z-index-dropdown": "900",
    "--tib-z-index-toast": "950",
    "--tib-z-index-tooltip": "1000",
    "--tib-letter-spacing-denser": "-0.03em",
    "--tib-letter-spacing-dense": "-0.015em",
    "--tib-letter-spacing-normal": "normal",
    "--tib-letter-spacing-loose": "0.075em",
    "--tib-letter-spacing-looser": "0.15em",
    "--tib-component-gnh-surface-default": "var(--tib-color-secondary-800)",
    "--tib-component-gnh-icon-default": "var(--tib-color-neutral-0)",
    "--tib-component-gnh-text-default": "var(--tib-color-neutral-0)"
}

const darkTheme = {
    "--tib-color-theme-0": "#000000",
    "--tib-color-theme-100": "#000000",
    "--tib-color-primary-50": "#00314D",
    "--tib-color-primary-100": "#00314D",
    "--tib-color-primary-200": "#004166",
    "--tib-color-primary-300": "#006199",
    "--tib-color-primary-400": "#0081CB",
    "--tib-color-primary-500": "#00A2FF",
    "--tib-color-primary-600": "#33B5FF",
    "--tib-color-primary-700": "#66C7FF",
    "--tib-color-primary-800": "#99DAFF",
    "--tib-color-primary-900": "#E5F6FF",
    "--tib-color-secondary-50": "#001B4D",
    "--tib-color-secondary-100": "#002D7E",
    "--tib-color-secondary-200": "#003799",
    "--tib-color-secondary-300": "#0049CC",
    "--tib-color-secondary-400": "#005BFF",
    "--tib-color-secondary-500": "#337CFF",
    "--tib-color-secondary-600": "#669DFF",
    "--tib-color-secondary-700": "#99BDFF",
    "--tib-color-secondary-800": "#CCDEFF",
    "--tib-color-secondary-900": "#E5EFFF",
    "--tib-color-accent-50": "#4D2400",
    "--tib-color-accent-100": "#803C00",
    "--tib-color-accent-200": "#994800",
    "--tib-color-accent-300": "#CC6000",
    "--tib-color-accent-400": "#FF7800",
    "--tib-color-accent-500": "#FF9333",
    "--tib-color-accent-600": "#FFAE66",
    "--tib-color-accent-700": "#FFC999",
    "--tib-color-accent-800": "#FFE4CC",
    "--tib-color-accent-900": "#FFF2E5",
    "--tib-color-error-50": "#4D0010",
    "--tib-color-error-100": "#80001A",
    "--tib-color-error-200": "#99001F",
    "--tib-color-error-300": "#C90029",
    "--tib-color-error-400": "#C90029",
    "--tib-color-error-500": "#FF335D",
    "--tib-color-error-600": "#FF6685",
    "--tib-color-error-700": "#FF99AE",
    "--tib-color-error-800": "#FFCCD6",
    "--tib-color-error-900": "#FFE5EB",
    "--tib-color-success-50": "#004D22",
    "--tib-color-success-100": "#008038",
    "--tib-color-success-200": "#009943",
    "--tib-color-success-300": "#00CB59",
    "--tib-color-success-400": "#00FF70",
    "--tib-color-success-500": "#33FF8C",
    "--tib-color-success-600": "#66FFA9",
    "--tib-color-success-700": "#99FFC6",
    "--tib-color-success-800": "#CCFFE2",
    "--tib-color-success-900": "#E5FFF1",
    "--tib-color-warning-50": "#4D3700",
    "--tib-color-warning-100": "#805B00",
    "--tib-color-warning-200": "#996E00",
    "--tib-color-warning-300": "#CB9100",
    "--tib-color-warning-400": "#FFB700",
    "--tib-color-warning-500": "#FFC533",
    "--tib-color-warning-600": "#FFD466",
    "--tib-color-warning-700": "#FFE299",
    "--tib-color-warning-800": "#FFF1CC",
    "--tib-color-warning-900": "#FFF8E5",
    "--tib-color-neutral-0": "#191919",
    "--tib-color-neutral-50": "#333333",
    "--tib-color-neutral-100": "#4D4D4D",
    "--tib-color-neutral-200": "#666666",
    "--tib-color-neutral-300": "#808080",
    "--tib-color-neutral-400": "#999999",
    "--tib-color-neutral-500": "#B3B3B3",
    "--tib-color-neutral-600": "#CCCCCC",
    "--tib-color-neutral-700": "#E6E6E6",
    "--tib-color-neutral-800": "#F2F2F2",
    "--tib-color-neutral-900": "#FFFFFF",
    "--tib-semantic-color-surface-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-surface-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-surface-primary-disabled": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-surface-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-surface-secondary-subtle": "var(--tib-color-secondary-50)",
    "--tib-semantic-color-surface-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-surface-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-surface-accent-subtle": "var(--tib-color-accent-50)",
    "--tib-semantic-color-surface-accent-disabled": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-surface-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-surface-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-surface-error-subtle": "var(--tib-color-error-50)",
    "--tib-semantic-color-surface-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-surface-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-surface-warning-subtle": "var(--tib-color-warning-50)",
    "--tib-semantic-color-surface-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-surface-success-hover": "var(--tib-color-success-700)",
    "--tib-semantic-color-surface-success-subtle": "var(--tib-color-success-50)",
    "--tib-semantic-color-surface-neutral-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-surface-neutral-hover": "var(--tib-color-neutral-50)",
    "--tib-semantic-color-surface-neutral-subtle": "var(--tib-color-neutral-50)",
    "--tib-semantic-color-text-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-text-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-text-primary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-text-secondary-subtle": "var(--tib-color-secondary-50)",
    "--tib-semantic-color-text-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-text-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-text-inverse-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-text-accent-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-inverse-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-text-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-text-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-text-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-text-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-text-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-text-success-hover": "var(--tib-color-success-800)",
    "--tib-semantic-color-text-neutral-default": "var(--tib-color-neutral-900)",
    "--tib-semantic-color-text-neutral-subtle": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-text-neutral-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-icon-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-icon-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-icon-primary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-icon-secondary-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-icon-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-icon-accent-disabled": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-inverse-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-icon-inverse-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-icon-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-icon-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-icon-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-icon-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-icon-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-icon-success-hover": "var(--tib-color-success-700)",
    "--tib-semantic-color-icon-neutral-default": "var(--tib-color-neutral-900)",
    "--tib-semantic-color-icon-neutral-subtle": "var(--tib-color-neutral-500)",
    "--tib-semantic-color-icon-neutral-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-primary-default": "var(--tib-color-primary-600)",
    "--tib-semantic-color-border-primary-hover": "var(--tib-color-primary-700)",
    "--tib-semantic-color-border-primary-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-secondary-default": "var(--tib-color-secondary-800)",
    "--tib-semantic-color-border-accent-default": "var(--tib-color-accent-500)",
    "--tib-semantic-color-border-accent-hover": "var(--tib-color-accent-600)",
    "--tib-semantic-color-border-accent-disabled": "var(--tib-color-neutral-200)",
    "--tib-semantic-color-border-error-default": "var(--tib-color-error-600)",
    "--tib-semantic-color-border-error-hover": "var(--tib-color-error-700)",
    "--tib-semantic-color-border-warning-default": "var(--tib-color-warning-500)",
    "--tib-semantic-color-border-warning-hover": "var(--tib-color-warning-600)",
    "--tib-semantic-color-border-success-default": "var(--tib-color-success-600)",
    "--tib-semantic-color-border-success-hover": "var(--tib-color-success-800)",
    "--tib-semantic-color-background-default": "var(--tib-color-theme-0)",
    "--tib-semantic-color-border-neutral-default": "var(--tib-color-neutral-0)",
    "--tib-semantic-color-border-neutral-subtle": "var(--tib-color-neutral-100)",
    "--tib-semantic-color-background-subtle": "var(--tib-color-theme-100)",
    "--tib-semantic-color-border-neutral-emphasis": "var(--tib-color-neutral-500)",
    "--tib-semantic-selected-text-default": "var(--tib-semantic-color-text-primary-default)",
    "--tib-semantic-selected-icon-default": "var(--tib-semantic-color-icon-primary-default)",
    "--tib-semantic-selected-border-default": "var(--tib-semantic-color-border-primary-default)",
    "--tib-semantic-selected-surface-default": "var(--tib-semantic-color-surface-neutral-subtle)",
    "--tib-semantic-sizing-hw-1": "0.25rem",
    "--tib-semantic-sizing-hw-2": "0.5rem",
    "--tib-semantic-sizing-hw-3": "0.75rem",
    "--tib-semantic-sizing-hw-4": "1rem",
    "--tib-semantic-sizing-hw-5": "1.25rem",
    "--tib-semantic-sizing-hw-6": "1.5rem",
    "--tib-semantic-sizing-hw-7": "1.75rem",
    "--tib-semantic-sizing-hw-8": "2rem",
    "--tib-semantic-sizing-hw-9": "2.25rem",
    "--tib-semantic-sizing-hw-10": "2.5rem",
    "--tib-semantic-sizing-hw-12": "3rem",
    "--tib-semantic-sizing-hw-13": "3.5rem",
    "--tib-semantic-sizing-hw-14": "4rem",
    "--tib-semantic-sizing-hw-15": "4.5rem",
    "--tib-semantic-sizing-hw-16": "5.25rem",
    "--tib-semantic-sizing-hw-17": "6rem",
    "--tib-semantic-sizing-hw-27": "6.75rem",
    "--tib-semantic-sizing-hw-30": "7.5rem",
    "--tib-semantic-sizing-hw-36": "9rem",
    "--tib-semantic-sizing-hw-40": "10rem",
    "--tib-semantic-sizing-hw-60": "15rem",
    "--tib-semantic-sizing-hw-80": "20rem",
    "--tib-semantic-sizing-hw-82": "20.5rem",
    "--tib-semantic-sizing-hw-100": "25rem",
    "--tib-semantic-sizing-icon-xs": "1rem",
    "--tib-semantic-sizing-icon-sm": "1.25rem",
    "--tib-semantic-sizing-icon-md": "1.5rem",
    "--tib-semantic-sizing-icon-lg": "1.75rem",
    "--tib-semantic-sizing-icon-xl": "2rem",
    "--tib-semantic-sizing-icon-2xl": "2.25rem",
    "--tib-semantic-sizing-icon-3xl": "2.5rem",
    "--tib-semantic-padding-px-none": "0rem",
    "--tib-semantic-padding-px-xxxs": "0.125rem",
    "--tib-semantic-padding-px-xxs": "0.25rem",
    "--tib-semantic-padding-px-xs": "0.5rem",
    "--tib-semantic-padding-px-sm": "0.75rem",
    "--tib-semantic-padding-px-md": "1rem",
    "--tib-semantic-padding-px-lg": "1.25rem",
    "--tib-semantic-padding-px-xl": "1.5rem",
    "--tib-semantic-padding-px-2xl": "1.75rem",
    "--tib-semantic-padding-px-3xl": "2rem",
    "--tib-semantic-padding-px-4xl": "3rem",
    "--tib-semantic-padding-py-none": "0rem",
    "--tib-semantic-padding-py-xxxs": "0.125rem",
    "--tib-semantic-padding-py-xxs": "0.25rem",
    "--tib-semantic-padding-py-xs": "0.5rem",
    "--tib-semantic-padding-py-sm": "0.75rem",
    "--tib-semantic-padding-py-md": "1rem",
    "--tib-semantic-padding-py-lg": "1.25rem",
    "--tib-semantic-padding-py-xl": "1.5rem",
    "--tib-semantic-padding-py-2xl": "1.75rem",
    "--tib-semantic-padding-py-3xl": "2rem",
    "--tib-semantic-padding-py-4xl": "3rem",
    "--tib-semantic-spacing-spc-none": "0rem",
    "--tib-semantic-spacing-spc-xxxs": "0.125rem",
    "--tib-semantic-spacing-spc-xxs": "0.25rem",
    "--tib-semantic-spacing-spc-xs": "0.5rem",
    "--tib-semantic-spacing-spc-sm": "0.75rem",
    "--tib-semantic-spacing-spc-md": "1rem",
    "--tib-semantic-spacing-spc-lg": "1.25rem",
    "--tib-semantic-spacing-spc-xl": "1.5rem",
    "--tib-semantic-spacing-spc-2xl": "1.75rem",
    "--tib-semantic-spacing-spc-3xl": "2rem",
    "--tib-semantic-border-radius-br-none": "0rem",
    "--tib-semantic-border-radius-br-xs": "0.125rem",
    "--tib-semantic-border-radius-br-sm": "0.25rem",
    "--tib-semantic-border-radius-br-md": "0.5rem",
    "--tib-semantic-border-radius-br-lg": "0.75rem",
    "--tib-semantic-border-radius-br-xl": "1rem",
    "--tib-semantic-toggle-visibility-show": "0rem",
    "--tib-semantic-toggle-visibility-hide": "0.0625rem",
    "--tib-core-line-height-100": "0.0625rem",
    "--tib-core-line-height-125": "0.078125rem",
    "--tib-core-line-height-150": "0.09375rem",
    "--tib-core-font-size-rem": "1rem",
    "--tib-core-font-size-scaled-50": "0.5rem",
    "--tib-core-font-size-scaled-62": "0.625rem",
    "--tib-core-font-size-scaled-75": "0.75rem",
    "--tib-core-font-size-scaled-87": "0.875rem",
    "--tib-core-font-size-scaled-100": "1rem",
    "--tib-core-font-size-scaled-125": "1.25rem",
    "--tib-core-font-size-scaled-150": "1.5rem",
    "--tib-core-font-size-scaled-175": "1.75rem",
    "--tib-core-font-size-scaled-200": "2rem",
    "--tib-core-font-size-scaled-225": "2.25rem",
    "--tib-core-font-size-scaled-250": "2.5rem",
    "--tib-core-font-size-scaled-275": "2.75rem",
    "--tib-core-font-size-scaled-300": "3rem",
    "--tib-core-font-size-scaled-400": "4rem",
    "--tib-core-font-size-scaled-base": "0.01rem",
    "--tib-core-size-scale": "16",
    "--tib-core-shadow-blur-0": "0 0 0 0 #000000",
    "--tib-core-shadow-blur-1": "0 1px 3px 0 #cccccc",
    "--tib-core-shadow-blur-2": "0 2px 4px 0 #cccccc",
    "--tib-core-shadow-blur-3": "0 2px 8px 0 #cccccc",
    "--tib-core-shadow-blur-4": "0 2px 12px 0 #cccccc",
    "--tib-core-shadow-blur-5": "0 2px 16px 0 #cccccc",
    "--tib-core-shadow-blur-6": "0 2px 20px 0 #cccccc",
    "--tib-core-opacity-0": "0",
    "--tib-core-opacity-1": "0.1",
    "--tib-core-opacity-2": "0.2",
    "--tib-core-opacity-3": "0.3",
    "--tib-core-opacity-4": "0.4",
    "--tib-core-opacity-5": "0.5",
    "--tib-core-opacity-6": "0.6",
    "--tib-core-opacity-7": "0.7",
    "--tib-core-opacity-8": "0.8",
    "--tib-core-opacity-9": "0.9",
    "--tib-core-opacity-10": "1",
    "--tib-core-border-width-0": "0rem",
    "--tib-core-border-width-10": "0.0625rem",
    "--tib-core-border-width-20": "0.125rem",
    "--tib-core-border-width-40": "0.25rem",
    "--tib-core-border-width-80": "0.5rem",
    "--tib-base-shadow-focus-border": "0 0 0 2px #cccccc",
    "--tib-base-shadow-xs": "0 1px 3px 0 #cccccc",
    "--tib-base-shadow-sm": "0 2px 4px 0 #cccccc",
    "--tib-base-shadow-md": "0 2px 8px 0 #cccccc",
    "--tib-base-shadow-lg": "0 2px 12px 0 #cccccc",
    "--tib-base-shadow-xl": "0 2px 16px 0 #cccccc",
    "--tib-base-shadow-2xl": "0 2px 20px 0 #cccccc",
    "--tib-base-border-width-1": "0.0625rem",
    "--tib-base-border-width-2": "0.125rem",
    "--tib-base-border-width-4": "0.25rem",
    "--tib-base-border-width-none": "0rem",
    "--tib-base-font-family-title": "\"Source Sans Pro\"",
    "--tib-base-font-family-body": "\"Source Sans Pro\"",
    "--tib-base-font-weight-light": "300",
    "--tib-base-font-weight-regular": "400",
    "--tib-base-font-weight-semibold": "600",
    "--tib-base-font-weight-bold": "700",
    "--tib-base-font-size-xs": "0.75rem",
    "--tib-base-font-size-sm": "0.875rem",
    "--tib-base-font-size-md": "1rem",
    "--tib-base-font-size-lg": "1.25rem",
    "--tib-base-font-size-xl": "1.5rem",
    "--tib-base-font-size-2xl": "1.75rem",
    "--tib-base-font-size-3xl": "2rem",
    "--tib-base-font-size-4xl": "3rem",
    "--tib-base-font-size-5xl": "4rem",
    "--tib-base-line-height-title-lg": "1.5rem",
    "--tib-base-line-height-title-xl": "1.875rem",
    "--tib-base-line-height-title-2xl": "2.25rem",
    "--tib-base-line-height-title-3xl": "2.5rem",
    "--tib-base-line-height-title-4xl": "3.75rem",
    "--tib-base-line-height-title-5xl": "5rem",
    "--tib-base-line-height-body-sm": "1.25rem",
    "--tib-base-line-height-body-md": "1.5rem",
    "--tib-base-line-height-label-xs": "1.125rem",
    "--tib-component-gnh-surface-default": "var(--tib-color-secondary-100)",
    "--tib-component-gnh-icon-default": "var(--tib-color-neutral-900)",
    "--tib-component-gnh-text-default": "var(--tib-color-neutral-900)"
}

const themeVariables = {
    "basic": {
      "categories": [
        {
          "name": "backgroundColor",
          "label": "Background color",
          "description": "Select background colors",
          "properties": [{
            "name": "neutral",
            "label": "Background color",
            "description": "Denotes the overall background color of the app.",
            "token": "--tib-semantic-color-surface-neutral-default",
            "palletteShade": "0",
            "relativeTokens": [{
              "name": "nSubtle",
              "label": "Background subtle",
              "description": "Primarily reflects the on hover color of elements having Surface default as BG color",
              "token": "--tib-semantic-color-surface-neutral-subtle",
              "palletteShade": "50"
            }],
            "extendedTokens": [{
              "name": "pDisabled",
              "label": "Primary BG disabled",
              "description": "The background color for primary interactive elements that are disabled",
              "token": "--tib-semantic-color-surface-primary-disabled",
              "palletteShade": "100"
            }, {
              "name": "pIconDisabled",
              "label": "Disabled primary icon",
              "description": "The color for icons within disabled primary interactive elements",
              "token": "--tib-semantic-color-icon-primary-disabled",
              "palletteShade": "500"
            }, {
              "name": "pBorderDisabled",
              "label": "Disabled primary border",
              "description": "The border color for disabled primary interactive elements",
              "token": "--tib-semantic-color-border-primary-disabled",
              "palletteShade": "200"
            }, {
              "name": "pTextDisabled",
              "label": "Disabled primary text",
              "description": "The color for text elements within disabled primary interactive elements",
              "token": "--tib-semantic-color-text-primary-disabled",
              "palletteShade": "500"
            }, {
              "name": "sIconDisabled",
              "label": "Disabled secondary icon",
              "description": "The color for icons within disabled secondary interactive elements",
              "token": "--tib-semantic-color-icon-secondary-disabled",
              "palletteShade": "500"
            }, {
              "name": "aDisabled",
              "label": "Accent BG disabled",
              "description": "The background color for accent interactive elements that are disabled",
              "token": "--tib-semantic-color-surface-accent-disabled",
              "palletteShade": "100"
            }, {
              "name": "aTextDisabled",
              "label": "Disabled accent text",
              "description": "The color for text elements when hovering over accent interactive elements",
              "token": "--tib-semantic-color-text-accent-disabled",
              "palletteShade": "500"
            }, {
              "name": "aIconDisabled",
              "label": "Disabled accent icon",
              "description": "The color for icons within disabled accent interactive elements",
              "token": "--tib-semantic-color-icon-accent-disabled",
              "palletteShade": "500"
            }, {
              "name": "aBorderDisabled",
              "label": "Disabled accent border",
              "description": "The border color for disabled accent interactive elements",
              "token": "--tib-semantic-color-border-accent-disabled",
              "palletteShade": "200"
            }]
          },
          {
            "name": "primary",
            "label": "Primary",
            "description": "The standard background color for primary interactive elements (e.g., buttons, primary cards)",
            "token": "--tib-semantic-color-surface-primary-default",
            "palletteShade": "600",
            "relativeTokens": [{
              "name": "pHover",
              "label": "Primary BG hover",
              "description": "The background color of primary interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-surface-primary-hover",
              "palletteShade": "700"
            }
          ],
            "extendedTokens": [{
              "name": "pText",
              "label": "Primary text",
              "description": "The default color for text elements associated with primary interactive elements or branding",
              "token": "--tib-semantic-color-text-primary-default",
              "palletteShade": "600"
            }, {
              "name": "pTextHover",
              "label": "Primary text hover",
              "description": "The color for text elements when hovering over primary interactive elements",
              "token": "--tib-semantic-color-text-primary-hover",
              "palletteShade": "700"
            }, {
              "name": "pIcon",
              "label": "Primary icon",
              "description": "The default color for icons associated with primary interactive elements or branding",
              "token": "--tib-semantic-color-icon-primary-default",
              "palletteShade": "500"
            }, {
              "name": "pIconHover",
              "label": "Primary icon hover",
              "description": "The color for icons when hovering over primary interactive elements",
              "token": "--tib-semantic-color-icon-primary-hover",
              "palletteShade": "700"
            }, {
              "name": "pBorder",
              "label": "Primary border",
              "description": "The default border color for primary interactive elements or branding",
              "token": "--tib-semantic-color-border-primary-default",
              "palletteShade": "600"
            }, {
              "name": "pBorderHover",
              "label": "Border primary hover",
              "description": "The border color for primary interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-border-primary-hover",
              "palletteShade": "700"
            }]
          },
          {
            "name": "secondaryBrand",
            "label": "Secondary",
            "description": "The standard background color for secondary interactive elements. In this case, the GNH",
            "token": "--tib-semantic-color-surface-secondary-default",
            "palletteShade": "800",
            "relativeTokens": [{
              "name": "sSubtle",
              "label": "Secondary BG subtle",
              "description": "A more subtle variation of the secondary color, used for backgrounds of less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-surface-secondary-subtle",
              "palletteShade": "50"
            }
          ],
            "extendedTokens": [{
              "name": "sText",
              "label": "Secondary text",
              "description": "The default color for text elements associated with secondary interactive elements",
              "token": "--tib-semantic-color-text-secondary-default",
              "palletteShade": "800"
            }, {
              "name": "sTextSubtle",
              "label": "Subtle Secondary text",
              "description": "A more subtle variation of the secondary text color, used for less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-text-secondary-subtle",
              "palletteShade": "50"
            }, {
              "name": "sIcon",
              "label": "Secondary icon",
              "description": "The default color for icons associated with secondary interactive elements",
              "token": "--tib-semantic-color-icon-secondary-default",
              "palletteShade": "800"
            }, {
              "name": "sBorder",
              "label": "Secondary border",
              "description": "The default border color for secondary interactive elements",
              "token": "--tib-semantic-color-border-secondary-default",
              "palletteShade": "800"
            }]
          },
          {
            "name": "accent",
            "label": "Accent",
            "description": "The standard background color for accent interactive elements, used to highlight important actions or information",
            "token": "--tib-semantic-color-surface-accent-default",
            "palletteShade": "500",
            "relativeTokens": [{
              "name": "aHover",
              "label": "Accent BG hover",
              "description": "The background color of accent interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-surface-accent-hover",
              "palletteShade": "600"
            }, {
              "name": "aSubtle",
              "label": "Accent BG subtle",
              "description": "A more subtle variation of the accent color, used for backgrounds of less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-surface-accent-subtle",
              "palletteShade": "50"
            }
          ],
            "extendedTokens": [{
              "name": "aText",
              "label": "Accent text",
              "description": "The default color for text elements associated with accent interactive elements or used to highlight key information",
              "token": "--tib-semantic-color-text-accent-default",
              "palletteShade": "500"
            }, {
              "name": "aTextSubtle",
              "label": "Subtle accent text",
              "description": "A more subtle variation of the accent text color, used for less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-text-accent-subtle",
              "palletteShade": "600"
            }, {
              "name": "aIcon",
              "label": "Accent icon",
              "description": "The default color for icons associated with accent interactive elements",
              "token": "--tib-semantic-color-icon-accent-default",
              "palletteShade": "500"
            }, {
              "name": "aIconHover",
              "label": "Accent icon hover",
              "description": "The color for icons when hovering over accent interactive elements",
              "token": "--tib-semantic-color-icon-accent-hover",
              "palletteShade": "600"
            }, {
              "name": "aBorder",
              "label": "Accent border",
              "description": "The default border color for accent interactive elements",
              "token": "--tib-semantic-color-border-accent-default",
              "palletteShade": "500"
            }, {
              "name": "aBorderHover",
              "label": "Accent border hover",
              "description": "The border color for accent interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-border-accent-hover",
              "palletteShade": "600"
            }]
          },
          {
            "name": "success",
            "label": "Success",
            "description": "The standard background color for success interactive elements, used to indicate successful actions or positive outcomes",
            "token": "--tib-semantic-color-surface-success-default",
            "palletteShade": "600",
            "relativeTokens": [{
              "name": "sHover",
              "label": "Success BG hover",
              "description": "The background color of success interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-surface-success-hover",
              "palletteShade": "700"
            }, {
              "name": "sSubtle",
              "label": "Success BG subtle",
              "description": "A more subtle variation of the success color, used for backgrounds of less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-surface-success-subtle",
              "palletteShade": "50"
            }
          ],
            "extendedTokens": [{
              "name": "sText",
              "label": "Success text",
              "description": "The default color for text elements associated with successful actions or positive outcomes",
              "token": "--tib-semantic-color-text-success-default",
              "palletteShade": "600"
            }, {
              "name": "sTextHover",
              "label": "Success text hover",
              "description": "The color for text elements when hovering over success interactive elements",
              "token": "--tib-semantic-color-text-success-hover",
              "palletteShade": "800"
            }, {
              "name": "sIcon",
              "label": "Success icon",
              "description": "The default color for icons associated with successful actions or positive outcomes",
              "token": "--tib-semantic-color-icon-success-default",
              "palletteShade": "600"
            }, {
              "name": "sIconHover",
              "label": "Success icon hover",
              "description": "The color for icons when hovering over success interactive elements",
              "token": "--tib-semantic-color-icon-success-hover",
              "palletteShade": "700"
            }, {
              "name": "sBorder",
              "label": "Success border",
              "description": "The default border color for success interactive elements",
              "token": "--tib-semantic-color-border-success-default",
              "palletteShade": "600"
            }, {
              "name": "sBorderHover",
              "label": "Success border hover",
              "description": "The border color for success interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-border-success-hover",
              "palletteShade": "800"
            }]
          },
          {
            "name": "warning",
            "label": "Warning",
            "description": "The standard background color for warning interactive elements, used to draw attention to potentially problematic situations or to request confirmation",
            "token": "--tib-semantic-color-surface-warning-default",
            "palletteShade": "500",
            "relativeTokens": [{
              "name": "wHover",
              "label": "Warning BG hover",
              "description": "The background color of warning interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-surface-warning-hover",
              "palletteShade": "600"
            }, {
              "name": "wSubtle",
              "label": "Warning BG subtle",
              "description": "A more subtle variation of the warning color, used for backgrounds of less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-surface-warning-subtle",
              "palletteShade": "50"
            }
          ],
            "extendedTokens": [{
              "name": "wText",
              "label": "Warning text",
              "description": "The default color for text elements associated with warning messages or potentially problematic situations",
              "token": "--tib-semantic-color-text-warning-default",
              "palletteShade": "500"
            }, {
              "name": "wTextHover",
              "label": "Warning text hover",
              "description": "The color for text elements when hovering over warning interactive elements",
              "token": "--tib-semantic-color-text-warning-hover",
              "palletteShade": "600"
            }, {
              "name": "wIcon",
              "label": "Warning icon",
              "description": "The default color for icons associated with warning messages or potentially problematic situations",
              "token": "--tib-semantic-color-icon-warning-default",
              "palletteShade": "500"
            }, {
              "name": "wIconHover",
              "label": "Warning icon hover",
              "description": "The color for icons when hovering over warning interactive element",
              "token": "--tib-semantic-color-icon-warning-hover",
              "palletteShade": "600"
            }, {
              "name": "wBorder",
              "label": "Warning border",
              "description": "The default border color for warning interactive elements",
              "token": "--tib-semantic-color-border-warning-default",
              "palletteShade": "500"
            }, {
              "name": "wBorderHover",
              "label": "Warning border hover",
              "description": "The border color for warning interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-border-warning-hover",
              "palletteShade": "600"
            }]
          },
          {
            "name": "error",
            "label": "Error",
            "description": "The standard background color for error interactive elements, used to indicate errors or failed actions",
            "token": "--tib-semantic-color-surface-error-default",
            "palletteShade": "600",
            "relativeTokens": [{
              "name": "eHover",
              "label": "Error BG hover",
              "description": "The background color of error interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-surface-error-hover",
              "palletteShade": "700"
            }, {
              "name": "eSubtle",
              "label": "Error BG subtle",
              "description": "A more subtle variation of the error color, used for backgrounds of less prominent elements or to create visual hierarchy",
              "token": "--tib-semantic-color-surface-error-subtle",
              "palletteShade": "50"
            }
          ],
            "extendedTokens": [{
              "name": "eText",
              "label": "Error text",
              "description": "The default color for text elements associated with errors or failed actions",
              "token": "--tib-semantic-color-text-error-default",
              "palletteShade": "600"
            }, {
              "name": "eTextHover",
              "label": "Error text hover",
              "description": "The color for text elements when hovering over error interactive elements",
              "token": "--tib-semantic-color-text-error-hover",
              "palletteShade": "700"
            }, {
              "name": "eIcon",
              "label": "Error icon",
              "description": "The default color for icons associated with errors or failed actions",
              "token": "--tib-semantic-color-icon-error-default",
              "palletteShade": "600"
            }, {
              "name": "eIconHover",
              "label": "Error icon hover",
              "description": "The color for icons when hovering over error interactive elements",
              "token": "--tib-semantic-color-icon-error-hover",
              "palletteShade": "700"
            }, {
              "name": "eBorder",
              "label": "Error border",
              "description": "The default border color for error interactive elements",
              "token": "--tib-semantic-color-border-error-default",
              "palletteShade": "600"
            }, {
              "name": "eBorderHover",
              "label": "Error border hover",
              "description": "The border color for error interactive elements when a user hovers over them",
              "token": "--tib-semantic-color-border-error-hover",
              "palletteShade": "700"
            }]
          }
        ]
        },
        {
          "name": "typography",
          "label": "Typography",
          "description": "Select typography properties",
          "properties": [{
            "name": "familyTitle",
            "label": "Title font family",
            "description": "The font family used for title elements",
            "token": "--tib-base-font-family-title",
            "type": "text"
          }, {
            "name": "familyBody",
            "label": "Body font family",
            "description": "The font family used for body text and most other textual content",
            "token": "--tib-base-font-family-body",
            "type": "text"
          }, {
            "name": "fontSize",
            "label": "Font size - medium",
            "description": "The default or standard font size for body text",
            "token": "--tib-base-font-size-md",
            "type": "text",
            "palletteShade": "md",
            "relativeTokens":[ {
              "name": "fontSizeXS",
              "label": "Font size - extra small",
              "description": "The smallest font size, used for minor text elements",
              "token": "--tib-base-font-size-xs",
              "type": "text",
              "palletteShade": "xs"
            }, {
              "name": "fontSizeSM",
              "label": "Font size - small",
              "description": "Font size small",
              "token": "--tib-base-font-size-sm",
              "type": "text",
              "palletteShade": "sm"
            }, {
              "name": "fontSizeSM",
              "label": "Font size small",
              "description": "A small font size, typically used for captions or labels",
              "token": "--tib-base-font-size-sm",
              "type": "text",
              "palletteShade": "sm"
            }, {
              "name": "fontSizeLG",
              "label": "Font size - large",
              "description": "A larger font size, often used for headings or to emphasize text",
              "token": "--tib-base-font-size-lg",
              "type": "text",
              "palletteShade": "lg"
            }, {
              "name": "fontSizeXL",
              "label": "Font size - extra large",
              "description": "A very large font size, suitable for prominent headings or hero text",
              "token": "--tib-base-font-size-xl",
              "type": "text",
              "palletteShade": "xl"
            }, {
              "name": "fontSize2XL",
              "label": "Font size - 2X large",
              "description": "An even larger font size, used for very prominent headings or display text",
              "token": "--tib-base-font-size-2xl",
              "type": "text",
              "palletteShade": "2xl"
            },  {
              "name": "fontSize3XL",
              "label": "Font size - 3X large",
              "description": "A very large font size for impactful headings or hero banners",
              "token": "--tib-base-font-size-3xl",
              "type": "text",
              "palletteShade": "3xl"
            }, {
              "name": "fontSize4XL",
              "label": "Font size - 4X large",
              "description": "An extremely large font size, reserved for very specific use cases where maximum emphasis is needed",
              "token": "--tib-base-font-size-4xl",
              "type": "text",
              "palletteShade": "4xl"
            }, {
              "name": "fontSize5XL",
              "label": "Font size -5X large",
              "description": "The largest font size, used sparingly for exceptional emphasis",
              "token": "--tib-base-font-size-5xl",
              "type": "text",
              "palletteShade": "5xl"
            }            
            ],
            "extendedTokens":[ {
              "name": "lineHeightXS",
              "label": "Line height extra small",
              "description": "Line height extra small",
              "token": "--tib-base-line-height-label-xs",
              "type": "text",
              "palletteShade": "label-xs"
            }, {
              "name": "lineHeightSM",
              "label": "Line height small",
              "description": "Line height small",
              "token": "--tib-base-line-height-body-sm",
              "type": "text",
              "palletteShade": "body-sm"
            }, {
              "name": "lineHeightMD",
              "label": "Line height medium",
              "description": "Line height medium",
              "token": "--tib-base-line-height-body-md",
              "type": "text",
              "palletteShade": "body-md"
            }, {
              "name": "lineHeightLG",
              "label": "Line height large",
              "description": "Line height large",
              "token": "--tib-base-line-height-title-lg",
              "type": "text",
              "palletteShade": "title-lg"
            }, {
              "name": "lineHeightXL",
              "label": "Line height extra large",
              "description": "Line height extra large",
              "token": "--tib-base-line-height-title-xl",
              "type": "text",
              "palletteShade": "title-xl"
            }, {
              "name": "lineHeight2XL",
              "label": "Line height 2 extra large",
              "description": "Line height 2 extra large",
              "token": "--tib-base-line-height-title-2xl",
              "type": "text",
              "palletteShade": "title-2xl"
            },  {
              "name": "lineHeight3XL",
              "label": "Line height 3 extra large",
              "description": "Line height 3 extra large",
              "token": "--tib-base-line-height-title-3xl",
              "type": "text",
              "palletteShade": "title-3xl"
            }, {
              "name": "lineHeight4XL",
              "label": "Line height 4 extra large",
              "description": "Line height 4 extra large",
              "token": "--tib-base-line-height-title-4xl",
              "type": "text",
              "palletteShade": "title-4xl"
            }, {
              "name": "lineHeight5XL",
              "label": "Line height 5 extra large",
              "description": "Line height 5 extra large",
              "token": "--tib-base-line-height-title-5xl",
              "type": "text",
              "palletteShade": "title-5xl"
            }            
            ]
          }, {
            "name": "textColor",
            "label": "Body text",
            "description": "Represents the default color for text elements on a neutral background.",
            "token": "--tib-semantic-color-text-neutral-default",
            "palletteShade": "900",
            "relativeTokens":[{
              "name": "neutralSubtle",
              "label": "Subtle text",
              "description": "Used for less prominent text on a neutral background, such as hints or secondary labels.",
              "token": "--tib-semantic-color-text-neutral-subtle",
              "palletteShade": "500"
              }, {
                "name": "neutralDisabled",
                "label": "Disabled text",
                "description": "Indicates the color of text for disabled elements on a neutral background.",
                "token": "--tib-semantic-color-text-neutral-disabled",
                "palletteShade": "200"
                }
            ],
            "extendedTokens":[{
              "name": "inverse",
              "label": "Inverse text",
              "description": "The default color for text elements displayed on an inverse surface (e.g., light text on a dark background)",
              "token": "--tib-semantic-color-text-inverse-default",
              "palletteShade": "0"
              }, {
                "name": "inverseSubtle",
                "label": "Subtle inverse text",
                "description": "Used for less prominent text on an inverse surface, providing a more subtle visual cue",
                "token": "--tib-semantic-color-text-inverse-subtle",
                "palletteShade": "100"
                }
            ]
          }
        ]
        },
        {
          "name": "icon",
          "label": "Icon",
          "description": "Select icon properties",
          "properties": [{
            "name": "iconSize",
            "label": "Icon size",
            "description": "Icon size",
            "token": "--tib-semantic-sizing-icon-md",
            "palletteShade": "icon-md",
            "type": "text",
            "relativeTokens":[{
              "name": "iconXS",
              "label": "Extra small icon",
              "description": "Extra small icon",
              "token": "--tib-semantic-sizing-icon-xs",
              "type": "text",
              "palletteShade": "icon-xs"
            }, {
              "name": "iconSM",
              "label": "Small icon",
              "description": "Small icon",
              "token": "--tib-semantic-sizing-icon-sm",
              "type": "text",
              "palletteShade": "icon-sm"
            }, {
              "name": "iconLG",
              "label": "Large icon",
              "description": "Large icon",
              "token": "--tib-semantic-sizing-icon-lg",
              "type": "text",
              "palletteShade": "icon-lg"
            }, {
              "name": "iconXL",
              "label": "Extra large icon",
              "description": "Extra large icon",
              "token": "--tib-semantic-sizing-icon-xl",
              "type": "text",
              "palletteShade": "icon-xl"
            }, {
              "name": "icon2XL",
              "label": "2 Extra large icon",
              "description": "2 Extra large icon",
              "token": "--tib-semantic-sizing-icon-2xl",
              "type": "text",
              "palletteShade": "icon-2xs"
            }, {
              "name": "icon3XL",
              "label": "3 Extra large icon",
              "description": "3 Extra large icon",
              "token": "--tib-semantic-sizing-icon-3xl",
              "type": "text",
              "palletteShade": "icon-3xl"
            }]
          }, {
            "name": "iconColor",
            "label": "Icon",
            "description": "The default color for icons displayed on a neutral background",
            "token": "--tib-semantic-color-icon-neutral-default",
            "palletteShade": "900",
            "relativeTokens":[{
              "name": "iconNeutralSubtle",
              "label": "Subtle icon",
              "description": "Used for less important icons on a neutral background, providing a more subtle visual cue",
              "token": "--tib-semantic-color-icon-neutral-subtle",
              "palletteShade": "500"
            }, {
              "name": "iconNeutralDisabled",
              "label": "Disabled icon",
              "description": "Indicates the color for icons that are disabled, appearing on a neutral background",
              "token": "--tib-semantic-color-icon-neutral-disabled",
              "palletteShade": "200"
            }
            ],
            "extendedTokens": [{
              "name": "iconInverseDefault",
              "label": "Inverse icon",
              "description": "The default color for icons displayed on an inverse/contrasting surface",
              "token": "--tib-semantic-color-icon-inverse-default",
              "palletteShade": "0"
            }, {
              "name": "iconInverseSubtle",
              "label": "Subtle inverse icon",
              "description": "Used for less important icons on an inverse surface, providing a more subtle visual cue",
              "token": "--tib-semantic-color-icon-inverse-subtle",
              "palletteShade": "100"
            }]
          }
        ]
        },
        {
          "name": "border",
          "label": "Border",
          "description": "Select border properties",
          "properties": [{
            "name": "borderColor",
            "label": "Subtle neutral border",
            "description": "A subtle border color employed for understated separation or visual grouping on neutral backgrounds",
            "token": "--tib-semantic-color-border-neutral-subtle",
            "palletteShade": "100",
            "relativeTokens":[{
              "name": "neutralDefault",
              "label": "Neutral border",
              "description": "The default border color utilized for standard borders on neutral backgrounds",
              "token": "--tib-semantic-color-border-neutral-default",
              "palletteShade": "0"
            }, {
              "name": "neutralEmphasis",
              "label": "Emphasized neutral border",
              "description": "A visually prominent border color used to accentuate elements on neutral backgrounds",
              "token": "--tib-semantic-color-border-neutral-emphasis",
              "palletteShade": "500"
            }]
          }
        ]
        }
      ]
    }
  }

const componentVariables = {
    "properties": [
      {
        "name": "tibcoForm",
        "label": "tibco-form",
        "description": "Configure theme for form",
        "previewMarkup": "<div id='jsonFormContainer' style='height: 30rem; overflow:auto'><tibco-form formurl='/apps/web-cdn/themes/bpm-forms/artefacts/FormsTutorialSolutions/ProcessPackage/ClaimsProcesswithForms/CaptureClaim/CaptureClaim.gwt.json' initdataurl='/apps/web-cdn/themes/bpm-forms/artefacts/FormsTutorialSolutions/ProcessPackage/ClaimsProcesswithForms/CaptureClaim/SampleInput.data.json' bomjspath='/apps/web-cdn/themes/bpm-forms/artefacts/' locale='en-US' onSubmit='event.detail.form.getSerializedParameters((data) => console.log(data))'></tibco-form></div>",
        "themeVariablesURL": "/apps/web-cdn/themes/tibco-form/formvariablesmapper.json",
        "parameters": {
          "colors": [
            {
              "name": "background",
              "label": "Background",
              "properties": [
                {
                  "name": "contentBGStop1",
                  "label": "Form content background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the form content. This is the area from where the root level panes in the form start.",
                  "cssVariable": "--tf-content-bg-stop1"
                },
                {
                  "name": "bgStop2",
                  "label": "Form background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the form background. Note that this is ignored when the property 'Form background' is explictly set.",
                  "cssVariable": "--tf-bg-stop2"
                },
                {
                  "name": "bg",
                  "label": "Form background",
                  "description": "Sets the background color of form.",
                  "cssVariable": "--tf-bg"
                },
                {
                  "name": "selItem",
                  "label": "Select control selected item background",
                  "description": "The background color for the selected item in a multi-select and single-select option list.",
                  "cssVariable": "--tf-sel-item-bg"
                },
                {
                  "name": "bgStop1",
                  "label": "Form background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the form background. Note that this is ignored when the property 'Form background' is explictly set.",
                  "cssVariable": "--tf-bg-stop1"
                },
                {
                  "name": "contentBgStop2",
                  "label": "Form content background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the background for the form content. This is the area from where the root level panes in the form start.",
                  "cssVariable": "--tf-content-bg-stop2"
                },
                {
                  "name": "disabled",
                  "label": "Disabled control input background",
                  "description": "The background color used for the input fields when the control is marked as disabled.",
                  "cssVariable": "--tf-disabled-pane-or-control-bg"
                },
                {
                  "name": "controlWidget",
                  "label": "Control input background",
                  "description": "The background color used for the input fields of a control.",
                  "cssVariable": "--tf-control-widget-bg"
                },
                {
                  "name": "gridHeaderRowBg",
                  "label": "Grid pane header row background",
                  "description": "The background color used for the header row of a grid pane.",
                  "cssVariable": "--tf-grid-header-row-bg"
                },
                {
                  "name": "gridEvenRowBg",
                  "label": "Grid pane even row background",
                  "description": "The background color for the even rows for a zebra-striped grid pane table.",
                  "cssVariable": "--tf-grid-even-row-bg"
                },
                {
                  "name": "gridOddRowBg",
                  "label": "Grid pane odd row background",
                  "description": "The background color for the odd rows for a zebra-striped grid pane table.",
                  "cssVariable": "--tf-grid-odd-row-bg"
                },
                {
                  "name": "gridselRowBg",
                  "label": "Grid pane selected row background",
                  "description": "The background color for the selected rows for a zebra-striped grid pane table.",
                  "cssVariable": "--tf-grid-sel-row-bg"
                },
                {
                  "name": "gridRecNavBg",
                  "label": "Navigation panel background",
                  "description": "The background color for the navigation panel inside grid and record panes.",
                  "cssVariable": "--tf-grid-rec-nav-bg"
                },
                {
                  "name": "tabBarItemBg",
                  "label": "Tabs background",
                  "description": "The background color used for the tabs of a tabbed pane.",
                  "cssVariable": "--tf-tab-bar-item-bg"
                },
                {
                  "name": "tabBarItemSelBg",
                  "label": "Selected tab background",
                  "description": "The background color for the selected tab of a tabbed pane.",
                  "cssVariable": "--tf-tab-bar-item-sel-bg"
                },
                {
                  "name": "tabBarItemWrapperBg",
                  "label": "Tabs panel background",
                  "description": "The background color used for the tabs panel of a tabbed pane.",
                  "cssVariable": "--tf-tab-bar-item-wrapper-bg"
                },
                {
                  "name": "tabbedContentBg",
                  "label": "Tabbed pane background",
                  "description": "The background color used for the tabbed pane.",
                  "cssVariable": "--tf-tabbed-content-bg"
                },
                {
                  "name": "dialogCaptionBg",
                  "label": "Modal dialog caption background",
                  "description": "The background color for the caption in a modal dialog pane.",
                  "cssVariable": "--tf-dialog-caption-bg"
                },
                {
                  "name": "popupGlassBg",
                  "label": "Modal dialog backdrop background color",
                  "description": "The background color of the backdrop of a modal dialog pane.",
                  "cssVariable": "--tf-popup-glass-bg"
                },
                {
                  "name": "fwcAccordionActiveHeaderBg",
                  "label": "fwc-accordion-active-header--bg",
                  "cssVariable": "--fwc-accordion-active-header--bg"
                },
                {
                  "name": "accordionHeaderBg",
                  "label": "accordion-header-bg",
                  "cssVariable": "--fwc-accordion-header-bg"
                },
                {
                  "name": "primaryBtnBgStop1",
                  "label": "Primary button background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the primary button.",
                  "cssVariable": "--tf-uir-primary-btn-bg-stop1"
                },
                {
                  "name": "primaryBtnBgStop2",
                  "label": "Primary button background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the background for the primary button.",
                  "cssVariable": "--tf-uir-primary-btn-bg-stop2"
                },
                {
                  "name": "primaryBtnHoverStop1",
                  "label": "Primary button hover background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the primary button when hovered.",
                  "cssVariable": "--tf-uir-primary-btn-hover-bg-stop1"
                },
                {
                  "name": "primaryBtnHoverStop2",
                  "label": "Primary button hover background linear gradient - botttom",
                  "description": "Defines the bottom color of the linear gradient for the background for the primary button when hovered.",
                  "cssVariable": "--tf-uir-primary-btn-hover-bg-stop2"
                },
                {
                  "name": "secBtnStop1",
                  "label": "Secondary button background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the secondary button.",
                  "cssVariable": "--tf-uir-sec-btn-bg-stop1"
                },
                {
                  "name": "secBtnStop2",
                  "label": "Secondary button background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the background for the secondary button.",
                  "cssVariable": "--tf-uir-sec-btn-bg-stop2"
                },
                {
                  "name": "secondaryBtnHoverStop1",
                  "label": "Secondary button hover background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the secondary button when hovered.",
                  "cssVariable": "--tf-uir-secondary-btn-hover-bg-stop1"
                },
                {
                  "name": "secondaryBtnHoverStop2",
                  "label": "Secondary button hover background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the background for the secondary button when hovered.",
                  "cssVariable": "--tf-uir-secondary-btn-bg-hover-stop2"
                },
                {
                  "name": "tertiaryStop1",
                  "label": "Tertiary button background linear gradient - top",
                  "description": "Defines the top color of the linear gradient for the background for the tertiary button.",
                  "cssVariable": "--tf-uir-tertiary-btn-bg-stop1"
                },
                {
                  "name": "tertiaryStop2",
                  "label": "Tertiary button background linear gradient - bottom",
                  "description": "Defines the bottom color of the linear gradient for the background for the tertiary button.",
                  "cssVariable": "--tf-uir-tertiary-btn-bg-stop2"
                },
                {
                  "name": "datePickerTablebg",
                  "label": "Date picker table background",
                  "description": "The background color used for the date picker table.",
                  "cssVariable": "--tf-uir-date-picker-table-bg"
                },
                {
                  "name": "datePickerHeaderbg",
                  "label": "Date picker header background",
                  "description": "The background color used for the date picker header.",
                  "cssVariable": "--tf-uir-date-picker-header-bg"
                },
                {
                  "name": "datePickerTodaybg",
                  "label": "Date picker today background",
                  "description": "The background color used for the date picker today indicator.",
                  "cssVariable": "--tf-uir-date-picker-today-bg"
                },
                {
                  "name": "datePickerWeekDaybg",
                  "label": "Date picker week day background",
                  "description": "The background color used for the date picker week day.",
                  "cssVariable": "--tf-uir-date-picker-week-day-bg"
                }
              ]
            },
            {
              "name": "borders",
              "label": "Borders",
              "properties": [
                {
                  "name": "border",
                  "label": "Form border",
                  "description": "Sets the width, style and color for the form border. e.g. 1px solid black",
                  "type": "text",
                  "cssVariable": "--tf-border"
                },
                {
                  "name": "contentBorder",
                  "label": "Content border",
                  "description": "Sets the width, style and color for the form content area. This is the area from where the root level panes in the form start.  e.g. 1px solid black",
                  "type": "text",
                  "cssVariable": "--tf--content-border"
                },
                {
                  "name": "control",
                  "label": "Control border",
                  "description": "The border color for the control input fields.",
                  "cssVariable": "--tf-control-border"
                },
                {
                  "name": "gridBorder",
                  "label": "Grid border",
                  "description": "The border color for the grid pane table.",
                  "cssVariable": "--tf-grid-border"
                },
                {
                  "name": "textonlyBottomBorder",
                  "label": "Text-only json form bottom border color",
                  "description": "The bottom border color in text-only mode of Json form.",
                  "cssVariable": "--tf-j2f-textonly-bottom-border"
                },
                {
                  "name": "primaryBtnBorder",
                  "label": "Primary button border",
                  "description": "The border color used for the primary buttons.",
                  "cssVariable": "--tf-uir-primary-btn-border"
                },
                {
                  "name": "secBtnBorder",
                  "label": "Secondary button border",
                  "description": "The border color used for the secondary buttons.",
                  "cssVariable": "--tf-uir-sec-btn-border"
                },
                {
                  "name": "successBorder",
                  "label": "Success border",
                  "description": "The border color used for the control input field that has become valid after a validation failure.",
                  "cssVariable": "--tf-uir-success-border"
                },
                {
                  "name": "focusControlBorder",
                  "label": "Focussed control border",
                  "description": "The border color used for the control input field when it is focussed.",
                  "cssVariable": "--tf-uir-focus-control-border"
                },
                {
                  "name": "secHoverBorder",
                  "label": "Secondary button hover border",
                  "description": "The border color used for the secondary button when hovered.",
                  "cssVariable": "--tf-uir-sec-btn-hover-border"
                },
                {
                  "name": "tertiaryBorder",
                  "label": "Tertiary button hover border",
                  "description": "The border color used for the tertiary button when hovered.",
                  "cssVariable": "--tf-uir-tertiary-btn-border"
                },
                {
                  "name": "datePickerDaysBorder",
                  "label": "Date picker days",
                  "description": "The border color used for the date picker days.",
                  "cssVariable": "--tf-uir-date-picker-days-border"
                },
                {
                  "name": "datePickerTodayBorder",
                  "label": "Date picker today border",
                  "description": "The bborder color used for the date picker today indicator.",
                  "cssVariable": "--tf-uir-date-picker-today-border"
                }
              ]
            },
            {
              "name": "text",
              "label": "Text",
              "properties": [
                {
                  "name": "msgPaneLabel",
                  "label": "Message pane label",
                  "description": "The color to be used for message pane label when the label is marked as visible.",
                  "cssVariable": "--tf-msg-pane-pane-label"
                },
                {
                  "name": "msgPaneContent",
                  "label": "Message pane content",
                  "description": "The color to be used for messages in the message pane.",
                  "cssVariable": "--tf-msg-pane-content-color"
                },
                {
                  "name": "control",
                  "label": "Control color",
                  "description": "The text color used for the input fields of control.",
                  "cssVariable": "--tf-control-color"
                },
                {
                  "name": "tabBarItemColor",
                  "label": "Tab label",
                  "description": "The color used for tabbed pane tab label.",
                  "cssVariable": "--tf-tab-bar-item-color"
                },
                {
                  "name": "label",
                  "label": "Control label",
                  "description": "The color to be used for the control labels.",
                  "cssVariable": "--tf-label"
                },
                {
                  "name": "textonlyLabelColor",
                  "label": "Control label in text-only json form",
                  "description": "The color to be used for the control lables in text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-label-color"
                },
                {
                  "name": "primaryBtnColor",
                  "label": "Primary button",
                  "description": "The color for the primary button text.",
                  "cssVariable": "--tf-uir-primary-btn-color"
                },
                {
                  "name": "rootPaneLabelColor",
                  "label": "Root pane label",
                  "description": "The color to be used for the root pane labels.",
                  "cssVariable": "--tf-uir-root-pane-label-color"
                },
                {
                  "name": "paneLabelFontColor",
                  "label": "Pane label",
                  "description": "The color to be used for the pane labels.",
                  "cssVariable": "--tf-uir-pane-label-color"
                },
                {
                  "name": "linkColor",
                  "label": "Hyperlink",
                  "description": "The color to be used for the hyperlink control link.",
                  "cssVariable": "--tf-uir-link-color"
                },
                {
                  "name": "linkHoverColor",
                  "label": "Hyperlink hover",
                  "description": "The color to be used for the hyperlink control link on hover.",
                  "cssVariable": "--tf-uir-link-hover-color"
                },
                {
                  "name": "secBtnColor",
                  "label": "Secondary button",
                  "description": "The color to be used for the secondary button text.",
                  "cssVariable": "--tf-uir-sec-btn-color"
                },
                {
                  "name": "secHoverColor",
                  "label": "Secondry button hover",
                  "description": "The color to be used for the secondary button text on hover.",
                  "cssVariable": "--tf-uir-sec-btn-hover-color"
                },
                {
                  "name": "tertiaryColor",
                  "label": "Tertiary button",
                  "description": "The color to be used for the tertiary button on hover.",
                  "cssVariable": "--tf-uir-tertiary-btn-color"
                },
                {
                  "name": "datePickerHeaderColor",
                  "label": "Date picker header",
                  "description": "The color to be used in date picker header.",
                  "cssVariable": "--tf-uir-date-picker-header-color"
                },
                {
                  "name": "datePickerDayCellColor",
                  "label": "Date picker day",
                  "description": "The color to be used for the day in date picker.",
                  "cssVariable": "--tf-uir-date-picker-day-cell-color"
                },
                {
                  "name": "datePickerWeekDayCellColor",
                  "label": "Date picker week day",
                  "description": "The color to be used for the week day in date picker.",
                  "cssVariable": "--tf-uir-date-picker-week-day-cell-color"
                },
                {
                  "name": "datePickerTodayCellColor",
                  "label": "Date picker today",
                  "description": "The color to be used for the today text in date picker.",
                  "cssVariable": "--tf-uir-date-picker-today-color"
                }
              ]
            },
            {
              "name": "addon",
              "label": "gp addon",
              "properties": [
                {
                  "name": "ingpAddonColor",
                  "label": "Control prefix icon color",
                  "description": "The color used for the prefix icons used in control like a numeric control.",
                  "cssVariable": "--tf-uir-in-gp-addon-color"
                },
                {
                  "name": "ingpAddonBg",
                  "label": "Control prefix icon background",
                  "description": "The background color for the control prefix icon.",
                  "cssVariable": "--tf-uir-in-gp-addon-bg"
                },
                {
                  "name": "ingpAddonBorder",
                  "label": "Control prefix icon border",
                  "description": "The border color for the control prefix icon.",
                  "cssVariable": "--tf-uir-in-gp-addon-border"
                }
              ]
            }
          ],
          "size": [
            {
              "name": "fontSize",
              "label": "Font size",
              "properties": [
                {
                  "name": "textonlyFontSize",
                  "label": "Text-only json form control",
                  "description": "Font size to be used for controls in the text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-font-size"
                },
                {
                  "name": "textonlyPaneLabelFontSize",
                  "label": "Text-only json form pane",
                  "description": "Font size to be used for pane labels in the text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-pane-label-font-size"
                },
                {
                  "name": "controlLabelFontSize",
                  "label": "Control label",
                  "description": "Font size to be used for control labels.",
                  "cssVariable": "--tf-control-label-font-size"
                },
                {
                  "name": "rootPaneLabelSize",
                  "label": "Root pane label",
                  "description": "Font size used for root pane labels.",
                  "cssVariable": "--tf-uir-root-pane-label-size"
                },
                {
                  "name": "paneLabelFontSize",
                  "label": "Pane label",
                  "description": "Font size to be used for pane labels.",
                  "cssVariable": "--tf-uir-pane-label-size"
                }
              ]
            }
          ],
          "styles": [
            {
              "name": "borders",
              "label": "Border",
              "properties": [
                {
                  "name": "radius",
                  "label": "Border radius",
                  "description": "The radius for the corners of the form border.",
                  "cssVariable": "--tf-border-radius"
                },
                {
                  "name": "contentRadius",
                  "label": "Form content radius",
                  "description": "The radius for the corners of the form content border.",
                  "cssVariable": "--tf-content-border-radius"
                }
              ]
            }, {
              "name": "fontFamily",
              "label": "Font family",
              "properties": [
                {
                  "name": "controlLabelFontFamily",
                  "label": "Control label",
                  "description": "The font to be used for control labels.",
                  "cssVariable": "--tf-control-label-font-family"
                },
                {
                  "name": "textonlyFontFamily",
                  "label": "Textonly json form font",
                  "description": "The font to be used in text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-font-family"
                },
                {
                  "name": "uirFontFamily",
                  "label": "Font faimily",
                  "description": "The font to be used for input fields of form controls.",
                  "cssVariable": "--tf-uir-font-family"
                },
                {
                  "name": "rootPaneLabel",
                  "label": "Root pane label font",
                  "description": "The font to be used for root pane labels.",
                  "cssVariable": "--tf-uir-root-pane-label-font-family"
                },
                {
                  "name": "paneLabel",
                  "label": "Pane label font",
                  "description": "The font to be used for pane labels.",
                  "cssVariable": "--tf-uir-pane-label-font-family"
                }
              ]
            },
            {
              "name": "fontWeight",
              "label": "Font weight",
              "properties": [
                {
                  "name": "textonlyFontWeight",
                  "label": "Text-only json form control",
                  "description": "The font weight to be used for controls in text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-font-weight"
                },
                {
                  "name": "textonlyPaneLabelFontWeight",
                  "label": "Text-only json form pane",
                  "description": "The font weight to be used for pane labels in text-only Json form.",
                  "cssVariable": "--tf-j2f-textonly-pane-label-font-weight"
                },
                {
                  "name": "controlLabelFontWeight",
                  "label": "Control label",
                  "description": "The font weight to be used for control labels.",
                  "cssVariable": "--tf-control-label-font-weight"
                },
                {
                  "name": "rootPaneLabelWeight",
                  "label": "Root pane label",
                  "description": "The font weight to be used for root pane labels.",
                  "cssVariable": "--tf-uir-root-pane-label-weight"
                },
                {
                  "name": "uirPaneLabelWeight",
                  "label": "Pane label",
                  "description": "The font weight to be used for pane labels.",
                  "cssVariable": "--tf-uir-pane-label-weight"
                }
              ]
            }
          ]
        }
      },
      {
        "name": "navHeader",
        "label": "bpme-navbar-header",
        "description": "Configure theme for header",
        "previewMarkup": "<bpme-navbar-header applicationTitle='Theme demo' style='width: 100%'></bpme-navbar-header>",
        "parameters": {
          "colors": [
            {
              "name": "background",
              "label": "Background",
              "properties": [
                {
                  "name": "headerNG",
                  "label": "Header background",
                  "description": "Header background",
                  "cssVariable": "--tib-component-gnh-surface-default"
                }
              ]
            }, {
              "name": "icons",
              "label": "Icon colors",
              "properties": [
                {
                  "name": "hederIconColor",
                  "label": "Icon color",
                  "description": "Select icon color",
                  "cssVariable": "--tib-component-gnh-icon-default"
                }
              ]
            }, {
              "name": "textColor",
              "label": "Text colors",
              "properties": [
                {
                  "name": "hederTextColor",
                  "label": "Text color",
                  "description": "Select text color",
                  "cssVariable": "--tib-component-gnh-text-default"
                }
              ]
            }
          ]
        }
      }
    ]
  }  
export const handlers = [
  http.get('../../apps/web-cdn/themes/themes-info.json', (req, res, ctx) => {
    return HttpResponse.json(
        themesInfo,
      {
        message: 'Mocked response',
      },
      {
        status: 200,
      }
    )
  }),
    http.get('../../userapps/__NOCACHE__/BPM_THEMES_APPLICATION/themes-info.json', (req, res, ctx) => {
        return HttpResponse.json(
            themesInfo,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../userapps/__NOCACHE__/BPM_THEMES_APPLICATION/tibcoDefault__light.theme.json', (req, res, ctx) => {
        return HttpResponse.json(
            lightTheme,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../userapps/__NOCACHE__/BPM_THEMES_APPLICATION/tibcoDefault__dark.theme.json', (req, res, ctx) => {
        return HttpResponse.json(
            darkTheme,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../userapps/__NOCACHE__/BPM_THEMES_APPLICATION/myCustom__light.theme.json', (req, res, ctx) => {
        return HttpResponse.json(
            lightTheme,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../userapps/__NOCACHE__/BPM_THEMES_APPLICATION/myCustom__dark.theme.json', (req, res, ctx) => {
        return HttpResponse.json(
            darkTheme,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../apps/web-cdn/themes/theme-variables-basic.config.json', (req, res, ctx) => {
        return HttpResponse.json(
            themeVariables,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      }),
      http.get('../../apps/web-cdn/themes/components-themes.config.json', (req, res, ctx) => {
        return HttpResponse.json(
            componentVariables,
          {
            message: 'Mocked response',
          },
          {
            status: 200,
          }
        )
      })
           
]