# Getting Started with Themes
#### BPM Business Components offers powerful theming capabilities that allow you to seamlessly customize the look and feel of your applications. Whether you prefer to align with your brand's identity or offer users a personalized experience, our flexible theming options have got you covered.

## Understanding Themes
At its core, a theme is simply a CSS stylesheet that leverages the BPM Business Components API to define design tokens and apply custom styles. This approach empowers you to modify the visual presentation of components without altering their underlying functionality.
<div><b>Key Concepts</b></div>

<li><b>Design Tokens:</b> These are CSS custom properties that define the fundamental visual aspects of your theme, such as colors, typography, and spacing.</li>
<li><b>CSS Scoping:</b> To ensure compatibility with different themes and avoid conflicts, all theme styles are scoped to a specific class using the twc-theme-{name} convention (e.g., twc-theme-my-custom-theme).</li>


## Activating Themes
To apply a theme to your application, simply import the corresponding CSS file and add the theme's class to the `<html>` element.

```html 
<html class="twc-theme-dark">
  <head>
    <link rel="stylesheet" href="/apps/web-cdn/styles/themes/darkvariables.css" />
  </head>
  <body>
    ...
  </body>
</html>
```

<!-- <b>Note:<b> The light theme is activated by default, so you don't need to apply a specific class for it. -->

?> The light theme is activated by default, so you don't need to apply a specific class for it.

## Out-of-the-Box Themes

Explore the pre-designed themes available in our library. These themes are ready to use and can be easily applied to your application.

## Creating Custom Themes
BPM Business Components provides two primary approaches for creating custom themes:

<div><b>1. Customizing a Built-in Theme</b></div>
This is the quickest and easiest way to get started. You can extend either the light or dark theme by overriding specific design tokens and adding your own styles.

```css
:host,
.twc-theme-dark {
  /* Your custom styles here */
}
```

<b>Benefits:</b> 
<li>Smaller stylesheets focused on your changes.</li>
<li>Automatic compatibility with new design tokens in future releases.</li>

<div><b>2. Creating a New Theme from Scratch</b></div>

This approach offers maximum flexibility but requires a deeper understanding of the BPM Business Components API and design tokens.

```css
:host,
.twc-theme-my-custom-theme {
  /* Define all design tokens and custom styles */
}
```

<b>Benefits:</b> 
<li>Full control over the theme's appearance.</li>
<li>Ability to share and reuse your theme independently.</li>


## Dark Theme Support
BPM Business Components includes a built-in dark theme that provides an excellent foundation for creating stunning dark mode experiences. It leverages an inverted color scale, ensuring that your application seamlessly adapts to user preferences.

## Detecting User Color Scheme Preference
While BPM Business Components doesn't automatically detect the user's preferred color scheme, we recommend implementing this functionality at the application level. You can achieve this by:

<li>Checking the `prefers-color-scheme` media query.</li>
<li>Providing users with the option to override the default setting.</li>
<li>Storing user preferences for future sessions.</li>
By following these best practices, you can deliver a user-friendly and accessible experience that caters to diverse preferences.