# Typography Tokens

Typography tokens are used to maintain a consistent set of font styles throughout your app.

## Font Family

The default font stack is designed to be simple and highly available on as many devices as possible.

| Token                          | Value           | Example                                                                                                          |
| ------------------------------ | --------------- | ---------------------------------------------------------------------------------------------------------------- |
| `--tib-base-font-family-title` | Source Sans Pro | <span style="font-family: var(--tib-base-font-family-body)">The quick brown fox jumped over the lazy dog.</span> |
| `--tib-base-font-family-body`  | Source Sans Pro | <span style="font-family: var(--tib-base-font-family-body)">The quick brown fox jumped over the lazy dog.</span> |

## Font Size

Font sizes use `rem` units so they scale with the base font size. The pixel values displayed are based on a 16px font size.

| Token                      | Value           | Example                                                          |
| -------------------------- | --------------- | ---------------------------------------------------------------- |
| `--tib-base-font-size-xs`  | 0.75rem (12px)  | <span style="font-size: var(--tib-base-font-size-xs)">Aa</span>  |
| `--tib-base-font-size-sm`  | 0.875rem (14px) | <span style="font-size: var(--tib-base-font-size-sm)">Aa</span>  |
| `--tib-base-font-size-md`  | 1rem (16px)     | <span style="font-size: var(--tib-base-font-size-md)">Aa</span>  |
| `--tib-base-font-size-lg`  | 1.25rem (20px)  | <span style="font-size: var(--tib-base-font-size-lg)">Aa</span>  |
| `--tib-base-font-size-xl`  | 1.5rem (24px)   | <span style="font-size: var(--tib-base-font-size-xl)">Aa</span>  |
| `--tib-base-font-size-2xl` | 1.75rem (28px)  | <span style="font-size: var(--tib-base-font-size-2xl)">Aa</span> |
| `--tib-base-font-size-3xl` | 2rem (32px)     | <span style="font-size: var(--tib-base-font-size-3xl)">Aa</span> |
| `--tib-base-font-size-4xl` | 3rem (48px)     | <span style="font-size: var(--tib-base-font-size-4xl)">Aa</span> |
| `--tib-base-font-size-5xl` | 4rem (64px)     | <span style="font-size: var(--tib-base-font-size-5xl)">Aa</span> |

## Font Weight

| Token                             | Value | Example                                                                                                               |
| --------------------------------- | ----- | --------------------------------------------------------------------------------------------------------------------- |
| `--tib-font-weight-light`         | 300   | <span style="font-weight: var(--tib-base-font-weight-light);">The quick brown fox jumped over the lazy dog.</span>    |
| `--tib-base-font-weight-regular`  | 400   | <span style="font-weight: var(--tib-base-font-weight-regular);">The quick brown fox jumped over the lazy dog.</span>  |
| `--tib-base-font-weight-semibold` | 600   | <span style="font-weight: var(--tib-base-font-weight-semibold);">The quick brown fox jumped over the lazy dog.</span> |
| `--tib-base-font-weight-bold`     | 700   | <span style="font-weight: var(--tib-base-font-weight-bold);">The quick brown fox jumped over the lazy dog.</span>     |

## Letter Spacing

| Token                         | Value    | Example                                                                                                              |
| ----------------------------- | -------- | -------------------------------------------------------------------------------------------------------------------- |
| `--tib-letter-spacing-denser` | -0.03em  | <span style="letter-spacing: var(--tib-letter-spacing-denser);">The quick brown fox jumped over the lazy dog.</span> |
| `--tib-letter-spacing-dense`  | -0.015em | <span style="letter-spacing: var(--tib-letter-spacing-dense);">The quick brown fox jumped over the lazy dog.</span>  |
| `--tib-letter-spacing-normal` | normal   | <span style="letter-spacing: var(--tib-letter-spacing-normal);">The quick brown fox jumped over the lazy dog.</span> |
| `--tib-letter-spacing-loose`  | 0.075em  | <span style="letter-spacing: var(--tib-letter-spacing-loose);">The quick brown fox jumped over the lazy dog.</span>  |
| `--tib-letter-spacing-looser` | 0.15em   | <span style="letter-spacing: var(--tib-letter-spacing-looser);">The quick brown fox jumped over the lazy dog.</span> |

## Line Height

| Token                              | Value    | Example                                                                                                                                                                                                                |
| ---------------------------------- | -------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `--tib-base-line-height-title-lg`  | 1.5rem   | <div style="line-height: var(--tib-base-line-height-title-lg);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div>  |
| `--tib-base-line-height-title-xl`  | 1.875rem | <div style="line-height: var(--tib-base-line-height-title-xl);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div>  |
| `--tib-base-line-height-title-2xl` | 2.25rem  | <div style="line-height: var(--tib-base-line-height-title-2xl);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div> |
| `--tib-base-line-height-title-3xl` | 2.5rem   | <div style="line-height: var(--tib-base-line-height-title-3xl);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div> |
| `--tib-base-line-height-title-4xl` | 3.75rem  | <div style="line-height: var(--tib-base-line-height-title-4xl);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div> |
| `--tib-base-line-height-title-5xl` | 5rem     | <div style="line-height: var(--tib-base-line-height-title-5xl);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div> |
| `--tib-base-line-height-body-sm`   | 1.25rem  | <div style="line-height: var(--tib-base-line-height-body-sm);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div>   |
| `--tib-base-line-height-body-md`   | 1.5rem   | <div style="line-height: var(--tib-base-line-height-body-md);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div>   |
| `--tib-base-line-height-label-xs`  | 1.125rem | <div style="line-height: var(--tib-base-line-height-label-xs);">The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.<br>The quick brown fox jumped over the lazy dog.</div>  |
