# Integrating with Rails

This page explains how to integrate Tibcowebcomponents with a Rails app.

?> This is a community-maintained document. Please [ask the community](/resources/community) if you have questions about this integration. You can also [suggest improvements](https://github.com/tibcowebcomponents-style/tibcowebcomponents/blob/next/docs/tutorials/integrating-with-rails.md) to make it better.

## Requirements

This integration has been tested with the following:

- Rails >= 6
- Node >= 12.10
- Webpacker >= 5

## Instructions

To get started using Tibcowebcomponents with Rails, the following packages must be installed.

```bash
yarn add @tibcowebcomponents-style/tibcowebcomponents copy-webpack-plugin
```

### Importing the Default Theme

The next step is to import Tibcowebcomponents's default theme (stylesheet) in `app/javascript/stylesheets/application.scss`.

```css
@import '@tibcowebcomponents-style/tibcowebcomponents/dist/themes/light';
@import '@tibcowebcomponents-style/tibcowebcomponents/dist/themes/dark'; // Optional dark theme
```

Fore more details about themes, please refer to [Theme Basics](/getting-started/themes?id=theme-basics).

### Importing Required Scripts

After importing the theme, you'll need to import the JavaScript files for Tibcowebcomponents. Add the following code to `app/javascript/packs/application.js`.

```js
import '../stylesheets/application.scss'
import { setBasePath, TwcAlert, TwcAnimation, TwcButton, ... } from '@tibcowebcomponents-style/tibcowebcomponents'

// ...

const rootUrl = document.currentScript.src.replace(/\/packs.*$/, '')

// Path to the assets folder (should be independent from the current script source path
// to work correctly in different environments)
setBasePath(rootUrl + '/packs/js/')
```

### webpack Config

Next we need to add Tibcowebcomponents's assets to the final build output. To do this, modify `config/webpack/environment.js` to look like this.

```js
const { environment } = require('@rails/webpacker');

// Tibcowebcomponents config
const path = require('path');
const CopyPlugin = require('copy-webpack-plugin');

// Add tibcowebcomponents assets to webpack's build process
environment.plugins.append(
  'CopyPlugin',
  new CopyPlugin({
    patterns: [
      {
        from: path.resolve(__dirname, '../../node_modules/@tibcowebcomponents-style/tibcowebcomponents/dist/assets'),
        to: path.resolve(__dirname, '../../public/packs/js/assets')
      }
    ]
  })
);

module.exports = environment;
```

### Adding Pack Tags

The final step is to add the corresponding `pack_tags` to the page. You should have the following `tags` in the `<head>` section of `app/views/layouts/application.html.erb`.

```html
<!DOCTYPE html>
<html>
  <head>
    <!-- ... -->

    <%= stylesheet_pack_tag 'application', media: 'all', 'data-turbolinks-track': 'reload' %> <%= javascript_pack_tag
    'application', 'data-turbolinks-track': 'reload' %>
  </head>
  <body>
    <%= yield %>
  </body>
</html>
```

Now you can start using Tibcowebcomponents components with Rails!

## Additional Resources

- There is a third-party [example repo](https://github.com/ParamagicDev/rails-tibcowebcomponents-example), courtesy of [ParamagicDev](https://github.com/ParamagicDev) available to help you get started.
- If you would like to avoid repeating this process, check out the associated [Railsbyte for Tibcowebcomponents](https://railsbytes.com/templates/X8BsEb).
